@@ -26,7 +26,7 @@
 #include "skgtransactionmng.h"
 
 SKGAdviceBoardWidget::SKGAdviceBoardWidget(QWidget *iParent, SKGDocument *iDocument)
-    : SKGBoardWidget(iParent, iDocument, i18nc("Dashboard widget title", "Advices"))
+    : SKGBoardWidget(iParent, iDocument, i18nc("Dashboard widget title", "Advice"))
     , m_maxAdvice(7)
     , m_refreshNeeded(true)
     , m_refresh(nullptr)
