@@ -29,9 +29,18 @@
 
 bool SKGBookmarkPluginDockWidget::m_middleClick = false;
 
-SKGBookmarkPluginDockWidget::SKGBookmarkPluginDockWidget(QWidget* iParent, SKGDocument* iDocument)
-    : SKGWidget(iParent, iDocument), m_mainMenu(nullptr), m_actDelete(nullptr), m_actRename(nullptr), m_actChangeIcon(nullptr), m_actAddBookmark(nullptr), m_actAddBookmarks(nullptr),
-      m_actAddBookmarkGroup(nullptr), m_actSetAutostart(nullptr), m_actUnsetAutostart(nullptr), m_modelview(nullptr)
+SKGBookmarkPluginDockWidget::SKGBookmarkPluginDockWidget(QWidget *iParent, SKGDocument *iDocument)
+    : SKGWidget(iParent, iDocument)
+    , m_mainMenu(nullptr)
+    , m_actDelete(nullptr)
+    , m_actRename(nullptr)
+    , m_actChangeIcon(nullptr)
+    , m_actAddBookmark(nullptr)
+    , m_actAddBookmarks(nullptr)
+    , m_actAddBookmarkGroup(nullptr)
+    , m_actSetAutostart(nullptr)
+    , m_actUnsetAutostart(nullptr)
+    , m_modelview(nullptr)
 {
     SKGTRACEINFUNC(1)
     if (iDocument == nullptr) {
@@ -44,21 +53,22 @@ SKGBookmarkPluginDockWidget::SKGBookmarkPluginDockWidget(QWidget* iParent, SKGDo
     newPalette.setColor(QPalette::Base, Qt::transparent);
     ui.kBookmarksList->setPalette(newPalette);
     ui.kBookmarksList->setRootIsDecorated(false);
-    ui.kBookmarksList->setAnimated(false);  // Not compatible with double click
+    ui.kBookmarksList->setAnimated(false); // Not compatible with double click
     ui.kBookmarksList->setEditTriggers(QAbstractItemView::NoEditTriggers);
 
-    ui.kTools->setIcon(SKGServices::fromTheme(QLatin1String("configure")));
+    ui.kTools->setIcon(SKGServices::fromTheme(QStringLiteral("configure")));
 
     ui.kBookmarksList->setContextMenuPolicy(Qt::CustomContextMenu);
     connect(ui.kBookmarksList, &SKGTreeView::customContextMenuRequested, this, &SKGBookmarkPluginDockWidget::showMenu);
 
     // Add model
-    m_modelview = new SKGObjectModelBase(getDocument(), QLatin1String("v_node"), QLatin1String("1=1 ORDER BY f_sortorder, t_name"), this, QLatin1String("rd_node_id"));
+    m_modelview =
+        new SKGObjectModelBase(getDocument(), QStringLiteral("v_node"), QStringLiteral("1=1 ORDER BY f_sortorder, t_name"), this, QStringLiteral("rd_node_id"));
     auto modelproxy = new SKGSortFilterProxyModel(this);
     modelproxy->setSourceModel(m_modelview);
     ui.kBookmarksList->setModel(modelproxy);
 
-    connect(ui.kFilterEdit, &QLineEdit::textChanged, this, [ = ](const QString & itext) {
+    connect(ui.kFilterEdit, &QLineEdit::textChanged, this, [modelproxy](const QString &itext) {
         modelproxy->setFilterKeyColumn(-1);
         modelproxy->setFilterCaseSensitivity(Qt::CaseInsensitive);
         modelproxy->setFilterFixedString(itext);
@@ -94,7 +104,7 @@ SKGBookmarkPluginDockWidget::~SKGBookmarkPluginDockWidget()
     m_modelview = nullptr;
 }
 
-QWidget* SKGBookmarkPluginDockWidget::mainWidget()
+QWidget *SKGBookmarkPluginDockWidget::mainWidget()
 {
     return ui.kBookmarksList;
 }
@@ -104,46 +114,49 @@ void SKGBookmarkPluginDockWidget::initMenu()
     if (m_mainMenu == nullptr) {
         // Build contextual menu
         m_mainMenu = new QMenu(ui.kBookmarksList);
-        QAction* actExpandAll = m_mainMenu->addAction(SKGServices::fromTheme(QLatin1String("format-indent-more")), i18nc("Noun, user action", "Expand all"));
+        QAction *actExpandAll = m_mainMenu->addAction(SKGServices::fromTheme(QStringLiteral("format-indent-more")), i18nc("Noun, user action", "Expand all"));
         connect(actExpandAll, &QAction::triggered, ui.kBookmarksList, &SKGTreeView::expandAll);
 
-        QAction* actCollapseAll = m_mainMenu->addAction(SKGServices::fromTheme(QLatin1String("format-indent-less")), i18nc("Noun, user action", "Collapse all"));
+        QAction *actCollapseAll =
+            m_mainMenu->addAction(SKGServices::fromTheme(QStringLiteral("format-indent-less")), i18nc("Noun, user action", "Collapse all"));
         connect(actCollapseAll, &QAction::triggered, ui.kBookmarksList, &SKGTreeView::collapseAll);
         ui.kBookmarksList->insertAction(nullptr, actCollapseAll);
 
         m_mainMenu->addSeparator();
 
-        m_actAddBookmark = m_mainMenu->addAction(SKGServices::fromTheme(QLatin1String("list-add")), i18nc("Verb", "Bookmark current page"));
+        m_actAddBookmark = m_mainMenu->addAction(SKGServices::fromTheme(QStringLiteral("list-add")), i18nc("Verb", "Bookmark current page"));
         connect(m_actAddBookmark, &QAction::triggered, this, &SKGBookmarkPluginDockWidget::onAddBookmark);
 
-        m_actAddBookmarks = m_mainMenu->addAction(SKGServices::fromTheme(QLatin1String("list-add")), i18nc("Verb", "Bookmark all pages"));
+        m_actAddBookmarks = m_mainMenu->addAction(SKGServices::fromTheme(QStringLiteral("list-add")), i18nc("Verb", "Bookmark all pages"));
         connect(m_actAddBookmarks, &QAction::triggered, this, &SKGBookmarkPluginDockWidget::onAddBookmarks);
 
-        m_actAddBookmarkGroup = m_mainMenu->addAction(SKGServices::fromTheme(QLatin1String("folder-new")), i18nc("Verb", "Add bookmark group"));
+        m_actAddBookmarkGroup = m_mainMenu->addAction(SKGServices::fromTheme(QStringLiteral("folder-new")), i18nc("Verb", "Add bookmark group"));
         connect(m_actAddBookmarkGroup, &QAction::triggered, this, &SKGBookmarkPluginDockWidget::onAddBookmarkGroup);
 
         m_mainMenu->addSeparator();
 
-        m_actDelete = m_mainMenu->addAction(SKGServices::fromTheme(QLatin1String("edit-delete")), i18nc("Verb, delete an item", "Delete"));
+        m_actDelete = m_mainMenu->addAction(SKGServices::fromTheme(QStringLiteral("edit-delete")), i18nc("Verb, delete an item", "Delete"));
         connect(m_actDelete, &QAction::triggered, this, &SKGBookmarkPluginDockWidget::onRemoveBookmark);
 
         m_mainMenu->addSeparator();
 
-        m_actSetAutostart = m_mainMenu->addAction(SKGServices::fromTheme(QLatin1String("media-playback-start")), i18nc("Verb, automatically load when the application is started", "Autostart"));
+        m_actSetAutostart = m_mainMenu->addAction(SKGServices::fromTheme(QStringLiteral("media-playback-start")),
+                                                  i18nc("Verb, automatically load when the application is started", "Autostart"));
         connect(m_actSetAutostart, &QAction::triggered, this, &SKGBookmarkPluginDockWidget::onSetAutostart);
 
-        m_actUnsetAutostart = m_mainMenu->addAction(SKGServices::fromTheme(QLatin1String("media-playback-stop")), i18nc("Verb", "Remove Autostart"));
+        m_actUnsetAutostart = m_mainMenu->addAction(SKGServices::fromTheme(QStringLiteral("media-playback-stop")), i18nc("Verb", "Remove Autostart"));
         connect(m_actUnsetAutostart, &QAction::triggered, this, &SKGBookmarkPluginDockWidget::onUnsetAutostart);
 
-        m_actRename = m_mainMenu->addAction(SKGServices::fromTheme(QLatin1String("edit-rename")), i18nc("Verb, change the name of an item", "Rename"));
+        m_actRename = m_mainMenu->addAction(SKGServices::fromTheme(QStringLiteral("edit-rename")), i18nc("Verb, change the name of an item", "Rename"));
         m_actRename->setShortcut(Qt::Key_F2);
         connect(m_actRename, &QAction::triggered, this, &SKGBookmarkPluginDockWidget::onRenameBookmark);
 
-        m_actChangeIcon = m_mainMenu->addAction(SKGServices::fromTheme(QLatin1String("edit-image-face-add")), i18nc("Verb, change the icon of an item", "Change icon…"));
+        m_actChangeIcon =
+            m_mainMenu->addAction(SKGServices::fromTheme(QStringLiteral("edit-image-face-add")), i18nc("Verb, change the icon of an item", "Change icon…"));
         connect(m_actChangeIcon, &QAction::triggered, this, &SKGBookmarkPluginDockWidget::onChangeIconBookmark);
 
         m_mainMenu->addSeparator();
-        m_mainMenu->addAction(SKGMainPanel::getMainPanel()->getGlobalAction(QLatin1String("tab_overwritebookmark")));
+        m_mainMenu->addAction(SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("tab_overwritebookmark")));
 
         ui.kTools->setMenu(m_mainMenu);
     }
@@ -158,16 +171,16 @@ void SKGBookmarkPluginDockWidget::showMenu(const QPoint iPos)
 void SKGBookmarkPluginDockWidget::onSetAutostart()
 {
     SKGTRACEINFUNC(10)
-    setAutostart(QLatin1String("Y"));
+    setAutostart(QStringLiteral("Y"));
 }
 
 void SKGBookmarkPluginDockWidget::onUnsetAutostart()
 {
     SKGTRACEINFUNC(10)
-    setAutostart(QLatin1String("N"));
+    setAutostart(QStringLiteral("N"));
 }
 
-void SKGBookmarkPluginDockWidget::setAutostart(const QString& value)
+void SKGBookmarkPluginDockWidget::setAutostart(const QString &value)
 {
     SKGTRACEINFUNC(10)
     SKGObjectBase::SKGListSKGObjectBase selectedBookmarks = getSelectedObjects();
@@ -177,26 +190,35 @@ void SKGBookmarkPluginDockWidget::setAutostart(const QString& value)
     // foreach selected bookmark, set the t_autostart attribute to 'y' or 'n'
     {
         int nb = selectedBookmarks.count();
-        SKGBEGINPROGRESSTRANSACTION(*getDocument(), value == QLatin1String("Y") ? i18nc("Noun, name of the user action", "Autostart bookmarks") : i18nc("Noun, name of the user action", "Do not Autostart bookmarks"), err, nb)
-        for (int i = 0 ; !err && i < nb  ; ++i) {
+        SKGBEGINPROGRESSTRANSACTION(*getDocument(),
+                                    value == QStringLiteral("Y") ? i18nc("Noun, name of the user action", "Autostart bookmarks")
+                                                                 : i18nc("Noun, name of the user action", "Do not Autostart bookmarks"),
+                                    err,
+                                    nb)
+        for (int i = 0; !err && i < nb; ++i) {
             SKGNodeObject bookmark(selectedBookmarks.at(i));
-            err = bookmark.setAttribute(QLatin1String("t_autostart"), value);
+            err = bookmark.setAttribute(QStringLiteral("t_autostart"), value);
             IFOKDO(err, bookmark.save())
 
             // Send message
-            IFOKDO(err, bookmark.getDocument()->sendMessage(i18nc("An information message", "The Autostart status of bookmark '%1' has been changed", bookmark.getDisplayName()), SKGDocument::Hidden))
+            IFOKDO(err,
+                   bookmark.getDocument()->sendMessage(
+                       i18nc("An information message", "The Autostart status of bookmark '%1' has been changed", bookmark.getDisplayName()),
+                       SKGDocument::Hidden))
 
             IFOKDO(err, getDocument()->stepForward(i + 1))
         }
     }
 
     // status bar
-    IFOKDO(err, SKGError(0, value == QLatin1String("Y") ? i18nc("Successful message after an user action", "Autostart bookmarks") : i18nc("Successful message after an user action", "Do not Autostart bookmarks")))
+    IFOKDO(err,
+           SKGError(0,
+                    value == QStringLiteral("Y") ? i18nc("Successful message after an user action", "Autostart bookmarks")
+                                                 : i18nc("Successful message after an user action", "Do not Autostart bookmarks")))
     SKGMainPanel::displayErrorMessage(err);
 }
 
-
-void SKGBookmarkPluginDockWidget::openBookmark(const SKGNodeObject& iNode, bool iFirstInNewPage, bool iPin)
+void SKGBookmarkPluginDockWidget::openBookmark(const SKGNodeObject &iNode, bool iFirstInNewPage, bool iPin)
 {
     SKGTRACEINFUNC(1)
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
@@ -210,7 +232,7 @@ void SKGBookmarkPluginDockWidget::openBookmark(const SKGNodeObject& iNode, bool
     if (nbTab != 0) {
         setForcusOn = nbTab - 1;
 
-        SKGTabPage* cPage = SKGMainPanel::getMainPanel()->currentPage();
+        SKGTabPage *cPage = SKGMainPanel::getMainPanel()->currentPage();
         if (m_middleClick || ((cPage != nullptr) && cPage->isPin())) {
             setForcusOn = nbTab;
         } else {
@@ -219,17 +241,22 @@ void SKGBookmarkPluginDockWidget::openBookmark(const SKGNodeObject& iNode, bool
     }
 
     int tabNumberForNextOpen = (m_middleClick || iFirstInNewPage ? -1 : SKGMainPanel::getMainPanel()->currentPageIndex());
-    for (int i = 0; i < nodes.count(); ++i) {  // WARNING: This list is modified dynamically
+    for (int i = 0; i < nodes.count(); ++i) { // WARNING: This list is modified dynamically
         SKGNodeObject selectedNode = nodes.at(i);
         QStringList data = SKGServices::splitCSVLine(selectedNode.getData());
         if (data.count() > 2) {
             // This bookmark has information ==> we open it
-            SKGTabPage* page = SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName(data[0]), tabNumberForNextOpen, data[2], selectedNode.getName(), SKGServices::intToString(selectedNode.getID()), i == nodes.count() - 1);
+            SKGTabPage *page = SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName(data[0]),
+                                                                      tabNumberForNextOpen,
+                                                                      data[2],
+                                                                      selectedNode.getName(),
+                                                                      SKGServices::intToString(selectedNode.getID()),
+                                                                      i == nodes.count() - 1);
             if (page != nullptr) {
                 if (skgbookmark_settings::pinhomebookmarks()) {
                     page->setPin(iPin);
                 }
-                SKGTabWidget* tab = SKGMainPanel::getMainPanel()->getTabWidget();
+                SKGTabWidget *tab = SKGMainPanel::getMainPanel()->getTabWidget();
                 if (tab != nullptr) {
                     tab->setTabIcon(tab->indexOf(page), selectedNode.getIcon());
                 }
@@ -240,7 +267,7 @@ void SKGBookmarkPluginDockWidget::openBookmark(const SKGNodeObject& iNode, bool
             // This bookmark is a folder ==> we open children by recursion
             SKGObjectBase::SKGListSKGObjectBase children;
             selectedNode.getNodes(children);
-            for (const auto& item : std::as_const(children)) {
+            for (const auto &item : std::as_const(children)) {
                 nodes.push_back(SKGNodeObject(item));
             }
         }
@@ -256,12 +283,12 @@ void SKGBookmarkPluginDockWidget::onBeforeOpenBookmark()
     m_middleClick = (QApplication::keyboardModifiers() & Qt::ControlModifier) != 0u || (QApplication::mouseButtons() & Qt::MiddleButton) != 0u;
 }
 
-void SKGBookmarkPluginDockWidget::onOpenBookmark(const QModelIndex& index)
+void SKGBookmarkPluginDockWidget::onOpenBookmark(const QModelIndex &index)
 {
     SKGTRACEINFUNC(1)
     if (!(QApplication::mouseButtons() & Qt::RightButton)) {
-        auto* proxyModel = qobject_cast<QSortFilterProxyModel*>(ui.kBookmarksList->model());
-        auto* model = qobject_cast<SKGObjectModelBase*>(proxyModel->sourceModel());
+        auto *proxyModel = qobject_cast<QSortFilterProxyModel *>(ui.kBookmarksList->model());
+        auto *model = qobject_cast<SKGObjectModelBase *>(proxyModel->sourceModel());
         if (model != nullptr) {
             SKGNodeObject node(model->getObject(proxyModel->mapToSource(index)));
             if (!node.isFolder()) {
@@ -271,12 +298,12 @@ void SKGBookmarkPluginDockWidget::onOpenBookmark(const QModelIndex& index)
     }
 }
 
-void SKGBookmarkPluginDockWidget::onOpenBookmarkFolder(const QModelIndex& index)
+void SKGBookmarkPluginDockWidget::onOpenBookmarkFolder(const QModelIndex &index)
 {
     SKGTRACEINFUNC(1)
     if (!(QApplication::mouseButtons() & Qt::RightButton)) {
-        auto* proxyModel = qobject_cast<QSortFilterProxyModel*>(ui.kBookmarksList->model());
-        auto* model = qobject_cast<SKGObjectModelBase*>(proxyModel->sourceModel());
+        auto *proxyModel = qobject_cast<QSortFilterProxyModel *>(ui.kBookmarksList->model());
+        auto *model = qobject_cast<SKGObjectModelBase *>(proxyModel->sourceModel());
         if (model != nullptr) {
             SKGNodeObject node(model->getObject(proxyModel->mapToSource(index)));
             if (node.isFolder()) {
@@ -317,11 +344,14 @@ void SKGBookmarkPluginDockWidget::onAddBookmarkGroup()
         IFOKDO(err, SKGNodeObject::createPathNode(getDocument(), name, node, true))
 
         // Send message
-        IFOKDO(err, node.getDocument()->sendMessage(i18nc("An information message", "The bookmark folder '%1' has been added", node.getDisplayName()), SKGDocument::Hidden))
+        IFOKDO(err,
+               node.getDocument()->sendMessage(i18nc("An information message", "The bookmark folder '%1' has been added", node.getDisplayName()),
+                                               SKGDocument::Hidden))
     }
 
     // status bar
-    IFOK(err) {
+    IFOK(err)
+    {
         ui.kBookmarksList->selectObject(node.getUniqueID());
         err = SKGError(0, i18nc("Successful message after an user action", "Bookmark group created"));
     }
@@ -363,12 +393,15 @@ void SKGBookmarkPluginDockWidget::onAddBookmarks()
             err = createNodeFromPage(SKGMainPanel::getMainPanel()->page(i), rootNode, node);
 
             // Send message
-            IFOKDO(err, node.getDocument()->sendMessage(i18nc("An information message", "The bookmark '%1' has been added", node.getDisplayName()), SKGDocument::Hidden))
+            IFOKDO(err,
+                   node.getDocument()->sendMessage(i18nc("An information message", "The bookmark '%1' has been added", node.getDisplayName()),
+                                                   SKGDocument::Hidden))
         }
     }
 
     // status bar
-    IFOK(err) {
+    IFOK(err)
+    {
         ui.kBookmarksList->selectObject(rootNode.getUniqueID());
         err = SKGError(0, i18nc("Successful message after an user action", "Bookmarks created"));
     }
@@ -394,14 +427,15 @@ void SKGBookmarkPluginDockWidget::onAddBookmark()
         err = createNodeFromPage(SKGMainPanel::getMainPanel()->currentPage(), parentNode, node);
     }
     // status bar
-    IFOK(err) {
+    IFOK(err)
+    {
         ui.kBookmarksList->selectObject(node.getUniqueID());
         err = SKGError(0, i18nc("Successful message after an user action", "Bookmark created"));
     }
     SKGMainPanel::displayErrorMessage(err);
 }
 
-SKGError SKGBookmarkPluginDockWidget::createNodeFromPage(SKGTabPage* iPage, const SKGNodeObject& iParentNode, SKGNodeObject& oCreatedNode)
+SKGError SKGBookmarkPluginDockWidget::createNodeFromPage(SKGTabPage *iPage, const SKGNodeObject &iParentNode, SKGNodeObject &oCreatedNode)
 {
     SKGTRACEINFUNC(1)
     SKGError err;
@@ -433,26 +467,28 @@ SKGError SKGBookmarkPluginDockWidget::createNodeFromPage(SKGTabPage* iPage, cons
         if (tab) {
             auto index = tab->indexOf(iPage);
             if (index != -1) {
-                defaultName = tab-> tabText(index);
-                defaultIcon = tab-> tabIcon(index).name();
+                defaultName = tab->tabText(index);
+                defaultIcon = tab->tabIcon(index).name();
             }
         }
-        name += defaultName.replace("&", "");
+        name += defaultName.replace(QStringLiteral("&"), QString());
 
         // Create bookmark
         SKGBEGINTRANSACTION(*iParentNode.getDocument(), i18nc("Noun, name of the user action", "Bookmark creation '%1'", name), err)
         err = SKGNodeObject::createPathNode(iParentNode.getDocument(), name, oCreatedNode, true);
-        IFOK(err) {
-            QString value = SKGServices::stringToCsv(iPage->objectName()) % QLatin1Char(';') %
-                            SKGServices::stringToCsv(defaultName) % QLatin1Char(';') %
-                            SKGServices::stringToCsv(iPage->getState());
+        IFOK(err)
+        {
+            QString value = SKGServices::stringToCsv(iPage->objectName()) % u';' % SKGServices::stringToCsv(defaultName) % u';'
+                % SKGServices::stringToCsv(iPage->getState());
 
             err = oCreatedNode.setData(value);
             IFOKDO(err, oCreatedNode.setIcon(defaultIcon))
             IFOKDO(err, oCreatedNode.save())
 
             // Send message
-            IFOKDO(err, oCreatedNode.getDocument()->sendMessage(i18nc("An information message", "The bookmark '%1' has been added", oCreatedNode.getDisplayName()), SKGDocument::Hidden))
+            IFOKDO(err,
+                   oCreatedNode.getDocument()->sendMessage(i18nc("An information message", "The bookmark '%1' has been added", oCreatedNode.getDisplayName()),
+                                                           SKGDocument::Hidden))
         }
     }
     return err;
@@ -462,10 +498,10 @@ void SKGBookmarkPluginDockWidget::onRenameBookmark()
 {
     SKGTRACEINFUNC(1)
 
-    QItemSelectionModel* selModel = ui.kBookmarksList->selectionModel();
-    auto* proxyModel = qobject_cast< QSortFilterProxyModel* >(ui.kBookmarksList->model());
+    QItemSelectionModel *selModel = ui.kBookmarksList->selectionModel();
+    auto *proxyModel = qobject_cast<QSortFilterProxyModel *>(ui.kBookmarksList->model());
     if ((proxyModel != nullptr) && (selModel != nullptr)) {
-        auto* model = qobject_cast<SKGObjectModelBase*>(proxyModel->sourceModel());
+        auto *model = qobject_cast<SKGObjectModelBase *>(proxyModel->sourceModel());
         if (model != nullptr) {
             QModelIndexList indexes = selModel->selectedRows();
             if (indexes.count() == 1) {
@@ -492,7 +528,9 @@ void SKGBookmarkPluginDockWidget::onChangeIconBookmark()
                 IFOKDO(err, node.save())
 
                 // Send message
-                IFOKDO(err, node.getDocument()->sendMessage(i18nc("An information message", "The icon of the bookmark '%1' has been changed", node.getDisplayName()), SKGDocument::Hidden))
+                IFOKDO(err,
+                       node.getDocument()->sendMessage(i18nc("An information message", "The icon of the bookmark '%1' has been changed", node.getDisplayName()),
+                                                       SKGDocument::Hidden))
             }
             // status bar
             IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Bookmark icon changed")))
@@ -501,7 +539,6 @@ void SKGBookmarkPluginDockWidget::onChangeIconBookmark()
     }
 }
 
-
 void SKGBookmarkPluginDockWidget::onRemoveBookmark()
 {
     SKGTRACEINFUNC(1)
@@ -558,10 +595,10 @@ void SKGBookmarkPluginDockWidget::refresh()
     if (nbSelectedObjects == 1) {
         SKGNodeObject node(bookmarks.at(0));
         if (m_actSetAutostart != nullptr) {
-            m_actSetAutostart->setEnabled(node.getAttribute(QLatin1String("t_autostart")) != QLatin1String("Y"));
+            m_actSetAutostart->setEnabled(node.getAttribute(QStringLiteral("t_autostart")) != QStringLiteral("Y"));
         }
         if (m_actUnsetAutostart != nullptr) {
-            m_actUnsetAutostart->setEnabled(node.getAttribute(QLatin1String("t_autostart")) == QLatin1String("Y"));
+            m_actUnsetAutostart->setEnabled(node.getAttribute(QStringLiteral("t_autostart")) == QStringLiteral("Y"));
         }
     } else {
         if (m_actSetAutostart != nullptr) {
@@ -579,14 +616,14 @@ void SKGBookmarkPluginDockWidget::onPageChanged()
 {
     // Set current selection of dock
     QString id;
-    SKGTabPage* cPage = SKGMainPanel::getMainPanel()->currentPage();
+    SKGTabPage *cPage = SKGMainPanel::getMainPanel()->currentPage();
     if (cPage != nullptr) {
         id = cPage->getBookmarkID();
     }
     ui.kBookmarksList->selectObject(id % "-node");
 }
 
-void SKGBookmarkPluginDockWidget::resizeEvent(QResizeEvent* iEvent)
+void SKGBookmarkPluginDockWidget::resizeEvent(QResizeEvent *iEvent)
 {
     if (iEvent != nullptr) {
         QSize newSize = iEvent->size();
@@ -598,5 +635,3 @@ void SKGBookmarkPluginDockWidget::resizeEvent(QResizeEvent* iEvent)
 
     QWidget::resizeEvent(iEvent);
 }
-
-
