@@ -11,11 +11,7 @@
 #include "skgdebugpluginwidget.h"
 
 #include <qdom.h>
-#ifdef SKG_QT6
 #include <qjsengine.h>
-#else
-#include <qscriptengine.h>
-#endif
 
 #include "skgdocument.h"
 #include "skgmainpanel.h"
@@ -23,6 +19,13 @@
 #include "skgtraces.h"
 #include "skgtransactionmng.h"
 
+const auto EXECUTE = QStringLiteral("EXECUTE");
+const auto BENCHMARK = QStringLiteral("BENCHMARK");
+const auto EXECUTE_MULTI = QStringLiteral("EXECUTE_MULTI");
+const auto EXPLAIN = QStringLiteral("EXPLAIN");
+const auto EXPLAIN_PLAN = QStringLiteral("EXPLAIN_PLAN");
+const auto RUN_SCRIPT = QStringLiteral("RUN_SCRIPT");
+
 SKGDebugPluginWidget::SKGDebugPluginWidget(QWidget *iParent, SKGDocument *iDocument)
     : SKGTabPage(iParent, iDocument)
 {
@@ -39,11 +42,16 @@ SKGDebugPluginWidget::SKGDebugPluginWidget(QWidget *iParent, SKGDocument *iDocum
     ui.kRefreshViewsAndIndexes->setIcon(SKGServices::fromTheme(QStringLiteral("view-refresh")));
 
     // Fill combo box
-    ui.kExplainCmb->addItem(SKGServices::fromTheme(QStringLiteral("system-run")), i18nc("Execute an SQL query", "Execute"));
-    ui.kExplainCmb->addItem(SKGServices::fromTheme(QStringLiteral("system-run")), i18nc("Execute an SQL queries (one per line)", "Execute multi queries"));
-    ui.kExplainCmb->addItem(SKGServices::fromTheme(QStringLiteral("help-hint")), i18nc("Explain an SQL query", "Explain"));
-    ui.kExplainCmb->addItem(SKGServices::fromTheme(QStringLiteral("games-hint")), i18nc("Explain the SQL query plan", "Explain query plan"));
-    ui.kExplainCmb->addItem(SKGServices::fromTheme(QStringLiteral("media-playback-start")), i18nc("Execute script", "Execute script [%1]", "javascript"));
+    ui.kExplainCmb->addItem(SKGServices::fromTheme(QStringLiteral("system-run")), i18nc("Execute an SQL query", "Execute"), EXECUTE);
+    ui.kExplainCmb->addItem(SKGServices::fromTheme(QStringLiteral("system-run")), i18nc("Execute an SQL query (Benchmark)", "Execute benchmark"), BENCHMARK);
+    ui.kExplainCmb->addItem(SKGServices::fromTheme(QStringLiteral("system-run")),
+                            i18nc("Execute an SQL queries (one per line)", "Execute multi queries"),
+                            EXECUTE_MULTI);
+    ui.kExplainCmb->addItem(SKGServices::fromTheme(QStringLiteral("help-hint")), i18nc("Explain an SQL query", "Explain"), EXPLAIN);
+    ui.kExplainCmb->addItem(SKGServices::fromTheme(QStringLiteral("games-hint")), i18nc("Explain the SQL query plan", "Explain query plan"), EXPLAIN_PLAN);
+    ui.kExplainCmb->addItem(SKGServices::fromTheme(QStringLiteral("media-playback-start")),
+                            i18nc("Execute script", "Execute script [%1]", "javascript"),
+                            RUN_SCRIPT);
     ui.kInput->setVisible(false);
 
     // Set level trace
@@ -73,7 +81,7 @@ SKGDebugPluginWidget::SKGDebugPluginWidget(QWidget *iParent, SKGDocument *iDocum
         ui.kSQLInput->addItem("PRAGMA index_info(" % tables.at(i) % ");");
     }
     connect(ui.kTraceLevel, &QSlider::valueChanged, this, &SKGDebugPluginWidget::onTraceLevelModified);
-    connect(ui.kEnableProfilingChk, &QCheckBox::stateChanged, this, &SKGDebugPluginWidget::onProfilingModeChanged);
+    connect(ui.kEnableProfilingChk, &QCheckBox::checkStateChanged, this, &SKGDebugPluginWidget::onProfilingModeChanged);
     connect(ui.kExplainCmb, static_cast<void (SKGComboBox::*)(int)>(&SKGComboBox::currentIndexChanged), this, &SKGDebugPluginWidget::onModeChanged);
     connect(ui.kSQLPushButton, &QPushButton::clicked, this, &SKGDebugPluginWidget::onExecuteSqlOrder);
     connect(ui.kSQLTransactionPushButton, &QPushButton::clicked, this, &SKGDebugPluginWidget::onExecuteSqlOrderInTransaction);
@@ -159,15 +167,11 @@ void SKGDebugPluginWidget::onExecuteSqlOrder(bool iInTransaction)
 {
     SKGTRACEINFUNC(10)
     SKGError err;
-    int exp = ui.kExplainCmb->currentIndex();
-    if (exp == 4) {
+    auto exp = ui.kExplainCmb->currentData().toString();
+    if (exp == RUN_SCRIPT) {
         // Script execution
         ui.kSQLResult->clear();
-#ifdef SKG_QT6
         QJSEngine myEngine;
-#else
-        QScriptEngine myEngine;
-#endif
         // skgresult.setText(skgdocument.getUniqueIdentifier())
         // skgerror=skgdocument.sendMessage(QStringLiteral("Hello"))
         // skgerror=skgdocument.sendMessage(QStringLiteral("Hello"))
@@ -180,7 +184,7 @@ void SKGDebugPluginWidget::onExecuteSqlOrder(bool iInTransaction)
 
         // Finally execute the scripting code.
         myEngine.evaluate(ui.kInput->toPlainText());
-    } else if (exp == 1) {
+    } else if (exp == EXECUTE_MULTI) {
         // SQL multi lines
         auto sqls = ui.kInput->toPlainText().split('\n');
         QString oResultGlobal;
@@ -201,24 +205,37 @@ void SKGDebugPluginWidget::onExecuteSqlOrder(bool iInTransaction)
     } else {
         // SQL execution
         QString text = ui.kSQLInput->currentText();
-        if (exp == 2) {
+        if (exp == EXPLAIN) {
             text = "EXPLAIN " % text;
-        } else if (exp == 3) {
+        } else if (exp == EXPLAIN_PLAN) {
             text = "EXPLAIN QUERY PLAN " % text;
         }
         QString oResult;
         double time = SKGServices::getMicroTime();
-        if (iInTransaction) {
-            SKGBEGINTRANSACTION(*getDocument(), i18nc("Display an SQL command from the debug plugin", "SQL command from debug plugin"), err)
-            IFOKDO(err, getDocument()->dumpSelectSqliteOrder(text, oResult))
-        } else {
-            QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-            err = getDocument()->dumpSelectSqliteOrder(text, oResult);
-            QApplication::restoreOverrideCursor();
+        int max_nb = exp == BENCHMARK ? 1000 : 1; // If benchmark, execute 10 times
+        int max_time = 10000; // 10 seconds max
+        int nb_run = 0;
+        for (int i = 0; i < max_nb; ++i) {
+            if (iInTransaction) {
+                SKGBEGINTRANSACTION(*getDocument(), i18nc("Display an SQL command from the debug plugin", "SQL command from debug plugin"), err)
+                IFOKDO(err, getDocument()->dumpSelectSqliteOrder(text, oResult))
+            } else {
+                QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+                err = getDocument()->dumpSelectSqliteOrder(text, oResult);
+                QApplication::restoreOverrideCursor();
+            }
+            nb_run++;
+            if (SKGServices::getMicroTime() - time > max_time) {
+                break; // Stop if we reach the max time
+            }
         }
-        time = SKGServices::getMicroTime() - time;
+        time = (SKGServices::getMicroTime() - time) / nb_run;
 
-        oResult += i18nc("Display the execution time needed by an SQL query", "\nExecution time: %1 ms", SKGServices::doubleToString(time));
+        oResult +=
+            i18nc("Display the execution time needed by an SQL query",
+                  "\nExecution time: %1 ms %2",
+                  SKGServices::doubleToString(time),
+                  nb_run > 1 ? "(" % i18nc("Display the average execution time of an SQL query", "Average for %1 runs", nb_run) % ")" : QStringLiteral(""));
 
         IFOK(err)
         {
@@ -240,8 +257,8 @@ void SKGDebugPluginWidget::onTraceLevelModified()
 void SKGDebugPluginWidget::onModeChanged()
 {
     SKGTRACEINFUNC(10)
-    int exp = ui.kExplainCmb->currentIndex();
-    ui.kInput->setVisible(exp == 4 || exp == 1);
+    auto exp = ui.kExplainCmb->currentData().toString();
+    ui.kInput->setVisible(exp == RUN_SCRIPT || exp == EXECUTE_MULTI);
     ui.kSQLInput->setVisible(!ui.kInput->isVisible());
 }
 
