@@ -10,13 +10,8 @@
  *
  * @author Stephane MANKOWSKI
  */
-#include <qobject.h>
-#ifdef SKG_QT6
 #include <KTextTemplate/Filter>
-#else
-#include <grantlee/filter.h>
-#define KTextTemplate Grantlee
-#endif
+#include <qobject.h>
 
 /**
  * The grantlee's filter to get items of a document table
