@@ -17,7 +17,6 @@
 #include <kactioncollection.h>
 #include <kpluginfactory.h>
 #include <kstandardaction.h>
-#include <ktoolbarpopupaction.h>
 
 #include "skgmainpanel.h"
 #include "skgpropertiesplugindockwidget.h"
@@ -116,9 +115,9 @@ bool SKGPropertiesPlugin::setupActions(SKGDocument *iDocument)
     }
 
     // Menu
-    auto actAddProperty =
-        new KToolBarPopupAction(SKGServices::fromTheme(icon()), i18nc("Allows user to add a user defined property on an object", "Add property"), this);
-    m_addPropertyMenu = actAddProperty->popupMenu();
+    auto actAddProperty = new QAction(SKGServices::fromTheme(icon()), i18nc("Allows user to add a user defined property on an object", "Add property"), this);
+    m_addPropertyMenu = new QMenu();
+    actAddProperty->setMenu(m_addPropertyMenu);
     connect(m_addPropertyMenu, &QMenu::aboutToShow, this, &SKGPropertiesPlugin::onShowAddPropertyMenu);
     registerGlobalAction(QStringLiteral("add_property"),
                          actAddProperty,
