@@ -83,11 +83,7 @@ SKGError SKGImportPluginAFB120::importFile()
                 {
                     QTextStream stream(&file);
                     if (!m_importer->getCodec().isEmpty()) {
-#ifdef SKG_QT6
                         stream.setEncoding(QStringConverter::encodingForName(m_importer->getCodec().toLatin1().constData()).value_or(QStringConverter::Utf8));
-#else
-                        stream.setCodec(m_importer->getCodec().toLatin1().constData());
-#endif
                     }
                     while (!stream.atEnd()) {
                         // Read line
