@@ -95,26 +95,28 @@ struct download {
     QString operator()(const QString &iAccountId)
     {
         QString file = m_path % "/" % iAccountId % ".csv";
-        // Build cmd
-        QString cmd = m_cmd;
-        cmd = cmd.replace(QStringLiteral("%2"), SKGServices::intToString(m_nbToDownload))
-                  .replace(QStringLiteral("%1"), iAccountId)
-                  .replace(QStringLiteral("%3"), m_pwd)
-                  .replace(QStringLiteral("%4"), m_date);
-
-        // Execute
-        QProcess p;
-        if (cmd.contains(QStringLiteral("%4"))) {
-            cmd = cmd.replace(QStringLiteral("%4"), file);
-            p.setProcessChannelMode(QProcess::ForwardedChannels);
-        } else {
-            p.setStandardOutputFile(file);
-        }
-        cmd = SKGServices::getFullPathCommandLine(cmd);
-        SKGTRACEL(1) << "Execute: " << cmd << Qt::endl;
-
         int retry = 0;
+        int nb_retry = 5;
+        QString cmd;
+        QProcess p;
         do {
+            // Build cmd
+            cmd = m_cmd;
+            cmd = cmd.replace(QStringLiteral("%2"), SKGServices::intToString(retry == nb_retry ? 1000 : m_nbToDownload * (nb_retry - retry) / nb_retry))
+                      .replace(QStringLiteral("%1"), iAccountId)
+                      .replace(QStringLiteral("%3"), m_pwd)
+                      .replace(QStringLiteral("%4"), m_date);
+
+            // Execute
+            if (cmd.contains(QStringLiteral("%4"))) {
+                cmd = cmd.replace(QStringLiteral("%4"), file);
+                p.setProcessChannelMode(QProcess::ForwardedChannels);
+            } else {
+                p.setStandardOutputFile(file);
+            }
+            cmd = SKGServices::getFullPathCommandLine(cmd);
+            SKGTRACEL(1) << "Execute: " << cmd << Qt::endl;
+
             p.start(QStringLiteral("/bin/bash"), QStringList() << QStringLiteral("-c") << cmd);
             if (p.waitForFinished(1000 * 60 * 2)) {
                 if (p.exitCode() == 0) {
@@ -128,7 +130,7 @@ struct download {
                 p.kill();
             }
             ++retry;
-        } while (retry < 6);
+        } while (retry <= nb_retry);
 
         QString errorMsg = i18nc("Error message", "The following command line failed with code %2:\n'%1'", cmd, p.exitCode());
         SKGTRACE << errorMsg << Qt::endl;
