@@ -62,7 +62,6 @@ SKGError SKGImportPluginGsb::importFile()
         int errorLine = 0;
         int errorCol = 0;
         bool contentOK = false;
-#ifdef SKG_QT6
         const auto &content = QString::fromUtf8(file.readAll());
         const auto &result = doc.setContent(content);
 
@@ -70,9 +69,6 @@ SKGError SKGImportPluginGsb::importFile()
         errorLine = result.errorLine;
         errorCol = result.errorColumn;
         errorMsg = result.errorMessage;
-#else
-        contentOK = doc.setContent(file.readAll(), &errorMsg, &errorLine, &errorCol);
-#endif
         file.close();
 
         // Get root
@@ -215,7 +211,7 @@ SKGError SKGImportPluginGsb::importFile()
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(4))
 
-            // Step 5-Get payement mode
+            // Step 5-Get payment mode
             IFOK(err)
             {
                 QDomNodeList paymentList = docElem.elementsByTagName(QStringLiteral("Payment"));
