@@ -1703,7 +1703,7 @@ SKGError SKGImportPluginKmy::exportOperation(const SKGOperationObject &iOperatio
         split.setAttribute(QStringLiteral("reconcileflag"), reconcileflag);
         split.setAttribute(QStringLiteral("memo"), iOperation.getComment());
         QString originalAmount = iOperation.getProperty(QStringLiteral("SKG_OP_ORIGINAL_AMOUNT"));
-        if (!originalAmount.isEmpty()) {
+        if (!originalAmount.isEmpty() && val2 != 0) {
             val2 = qAbs(SKGServices::stringToDouble(originalAmount)) * (val2 / qAbs(val2));
         }
         split.setAttribute(QStringLiteral("value"), SKGImportPluginKmy::kmyValue(val2));
@@ -1790,7 +1790,9 @@ double SKGImportPluginKmy::toKmyValue(const QString &iString)
     if (vals.count() == 1) {
         output = SKGServices::stringToDouble(vals.at(0));
     } else if (vals.count() == 2) {
-        output = SKGServices::stringToDouble(vals.at(0)) / SKGServices::stringToDouble(vals.at(1));
+        const auto div = SKGServices::stringToDouble(vals.at(1));
+        if (div != 0)
+            output = SKGServices::stringToDouble(vals.at(0)) / div;
     }
     return output;
 }
