@@ -303,11 +303,14 @@ SKGError SKGImportPluginLedger::importFile()
                         auto symbol2 = commodity2.firstChildElement(QStringLiteral("symbol")).toElement();
                         auto date = annotation.firstChildElement(QStringLiteral("date")).toElement().text().trimmed();
                         if (!date.isNull() && !symbol2.isNull() && !quantity.isNull()) {
-                            SKGUnitValueObject unitValueObj;
-                            IFOKDO(err, unitObj.addUnitValue(unitValueObj))
-                            IFOKDO(err, unitValueObj.setDate(QDate::fromString(date, QStringLiteral("yyyy/MM/dd"))))
-                            IFOKDO(err, unitValueObj.setQuantity(1.0 / SKGServices::stringToDouble(quantity)))
-                            IFOKDO(err, unitValueObj.save())
+                            const auto div = SKGServices::stringToDouble(quantity);
+                            if (div != 0) {
+                                SKGUnitValueObject unitValueObj;
+                                IFOKDO(err, unitObj.addUnitValue(unitValueObj))
+                                IFOKDO(err, unitValueObj.setDate(QDate::fromString(date, QStringLiteral("yyyy/MM/dd"))))
+                                IFOKDO(err, unitValueObj.setQuantity(1.0 / div))
+                                IFOKDO(err, unitValueObj.save())
+                            }
                         }
 
                         mapIdUnit[symbol] = unitObj;
