@@ -32,7 +32,7 @@ QMap<QString, SKGAccountObject> SKGImportPluginOfx::m_accounts;
  */
 K_PLUGIN_CLASS_WITH_JSON(SKGImportPluginOfx, "metadata.json")
 
-SKGImportPluginOfx::SKGImportPluginOfx(QObject* iImporter, const QVariantList& iArg)
+SKGImportPluginOfx::SKGImportPluginOfx(QObject *iImporter, const QVariantList &iArg)
     : SKGImportPlugin(iImporter)
 {
     SKGTRACEINFUNC(10)
@@ -40,13 +40,14 @@ SKGImportPluginOfx::SKGImportPluginOfx(QObject* iImporter, const QVariantList& i
     SKGImportPluginOfx::m_accounts.clear();
 }
 
-SKGImportPluginOfx::~SKGImportPluginOfx()
-    = default;
+SKGImportPluginOfx::~SKGImportPluginOfx() = default;
 
 bool SKGImportPluginOfx::isImportPossible()
 {
     SKGTRACEINFUNC(10)
-    return (m_importer->getDocument() == nullptr ? true : m_importer->getFileNameExtension() == QLatin1String("OFX") || m_importer->getFileNameExtension() == QLatin1String("QFX"));
+    return (m_importer->getDocument() == nullptr
+                ? true
+                : m_importer->getFileNameExtension() == QStringLiteral("OFX") || m_importer->getFileNameExtension() == QStringLiteral("QFX"));
 }
 
 SKGError SKGImportPluginOfx::importFile()
@@ -59,10 +60,11 @@ SKGError SKGImportPluginOfx::importFile()
     SKGTRACEINFUNCRC(2, err)
 
     if (!QFile(m_importer->getLocalFileName()).exists()) {
-        err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().toDisplayString()));
+        err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message", "Open file '%1' failed", m_importer->getFileName().toDisplayString()));
     }
-    IFOKDO(err, m_importer->getDocument()->beginTransaction(QLatin1String("#INTERNAL#") % i18nc("Import step", "Import OFX file")))
-    IFOK(err) {
+    IFOKDO(err, m_importer->getDocument()->beginTransaction(QStringLiteral("#INTERNAL#") % i18nc("Import step", "Import OFX file")))
+    IFOK(err)
+    {
         SKGImportPluginOfx::m_ofxError = SKGError();
         SKGImportPluginOfx::m_ofxInitialBalanceName.clear();
         SKGImportPluginOfx::m_ofxInitialBalanceAmount.clear();
@@ -79,13 +81,17 @@ SKGError SKGImportPluginOfx::importFile()
             ofx_set_transaction_cb(ctx, SKGImportPluginOfx::ofxTransactionCallback, m_importer);
             // ofx_set_security_cb(ctx, ofxSecurityCallback, this);
             libofx_proc_file(ctx, m_importer->getLocalFileName().toUtf8().data(), AUTODETECT);
-            IFOKDO(err, SKGImportPluginOfx::m_ofxError) {
+            IFOKDO(err, SKGImportPluginOfx::m_ofxError)
+            {
                 // This is an option ==> no error management
                 SKGError err2;
                 int nb = SKGImportPluginOfx::m_ofxInitialBalanceName.count();
                 for (int i = 0; !err2 && i < nb; ++i) {
                     SKGAccountObject act;
-                    err2 = m_importer->getDocument()->getObject(QLatin1String("v_account"), QLatin1String("t_number='") % SKGServices::stringToSqlString(m_ofxInitialBalanceName.at(i)) % QLatin1Char('\''), act);
+                    err2 = m_importer->getDocument()->getObject(QStringLiteral("v_account"),
+                                                                QStringLiteral("t_number='") % SKGServices::stringToSqlString(m_ofxInitialBalanceName.at(i))
+                                                                    % u'\'',
+                                                                act);
 
                     // Date of balance
                     auto date = m_ofxInitialBalanceDate.at(i);
@@ -107,12 +113,13 @@ SKGError SKGImportPluginOfx::importFile()
                         err2 = act.save();
                     }
                     if (!err2) {
-                        err2 = m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has been set", act.getName()));
+                        err2 =
+                            m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has been set", act.getName()));
                     }
                 }
             }
             libofx_free_context(ctx);
-        } catch (...) {  // NOLINT(whitespace/parens)
+        } catch (...) { // NOLINT(whitespace/parens)
             err = SKGError(ERR_HANDLE, i18nc("Error message", "OFX import failed"));
         }
 
@@ -120,12 +127,12 @@ SKGError SKGImportPluginOfx::importFile()
         SKGImportPluginOfx::m_ofxInitialBalanceAmount.clear();
         SKGImportPluginOfx::m_ofxInitialBalanceDate.clear();
 
-        SKGENDTRANSACTION(m_importer->getDocument(),  err)
+        SKGENDTRANSACTION(m_importer->getDocument(), err)
     }
     return err;
 }
 
-QString SKGImportPluginOfx::getAccountName(OfxAccountData* iAccountData)
+QString SKGImportPluginOfx::getAccountName(OfxAccountData *iAccountData)
 {
     SKGTRACEINFUNC(3)
     QString accountNumber;
@@ -139,9 +146,9 @@ QString SKGImportPluginOfx::getAccountName(OfxAccountData* iAccountData)
             accountNumber = QString::fromUtf8(iAccountData->account_number);
         }
         // Correction BUG 234771 ^^^^^
-        if (accountNumber.startsWith(bankNumber % QLatin1Char(' '))) {
+        if (accountNumber.startsWith(bankNumber % u' ')) {
             accountNumber = accountNumber.right(accountNumber.length() - bankNumber.length() - 1);
-            QStringList splitNumbers = accountNumber.split(QLatin1Char(' '));
+            QStringList splitNumbers = accountNumber.split(u' ');
             if (splitNumbers.count() == 2) {
                 accountNumber = splitNumbers.at(1);
             }
@@ -151,7 +158,7 @@ QString SKGImportPluginOfx::getAccountName(OfxAccountData* iAccountData)
     return accountNumber;
 }
 
-SKGError SKGImportPluginOfx::getAccount(OfxAccountData* iAccountData, SKGDocumentBank* iDoc, SKGAccountObject& oAccount)
+SKGError SKGImportPluginOfx::getAccount(OfxAccountData *iAccountData, SKGDocumentBank *iDoc, SKGAccountObject &oAccount)
 {
     SKGError err;
     SKGTRACEINFUNCRC(3, err)
@@ -163,32 +170,34 @@ SKGError SKGImportPluginOfx::getAccount(OfxAccountData* iAccountData, SKGDocumen
             oAccount = m_accounts[name];
         } else {
             SKGTRACEL(3) << "NOT found in index" << Qt::endl;
-            QString wc = QLatin1String("t_number='") % SKGServices::stringToSqlString(name) % QLatin1String("' OR EXISTS(SELECT 1 FROM parameters WHERE t_uuid_parent=v_account.id||'-account' AND t_name='alias' AND t_value= '") % SKGServices::stringToSqlString(name) % QLatin1String("')");
-            err = iDoc->getObject(QLatin1String("v_account"), wc, oAccount);
+            QString wc = QStringLiteral("t_number='") % SKGServices::stringToSqlString(name)
+                % QStringLiteral("' OR EXISTS(SELECT 1 FROM parameters WHERE t_uuid_parent=v_account.id||'-account' AND t_name='alias' AND t_value= '")
+                % SKGServices::stringToSqlString(name) % QStringLiteral("')");
+            err = iDoc->getObject(QStringLiteral("v_account"), wc, oAccount);
         }
     }
 
     return err;
 }
 
-int SKGImportPluginOfx::ofxStatementCallback(struct OfxStatementData data, void* pv)  // clazy:exclude=function-args-by-ref
+int SKGImportPluginOfx::ofxStatementCallback(struct OfxStatementData data, void *pv) // clazy:exclude=function-args-by-ref
 {
     if (SKGImportPluginOfx::m_ofxError) {
         return 0;
     }
     SKGTRACEINFUNCRC(5, SKGImportPluginOfx::m_ofxError)
 
-    auto* impotExporter = static_cast<SKGImportExportManager*>(pv);
+    auto *impotExporter = static_cast<SKGImportExportManager *>(pv);
     if (impotExporter == nullptr) {
         return 0;
     }
-    SKGDocumentBank* doc = impotExporter->getDocument();
+    SKGDocumentBank *doc = impotExporter->getDocument();
     if (doc == nullptr) {
         return 0;
     }
 
     // // Get data
-    OfxAccountData* accountData = data.account_ptr;
+    OfxAccountData *accountData = data.account_ptr;
     if ((accountData != nullptr) && static_cast<bool>(data.ledger_balance_valid)) {
         // Get account
         SKGAccountObject act;
@@ -196,7 +205,10 @@ int SKGImportPluginOfx::ofxStatementCallback(struct OfxStatementData data, void*
         if (!SKGImportPluginOfx::m_ofxError) {
             impotExporter->addAccountToCheck(act, data.ledger_balance);
             if (act.getNbOperation() > 1) {
-                SKGImportPluginOfx::m_ofxError = doc->sendMessage(i18nc("An information message", "The initial balance of '%1' has not been set because some transactions are already existing", act.getName()));
+                SKGImportPluginOfx::m_ofxError =
+                    doc->sendMessage(i18nc("An information message",
+                                           "The initial balance of '%1' has not been set because some transactions are already existing",
+                                           act.getName()));
             } else {
                 auto d = QDate::currentDate();
                 if (static_cast<bool>(data.ledger_balance_date_valid)) {
@@ -214,18 +226,18 @@ int SKGImportPluginOfx::ofxStatementCallback(struct OfxStatementData data, void*
     return SKGImportPluginOfx::m_ofxError.getReturnCode();
 }
 
-int SKGImportPluginOfx::ofxAccountCallback(struct OfxAccountData data, void* pv)
+int SKGImportPluginOfx::ofxAccountCallback(struct OfxAccountData data, void *pv)
 {
     if (SKGImportPluginOfx::m_ofxError) {
         return 0;
     }
     SKGTRACEINFUNCRC(5, SKGImportPluginOfx::m_ofxError)
 
-    auto* impotExporter = static_cast<SKGImportExportManager*>(pv);
+    auto *impotExporter = static_cast<SKGImportExportManager *>(pv);
     if (impotExporter == nullptr) {
         return 0;
     }
-    SKGDocumentBank* doc = impotExporter->getDocument();
+    SKGDocumentBank *doc = impotExporter->getDocument();
     if (doc == nullptr) {
         return 0;
     }
@@ -241,9 +253,9 @@ int SKGImportPluginOfx::ofxAccountCallback(struct OfxAccountData data, void* pv)
     if (accountNumber.isEmpty()) {
         accountNumber = QString::fromUtf8(data.account_number);
     }
-    if (accountNumber.startsWith(bankNumber % QLatin1Char(' '))) {
+    if (accountNumber.startsWith(bankNumber % u' ')) {
         accountNumber = accountNumber.right(accountNumber.length() - bankNumber.length() - 1);
-        QStringList splitNumbers = accountNumber.split(QLatin1Char(' '));
+        QStringList splitNumbers = accountNumber.split(u' ');
         if (splitNumbers.count() == 2) {
             agencyNumber = splitNumbers.at(0);
             accountNumber = splitNumbers.at(1);
@@ -266,7 +278,8 @@ int SKGImportPluginOfx::ofxAccountCallback(struct OfxAccountData data, void* pv)
 
         // Check if bank is already existing
         SKGBankObject bank;
-        SKGImportPluginOfx::m_ofxError = doc->getObject(QLatin1String("v_bank"), QLatin1String("t_bank_number='") % SKGServices::stringToSqlString(bankId) % QLatin1Char('\''), tmp);
+        SKGImportPluginOfx::m_ofxError =
+            doc->getObject(QStringLiteral("v_bank"), QStringLiteral("t_bank_number='") % SKGServices::stringToSqlString(bankId) % u'\'', tmp);
         if (!SKGImportPluginOfx::m_ofxError) {
             // Already existing
             bank = tmp;
@@ -287,7 +300,7 @@ int SKGImportPluginOfx::ofxAccountCallback(struct OfxAccountData data, void* pv)
         if (name.isEmpty()) {
             name = QString::fromUtf8(data.account_id);
         } else {
-            name = name.remove(QLatin1String("Bank account "));
+            name = name.remove(QStringLiteral("Bank account "));
         }
         if (name.isEmpty()) {
             name = QString::fromUtf8(data.account_id);
@@ -348,7 +361,11 @@ int SKGImportPluginOfx::ofxAccountCallback(struct OfxAccountData data, void* pv)
     if (static_cast<bool>(data.currency_valid)) {
         // Check if unit is already existing
         SKGUnitObject unit(doc);
-        SKGImportPluginOfx::m_ofxError = doc->getObject(QLatin1String("v_unit"), QLatin1String("t_name='") % SKGServices::stringToSqlString(QString::fromUtf8(data.currency)) % QLatin1String("' OR t_name like '%(") % SKGServices::stringToSqlString(QString::fromUtf8(data.currency)) % QLatin1String(")%'"), tmp);
+        SKGImportPluginOfx::m_ofxError = doc->getObject(QStringLiteral("v_unit"),
+                                                        QStringLiteral("t_name='") % SKGServices::stringToSqlString(QString::fromUtf8(data.currency))
+                                                            % QStringLiteral("' OR t_name like '%(")
+                                                            % SKGServices::stringToSqlString(QString::fromUtf8(data.currency)) % QStringLiteral(")%'"),
+                                                        tmp);
         if (!SKGImportPluginOfx::m_ofxError) {
             // Already existing
             unit = tmp;
@@ -371,18 +388,18 @@ int SKGImportPluginOfx::ofxAccountCallback(struct OfxAccountData data, void* pv)
     return SKGImportPluginOfx::m_ofxError.getReturnCode();
 }
 
-int SKGImportPluginOfx::ofxTransactionCallback(struct OfxTransactionData data, void* pv)  // clazy:exclude=function-args-by-ref
+int SKGImportPluginOfx::ofxTransactionCallback(struct OfxTransactionData data, void *pv) // clazy:exclude=function-args-by-ref
 {
     if (SKGImportPluginOfx::m_ofxError) {
         return 0;
     }
     SKGTRACEINFUNCRC(5, SKGImportPluginOfx::m_ofxError)
 
-    auto* impotExporter = static_cast<SKGImportExportManager*>(pv);
+    auto *impotExporter = static_cast<SKGImportExportManager *>(pv);
     if (impotExporter == nullptr) {
         return 0;
     }
-    SKGDocumentBank* doc = impotExporter->getDocument();
+    SKGDocumentBank *doc = impotExporter->getDocument();
     if (doc == nullptr) {
         return 0;
     }
@@ -403,18 +420,19 @@ int SKGImportPluginOfx::ofxTransactionCallback(struct OfxTransactionData data, v
         // Create id
         QString ID;
         if (static_cast<bool>(data.fi_id_valid)) {
-            if (QString::fromUtf8(data.fi_id).count(QLatin1Char('0')) != QString::fromUtf8(data.fi_id).size()) {
-                ID = QLatin1String("ID-") % QString::fromUtf8(data.fi_id);
+            if (QString::fromUtf8(data.fi_id).count(u'0') != QString::fromUtf8(data.fi_id).size()) {
+                ID = QStringLiteral("ID-") % QString::fromUtf8(data.fi_id);
             }
         } else if (static_cast<bool>(data.reference_number_valid)) {
-            if (QString::fromUtf8(data.reference_number).count(QLatin1Char('0')) != QString::fromUtf8(data.reference_number).size()) {
-                ID = QLatin1String("REF-") % QString::fromUtf8(data.reference_number);
+            if (QString::fromUtf8(data.reference_number).count(u'0') != QString::fromUtf8(data.reference_number).size()) {
+                ID = QStringLiteral("REF-") % QString::fromUtf8(data.reference_number);
             }
         }
 
         if (ID.isEmpty()) {
-            QByteArray hash = QCryptographicHash::hash(QString(SKGServices::dateToSqlString(date) % SKGServices::doubleToString(data.amount)).toUtf8(), QCryptographicHash::Md5);
-            ID = QLatin1String("ID-") % QString::fromLatin1(hash.toHex());
+            QByteArray hash = QCryptographicHash::hash(QString(SKGServices::dateToSqlString(date) % SKGServices::doubleToString(data.amount)).toUtf8(),
+                                                       QCryptographicHash::Md5);
+            ID = QStringLiteral("ID-") % QString::fromLatin1(hash.toHex());
         }
 
         // Create operation
@@ -429,7 +447,7 @@ int SKGImportPluginOfx::ofxTransactionCallback(struct OfxTransactionData data, v
             SKGImportPluginOfx::m_ofxError = ope.setUnit(unit);
         }
         if (!SKGImportPluginOfx::m_ofxError) {
-            SKGImportPluginOfx::m_ofxError = ope.setAttribute(QLatin1String("t_imported"), QLatin1String("T"));
+            SKGImportPluginOfx::m_ofxError = ope.setAttribute(QStringLiteral("t_imported"), QStringLiteral("T"));
         }
         if (!SKGImportPluginOfx::m_ofxError) {
             SKGImportPluginOfx::m_ofxError = ope.setImportID(ID);
@@ -506,9 +524,10 @@ int SKGImportPluginOfx::ofxTransactionCallback(struct OfxTransactionData data, v
             SKGImportPluginOfx::m_ofxError = ope.addSubOperation(subop);
         }
         if (!SKGImportPluginOfx::m_ofxError && static_cast<bool>(data.amount_valid)) {
-            bool mustFlipSign = (data.transactiontype == OFX_DEBIT || data.transactiontype == OFX_FEE || data.transactiontype == OFX_SRVCHG ||
-                                 data.transactiontype == OFX_PAYMENT || data.transactiontype == OFX_CASH || data.transactiontype == OFX_DIRECTDEBIT ||
-                                 data.transactiontype == OFX_REPEATPMT) && data.amount > 0;  // OFX spec version 2.1.1, section 3.2.9.2
+            bool mustFlipSign = (data.transactiontype == OFX_DEBIT || data.transactiontype == OFX_FEE || data.transactiontype == OFX_SRVCHG
+                                 || data.transactiontype == OFX_PAYMENT || data.transactiontype == OFX_CASH || data.transactiontype == OFX_DIRECTDEBIT
+                                 || data.transactiontype == OFX_REPEATPMT)
+                && data.amount > 0; // OFX spec version 2.1.1, section 3.2.9.2
             double sign = mustFlipSign ? -1.0 : 1.0;
             double commission = static_cast<bool>(data.commission_valid) ? data.commission : 0;
             SKGImportPluginOfx::m_ofxError = subop.setQuantity(sign * (data.amount + commission));
@@ -528,7 +547,8 @@ int SKGImportPluginOfx::ofxTransactionCallback(struct OfxTransactionData data, v
                 SKGImportPluginOfx::m_ofxError = ope.addSubOperation(subop2);
             }
             if (!SKGImportPluginOfx::m_ofxError) {
-                SKGImportPluginOfx::m_ofxError = subop2.setComment(i18nc("Noun, a quantity of money taken by a financial institution to perform an operation", "Commission"));
+                SKGImportPluginOfx::m_ofxError =
+                    subop2.setComment(i18nc("Noun, a quantity of money taken by a financial institution to perform an operation", "Commission"));
             }
             if (!SKGImportPluginOfx::m_ofxError) {
                 SKGImportPluginOfx::m_ofxError = subop2.setQuantity(-data.commission);
@@ -543,7 +563,7 @@ int SKGImportPluginOfx::ofxTransactionCallback(struct OfxTransactionData data, v
 
 QString SKGImportPluginOfx::getMimeTypeFilter() const
 {
-    return QLatin1String("*.ofx *.qfx|") % i18nc("A file format", "OFX file");
+    return QStringLiteral("*.ofx *.qfx|") % i18nc("A file format", "OFX file");
 }
 
 #include <skgimportpluginofx.moc>
