@@ -100,6 +100,8 @@ SKGError SKGImportPluginQif::importFile()
                     }
 
                     if (QString::compare(line, QStringLiteral("!account"), Qt::CaseInsensitive) == 0
+                        || QString::compare(line, QStringLiteral("!type:payee"), Qt::CaseInsensitive) == 0
+                        || QString::compare(line, QStringLiteral("!type:budget"), Qt::CaseInsensitive) == 0
                         || QString::compare(line, QStringLiteral("!type:cat"), Qt::CaseInsensitive) == 0
                         || QString::compare(line, QStringLiteral("!type:tag"), Qt::CaseInsensitive) == 0
                         || QString::compare(line, QStringLiteral("!type:class"), Qt::CaseInsensitive) == 0) {
@@ -182,6 +184,8 @@ SKGError SKGImportPluginQif::importFile()
 
                     // Manage !Account section
                     if (QString::compare(line, QStringLiteral("!type:bank"), Qt::CaseInsensitive) == 0
+                        || QString::compare(line, QStringLiteral("!type:payee"), Qt::CaseInsensitive) == 0
+                        || QString::compare(line, QStringLiteral("!type:budget"), Qt::CaseInsensitive) == 0
                         || QString::compare(line, QStringLiteral("!type:cash"), Qt::CaseInsensitive) == 0
                         || QString::compare(line, QStringLiteral("!type:ccard"), Qt::CaseInsensitive) == 0
                         || QString::compare(line, QStringLiteral("!type:oth a"), Qt::CaseInsensitive) == 0
