@@ -367,7 +367,7 @@ void SKGAccountBoardWidget::dataModified(const QString &iTableName, int iIdTrans
                                     SKGServices::SKGUnitInfo u2 = primary;
                                     u2.Symbol = unitAccountSymbol;
                                     u2.NbDecimal = unitAccount.getNumberDecimal();
-                                    html += doc->formatMoney(v1 / unitAccountValue, u2);
+                                    html += unitAccountValue != 0 ? QStringLiteral("\x221E") : doc->formatMoney(v1 / unitAccountValue, u2);
                                     html += '=';
                                 }
                                 html += doc->formatMoney(v1, primary);
