@@ -25,8 +25,9 @@
 #include "skgtransactionmng.h"
 #include "skgunitobject.h"
 
-SKGCalculatorPluginWidget::SKGCalculatorPluginWidget(QWidget* iParent, SKGDocumentBank* iDocument)
-    : SKGTabPage(iParent, iDocument), m_objectModel(nullptr)
+SKGCalculatorPluginWidget::SKGCalculatorPluginWidget(QWidget *iParent, SKGDocumentBank *iDocument)
+    : SKGTabPage(iParent, iDocument)
+    , m_objectModel(nullptr)
 {
     SKGTRACEINFUNC(1)
     if (iDocument == nullptr) {
@@ -38,44 +39,47 @@ SKGCalculatorPluginWidget::SKGCalculatorPluginWidget(QWidget* iParent, SKGDocume
 
     ui.setupUi(this);
     ui.kUnitEdit->setDocument(iDocument);
-    ui.kUnitEdit->setWhereClauseCondition(QLatin1String("t_type IN ('1','2','C')"));
+    ui.kUnitEdit->setWhereClauseCondition(QStringLiteral("t_type IN ('1','2','C')"));
 
-    ui.kUpdate->setIcon(SKGServices::fromTheme(QLatin1String("dialog-ok")));
-    ui.kAdd->setIcon(SKGServices::fromTheme(QLatin1String("list-add")));
+    ui.kUpdate->setIcon(SKGServices::fromTheme(QStringLiteral("dialog-ok")));
+    ui.kAdd->setIcon(SKGServices::fromTheme(QStringLiteral("list-add")));
 
-    ui.kLoadSummaryTitle->setIcon(SKGServices::fromTheme(QLatin1String("configure")), KTitleWidget::ImageLeft);
-    ui.kPaymentSummaryTitle->setIcon(SKGServices::fromTheme(QLatin1String("bookmarks")), KTitleWidget::ImageLeft);
-    ui.kAmortizationTableTitle->setIcon(SKGServices::fromTheme(QLatin1String("view-pim-calendar")), KTitleWidget::ImageLeft);
+    ui.kLoadSummaryTitle->setIcon(SKGServices::fromTheme(QStringLiteral("configure")), KTitleWidget::ImageLeft);
+    ui.kPaymentSummaryTitle->setIcon(SKGServices::fromTheme(QStringLiteral("bookmarks")), KTitleWidget::ImageLeft);
+    ui.kAmortizationTableTitle->setIcon(SKGServices::fromTheme(QStringLiteral("view-pim-calendar")), KTitleWidget::ImageLeft);
 
-    ui.kInterestResultsTitle->setIcon(SKGServices::fromTheme(QLatin1String("bookmarks")), KTitleWidget::ImageLeft);
-    ui.kInterestValuesTitle->setIcon(SKGServices::fromTheme(QLatin1String("configure")), KTitleWidget::ImageLeft);
-    ui.kDefineValueTitle->setIcon(SKGServices::fromTheme(QLatin1String("configure")), KTitleWidget::ImageLeft);
+    ui.kInterestResultsTitle->setIcon(SKGServices::fromTheme(QStringLiteral("bookmarks")), KTitleWidget::ImageLeft);
+    ui.kInterestValuesTitle->setIcon(SKGServices::fromTheme(QStringLiteral("configure")), KTitleWidget::ImageLeft);
+    ui.kDefineValueTitle->setIcon(SKGServices::fromTheme(QStringLiteral("configure")), KTitleWidget::ImageLeft);
 
-    ui.kCreditValueDate->addItem(i18nc("A period of 15 days",  "Fifteen"));
-    ui.kDebitValueDate->addItem(i18nc("A period of 15 days",  "Fifteen"));
-    for (int i = 0 ; i <= 5 ; ++i) {
-        ui.kCreditValueDate->addItem(i18nc("Used for configurating when interests are paid on an account : %s days after being calculated",  "Day +%1", i));
-        ui.kDebitValueDate->addItem(i18nc("Used for configurating when interests are paid on an account : %s days after being calculated",  "Day -%1", i));
+    ui.kCreditValueDate->addItem(i18nc("A period of 15 days", "Fifteen"));
+    ui.kDebitValueDate->addItem(i18nc("A period of 15 days", "Fifteen"));
+    for (int i = 0; i <= 5; ++i) {
+        ui.kCreditValueDate->addItem(i18nc("Used for configurating when interests are paid on an account : %s days after being calculated", "Day +%1", i));
+        ui.kDebitValueDate->addItem(i18nc("Used for configurating when interests are paid on an account : %s days after being calculated", "Day -%1", i));
     }
 
-    ui.kMode->addItem(i18nc("24 fifteen is the name of a financial method to compute interests on an account",  "24 fifteen"));
-    ui.kMode->addItem(i18nc("A period of 360 days",  "360 days"));
-    ui.kMode->addItem(i18nc("A period of 365 days",  "365 days"));
+    ui.kMode->addItem(i18nc("24 fifteen is the name of a financial method to compute interests on an account", "24 fifteen"));
+    ui.kMode->addItem(i18nc("A period of 360 days", "360 days"));
+    ui.kMode->addItem(i18nc("A period of 365 days", "365 days"));
 
     ui.kAmortizationTable->verticalHeader()->setDefaultSectionSize(ui.kAmortizationTable->verticalHeader()->minimumSectionSize());
 
     SKGWidgetSelector::SKGListQWidget list;
     list.push_back(ui.kInterestFrm);
     list.push_back(ui.kBtnFrm);
-    ui.kWidgetSelector->addButton(SKGServices::fromTheme(QLatin1String("taxes-finances")), i18n("Interest"), i18n("Interests calculator"), list);
-    ui.kWidgetSelector->addButton(SKGServices::fromTheme(QLatin1String("accessories-calculator")), i18n("Amortization Table"), i18n("Loan amortization table calculator"), ui.kAmortizationFrm);
+    ui.kWidgetSelector->addButton(SKGServices::fromTheme(QStringLiteral("taxes-finances")), i18n("Interest"), i18n("Interests calculator"), list);
+    ui.kWidgetSelector->addButton(SKGServices::fromTheme(QStringLiteral("dialog-scripts")),
+                                  i18n("Amortization Table"),
+                                  i18n("Loan amortization table calculator"),
+                                  ui.kAmortizationFrm);
     connect(ui.kWidgetSelector, &SKGWidgetSelector::selectedModeChanged, this, &SKGCalculatorPluginWidget::onBtnModeClicked);
 
     // Bind account creation view
-    m_objectModel = new SKGObjectModel(qobject_cast<SKGDocumentBank*>(getDocument()), QLatin1String("v_interest"), QLatin1String(""), this, QLatin1String(""), false);
+    m_objectModel = new SKGObjectModel(qobject_cast<SKGDocumentBank *>(getDocument()), QStringLiteral("v_interest"), QString(), this, QString(), false);
     ui.kInterestView->setModel(m_objectModel);
 
-    auto resultModel = new SKGObjectModel(qobject_cast<SKGDocumentBank*>(getDocument()), QLatin1String("interest_result"), QLatin1String(""), this, QLatin1String(""), false);
+    auto resultModel = new SKGObjectModel(qobject_cast<SKGDocumentBank *>(getDocument()), QStringLiteral("interest_result"), QString(), this, QString(), false);
     ui.kInterestResultTable->setModel(resultModel);
 
     connect(ui.kInterestView, &SKGTableView::selectionChangedDelayed, this, &SKGCalculatorPluginWidget::onSelectionChanged);
@@ -85,11 +89,19 @@ SKGCalculatorPluginWidget::SKGCalculatorPluginWidget(QWidget* iParent, SKGDocume
     ui.kWidgetSelector->setSelectedMode(0);
 
     // Refresh
-    connect(ui.kDisplayAccountCombo, static_cast<void (SKGComboBox::*)(const QString&)>(&SKGComboBox::currentTextChanged), this, &SKGCalculatorPluginWidget::onFilterChanged, Qt::QueuedConnection);
-    connect(ui.KYearEdit, static_cast<void (SKGComboBox::*)(const QString&)>(&SKGComboBox::currentTextChanged), this, &SKGCalculatorPluginWidget::onFilterChanged, Qt::QueuedConnection);
+    connect(ui.kDisplayAccountCombo,
+            static_cast<void (SKGComboBox::*)(const QString &)>(&SKGComboBox::currentTextChanged),
+            this,
+            &SKGCalculatorPluginWidget::onFilterChanged,
+            Qt::QueuedConnection);
+    connect(ui.KYearEdit,
+            static_cast<void (SKGComboBox::*)(const QString &)>(&SKGComboBox::currentTextChanged),
+            this,
+            &SKGCalculatorPluginWidget::onFilterChanged,
+            Qt::QueuedConnection);
 
     connect(getDocument(), &SKGDocument::tableModified, this, &SKGCalculatorPluginWidget::dataModified, Qt::QueuedConnection);
-    dataModified(QLatin1String(""), 0);
+    dataModified(QString(), 0);
 
     // Set Event filters to catch CTRL+ENTER or SHIFT+ENTER
     this->installEventFilter(this);
@@ -102,10 +114,19 @@ SKGCalculatorPluginWidget::SKGCalculatorPluginWidget(QWidget* iParent, SKGDocume
     connect(ui.kAdd, &QPushButton::clicked, this, &SKGCalculatorPluginWidget::onAdd);
     connect(ui.kUpdate, &QPushButton::clicked, this, &SKGCalculatorPluginWidget::onUpdate);
     connect(ui.kLoanEdit, &SKGCalculatorEdit::textChanged, this, &SKGCalculatorPluginWidget::onAmortizationComputationDelayed);
-    connect(ui.kUnitEdit, static_cast<void (SKGUnitComboBox::*)(const QString&)>(&SKGUnitComboBox::currentTextChanged), this, &SKGCalculatorPluginWidget::onAmortizationComputationDelayed);
+    connect(ui.kUnitEdit,
+            static_cast<void (SKGUnitComboBox::*)(const QString &)>(&SKGUnitComboBox::currentTextChanged),
+            this,
+            &SKGCalculatorPluginWidget::onAmortizationComputationDelayed);
     connect(ui.kLenghtEdit, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &SKGCalculatorPluginWidget::onAmortizationComputationDelayed);
-    connect(ui.kAnnualRateEdit, static_cast<void (QDoubleSpinBox::*)(double)>(&QDoubleSpinBox::valueChanged), this, &SKGCalculatorPluginWidget::onAmortizationComputationDelayed);
-    connect(ui.kInsuranceRateEdit, static_cast<void (QDoubleSpinBox::*)(double)>(&QDoubleSpinBox::valueChanged), this, &SKGCalculatorPluginWidget::onAmortizationComputationDelayed);
+    connect(ui.kAnnualRateEdit,
+            static_cast<void (QDoubleSpinBox::*)(double)>(&QDoubleSpinBox::valueChanged),
+            this,
+            &SKGCalculatorPluginWidget::onAmortizationComputationDelayed);
+    connect(ui.kInsuranceRateEdit,
+            static_cast<void (QDoubleSpinBox::*)(double)>(&QDoubleSpinBox::valueChanged),
+            this,
+            &SKGCalculatorPluginWidget::onAmortizationComputationDelayed);
 }
 
 SKGCalculatorPluginWidget::~SKGCalculatorPluginWidget()
@@ -114,14 +135,14 @@ SKGCalculatorPluginWidget::~SKGCalculatorPluginWidget()
     m_objectModel = nullptr;
 }
 
-bool SKGCalculatorPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
+bool SKGCalculatorPluginWidget::eventFilter(QObject *iObject, QEvent *iEvent)
 {
     if ((iEvent != nullptr) && iEvent->type() == QEvent::KeyPress) {
-        auto* keyEvent = dynamic_cast<QKeyEvent*>(iEvent);
+        auto *keyEvent = dynamic_cast<QKeyEvent *>(iEvent);
         if (keyEvent && (keyEvent->key() == Qt::Key_Return || keyEvent->key() == Qt::Key_Enter) && iObject == this) {
             if ((QApplication::keyboardModifiers() & Qt::ControlModifier) != 0u && ui.kAdd->isEnabled()) {
                 ui.kAdd->click();
-            } else if ((QApplication::keyboardModifiers() &Qt::ShiftModifier) != 0u && ui.kUpdate->isEnabled()) {
+            } else if ((QApplication::keyboardModifiers() & Qt::ShiftModifier) != 0u && ui.kUpdate->isEnabled()) {
                 ui.kUpdate->click();
             }
         }
@@ -133,43 +154,42 @@ bool SKGCalculatorPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
 QString SKGCalculatorPluginWidget::getState()
 {
     SKGTRACEINFUNC(10)
-    QDomDocument doc(QLatin1String("SKGML"));
-    QDomElement root = doc.createElement(QLatin1String("parameters"));
+    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomElement root = doc.createElement(QStringLiteral("parameters"));
     doc.appendChild(root);
 
-    root.setAttribute(QLatin1String("currentPage"), SKGServices::intToString(ui.kWidgetSelector->getSelectedMode()));
-    root.setAttribute(QLatin1String("account"), ui.kDisplayAccountCombo->currentText());
-    root.setAttribute(QLatin1String("year"), ui.KYearEdit->text());
-
-    root.setAttribute(QLatin1String("amortizationLoan"), ui.kLoanEdit->text());
-    root.setAttribute(QLatin1String("amortizationUnit"), ui.kUnitEdit->text());
-    root.setAttribute(QLatin1String("amortizationRate"), SKGServices::doubleToString(ui.kAnnualRateEdit->value()));
-    root.setAttribute(QLatin1String("amortizationLenght"), SKGServices::intToString(ui.kLenghtEdit->value()));
-    root.setAttribute(QLatin1String("amortizationInsuranceRate"), SKGServices::doubleToString(ui.kInsuranceRateEdit->value()));
+    root.setAttribute(QStringLiteral("currentPage"), SKGServices::intToString(ui.kWidgetSelector->getSelectedMode()));
+    root.setAttribute(QStringLiteral("account"), ui.kDisplayAccountCombo->currentText());
+    root.setAttribute(QStringLiteral("year"), ui.KYearEdit->text());
 
+    root.setAttribute(QStringLiteral("amortizationLoan"), ui.kLoanEdit->text());
+    root.setAttribute(QStringLiteral("amortizationUnit"), ui.kUnitEdit->text());
+    root.setAttribute(QStringLiteral("amortizationRate"), SKGServices::doubleToString(ui.kAnnualRateEdit->value()));
+    root.setAttribute(QStringLiteral("amortizationLenght"), SKGServices::intToString(ui.kLenghtEdit->value()));
+    root.setAttribute(QStringLiteral("amortizationInsuranceRate"), SKGServices::doubleToString(ui.kInsuranceRateEdit->value()));
 
     // Memorize table settings
-    root.setAttribute(QLatin1String("view"), ui.kInterestView->getState());
-    root.setAttribute(QLatin1String("viewResult"), ui.kInterestResultTable->getState());
+    root.setAttribute(QStringLiteral("view"), ui.kInterestView->getState());
+    root.setAttribute(QStringLiteral("viewResult"), ui.kInterestResultTable->getState());
 
     return doc.toString();
 }
 
-void SKGCalculatorPluginWidget::setState(const QString& iState)
+void SKGCalculatorPluginWidget::setState(const QString &iState)
 {
     SKGTRACEINFUNC(10)
-    QDomDocument doc(QLatin1String("SKGML"));
+    QDomDocument doc(QStringLiteral("SKGML"));
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
-    QString account = root.attribute(QLatin1String("account"));
-    QString currentPage = root.attribute(QLatin1String("currentPage"));
-    QString year = root.attribute(QLatin1String("year"));
-    QString amortizationLoan = root.attribute(QLatin1String("amortizationLoan"));
-    QString amortizationUnit = root.attribute(QLatin1String("amortizationUnit"));
-    QString amortizationRate = root.attribute(QLatin1String("amortizationRate"));
-    QString amortizationInsuranceRate = root.attribute(QLatin1String("amortizationInsuranceRate"));
-    QString amortizationLenght = root.attribute(QLatin1String("amortizationLenght"));
+    QString account = root.attribute(QStringLiteral("account"));
+    QString currentPage = root.attribute(QStringLiteral("currentPage"));
+    QString year = root.attribute(QStringLiteral("year"));
+    QString amortizationLoan = root.attribute(QStringLiteral("amortizationLoan"));
+    QString amortizationUnit = root.attribute(QStringLiteral("amortizationUnit"));
+    QString amortizationRate = root.attribute(QStringLiteral("amortizationRate"));
+    QString amortizationInsuranceRate = root.attribute(QStringLiteral("amortizationInsuranceRate"));
+    QString amortizationLenght = root.attribute(QStringLiteral("amortizationLenght"));
 
     if (!currentPage.isEmpty()) {
         ui.kWidgetSelector->setSelectedMode(SKGServices::stringToInt(currentPage));
@@ -207,13 +227,13 @@ void SKGCalculatorPluginWidget::setState(const QString& iState)
     }
 
     // !!! Must be done here after onFilterChanged
-    ui.kInterestView->setState(root.attribute(QLatin1String("view")));
-    ui.kInterestResultTable->setState(root.attribute(QLatin1String("viewResult")));
+    ui.kInterestView->setState(root.attribute(QStringLiteral("view")));
+    ui.kInterestResultTable->setState(root.attribute(QStringLiteral("viewResult")));
 }
 
 QString SKGCalculatorPluginWidget::getDefaultStateAttribute()
 {
-    return QLatin1String("SKGCALCULATOR_DEFAULT_PARAMETERS");
+    return QStringLiteral("SKGCALCULATOR_DEFAULT_PARAMETERS");
 }
 
 void SKGCalculatorPluginWidget::onBtnModeClicked(int mode)
@@ -233,7 +253,7 @@ void SKGCalculatorPluginWidget::onSelectionChanged()
 {
     SKGTRACEINFUNC(10)
     // Mapping
-    QItemSelectionModel* selModel = ui.kInterestView->selectionModel();
+    QItemSelectionModel *selModel = ui.kInterestView->selectionModel();
     if (selModel != nullptr) {
         QModelIndexList indexes = selModel->selectedRows();
         if (!indexes.isEmpty() && (m_objectModel != nullptr)) {
@@ -252,7 +272,7 @@ void SKGCalculatorPluginWidget::onSelectionChanged()
     }
 }
 
-void SKGCalculatorPluginWidget::dataModified(const QString& iTableName, int iIdTransaction)
+void SKGCalculatorPluginWidget::dataModified(const QString &iTableName, int iIdTransaction)
 
 {
     SKGTRACEINFUNC(10)
@@ -260,9 +280,9 @@ void SKGCalculatorPluginWidget::dataModified(const QString& iTableName, int iIdT
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
     // Refresh widgets
-    QSqlDatabase* db = getDocument()->getMainDatabase();
+    QSqlDatabase *db = getDocument()->getMainDatabase();
     setEnabled(db != nullptr);
-    if (db != nullptr && (iTableName == QLatin1String("interest") || iTableName.isEmpty())) {
+    if (db != nullptr && (iTableName == QStringLiteral("interest") || iTableName.isEmpty())) {
         // Correction bug 2299394 vvv
         if (ui.kInterestView->isAutoResized()) {
             ui.kInterestView->resizeColumnsToContentsDelayed();
@@ -276,16 +296,16 @@ void SKGCalculatorPluginWidget::dataModified(const QString& iTableName, int iIdT
 
     // Refresh interest parameter view
     QString current = ui.kDisplayAccountCombo->currentText();
-    if (db != nullptr && (iTableName == QLatin1String("v_account_display") || iTableName.isEmpty())) {
+    if (db != nullptr && (iTableName == QStringLiteral("v_account_display") || iTableName.isEmpty())) {
         // Clear
         ui.kDisplayAccountCombo->clear();
 
         SKGStringListList listAccount;
-        getDocument()->executeSelectSqliteOrder(QLatin1String("SELECT t_ICON, t_name from v_account_display where t_close='N' order by t_name"), listAccount);
+        getDocument()->executeSelectSqliteOrder(QStringLiteral("SELECT t_ICON, t_name from v_account_display where t_close='N' order by t_name"), listAccount);
 
         int nbAccounts = listAccount.count();
         if (nbAccounts >= 0) {
-            for (int i = 1; i < nbAccounts; ++i) {  // Ignore header
+            for (int i = 1; i < nbAccounts; ++i) { // Ignore header
                 QString fileName = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "skrooge/images/logo/" % listAccount.at(i).at(0));
                 if (fileName.isEmpty()) {
                     fileName = listAccount.at(i).at(0);
@@ -306,14 +326,17 @@ void SKGCalculatorPluginWidget::dataModified(const QString& iTableName, int iIdT
     }
 
     // Fill years
-    if (db != nullptr && (iTableName == QLatin1String("v_operation_display") || iTableName.isEmpty())) {
-        disconnect(ui.KYearEdit, static_cast<void (SKGComboBox::*)(const QString&)>(&SKGComboBox::currentTextChanged), this, &SKGCalculatorPluginWidget::onFilterChanged);
+    if (db != nullptr && (iTableName == QStringLiteral("v_operation_display") || iTableName.isEmpty())) {
+        disconnect(ui.KYearEdit,
+                   static_cast<void (SKGComboBox::*)(const QString &)>(&SKGComboBox::currentTextChanged),
+                   this,
+                   &SKGCalculatorPluginWidget::onFilterChanged);
 
         int lastYear = QDate::currentDate().year();
         int firstYear = lastYear;
 
         QStringList list;
-        getDocument()->getDistinctValues(QLatin1String("v_operation_display"), QLatin1String("d_DATEYEAR"), QLatin1String(""), list);
+        getDocument()->getDistinctValues(QStringLiteral("v_operation_display"), QStringLiteral("d_DATEYEAR"), QString(), list);
         if (!list.isEmpty()) {
             firstYear = SKGServices::stringToInt(list.at(0));
         }
@@ -329,10 +352,13 @@ void SKGCalculatorPluginWidget::dataModified(const QString& iTableName, int iIdT
         }
 
         ui.KYearEdit->setText(year);
-        connect(ui.KYearEdit, static_cast<void (SKGComboBox::*)(const QString&)>(&SKGComboBox::currentTextChanged), this, &SKGCalculatorPluginWidget::onFilterChanged);
+        connect(ui.KYearEdit,
+                static_cast<void (SKGComboBox::*)(const QString &)>(&SKGComboBox::currentTextChanged),
+                this,
+                &SKGCalculatorPluginWidget::onFilterChanged);
     }
     // Refresh computation
-    if (db != nullptr && (iTableName == QLatin1String("interest") || iTableName == QLatin1String("account") || iTableName.isEmpty())) {
+    if (db != nullptr && (iTableName == QStringLiteral("interest") || iTableName == QStringLiteral("account") || iTableName.isEmpty())) {
         computeInterest();
     }
     QApplication::restoreOverrideCursor();
@@ -347,21 +373,23 @@ void SKGCalculatorPluginWidget::computeInterest()
     SKGAccountObject::SKGInterestItemList oInterestList;
     double oInterests = 0;
     IFOKDO(err, account.getInterestItems(oInterestList, oInterests, SKGServices::stringToInt(ui.KYearEdit->text())))
-    IFOK(err) {
+    IFOK(err)
+    {
         // Refresh table
         ui.kInterestResultTable->setState(ui.kInterestResultTable->getState());
 
         // Set text
-        auto* doc = qobject_cast<SKGDocumentBank*>(getDocument());
+        auto *doc = qobject_cast<SKGDocumentBank *>(getDocument());
         if (doc != nullptr) {
             SKGServices::SKGUnitInfo unit1 = doc->getPrimaryUnit();
             SKGServices::SKGUnitInfo unit2 = doc->getSecondaryUnit();
 
             QString s1 = doc->formatMoney(oInterests, unit1);
-            ui.kInterestLbl->setText(i18nc("The Annual interest is the amount of money gained in one year on a remunerated account",  "Annual interest=%1", s1));
+            ui.kInterestLbl->setText(i18nc("The Annual interest is the amount of money gained in one year on a remunerated account", "Annual interest=%1", s1));
             if (!unit2.Symbol.isEmpty() && (unit2.Value != 0.0)) {
                 s1 = doc->formatMoney(oInterests, unit2);
-                ui.kInterestLbl->setToolTip(i18nc("The Annual interest is the amount of money gained in one year on a remunerated account",  "Annual interest=%1", s1));
+                ui.kInterestLbl->setToolTip(
+                    i18nc("The Annual interest is the amount of money gained in one year on a remunerated account", "Annual interest=%1", s1));
             }
         }
     }
@@ -431,11 +459,15 @@ void SKGCalculatorPluginWidget::onSelectedInterestChanged()
 void SKGCalculatorPluginWidget::onAdd()
 {
     SKGError err;
-    SKGTRACEINFUNCRC(10, err) {
+    SKGTRACEINFUNCRC(10, err)
+    {
         SKGInterestObject interestObj;
         {
             QString accountname = ui.kDisplayAccountCombo->currentText();
-            SKGBEGINTRANSACTION(*getDocument(), i18nc("Lets the user create parameters for computing interests on an account", "Interest parameter creation for account '%1'", accountname), err)
+            SKGBEGINTRANSACTION(
+                *getDocument(),
+                i18nc("Lets the user create parameters for computing interests on an account", "Interest parameter creation for account '%1'", accountname),
+                err)
 
             // Get Parent account
             SKGAccountObject accountObj(getDocument());
@@ -452,15 +484,22 @@ void SKGCalculatorPluginWidget::onAdd()
             IFOKDO(err, interestObj.save())
 
             // Send message
-            IFOKDO(err, interestObj.getDocument()->sendMessage(i18nc("An information to the user", "The interest parameter '%1' has been added", interestObj.getDisplayName()), SKGDocument::Hidden))
+            IFOKDO(err,
+                   interestObj.getDocument()->sendMessage(
+                       i18nc("An information to the user", "The interest parameter '%1' has been added", interestObj.getDisplayName()),
+                       SKGDocument::Hidden))
         }
 
         // status bar
-        IFOK(err) {
+        IFOK(err)
+        {
             err = SKGError(0, i18nc("User defined parameters for computing interests were successfully created", "Interest parameter created"));
             ui.kInterestView->selectObject(interestObj.getUniqueID());
-        } else {
-            err.addError(ERR_FAIL, i18nc("Error message: User defined parameters for computing interests could not be created",  "Interest parameter creation failed"));
+        }
+        else
+        {
+            err.addError(ERR_FAIL,
+                         i18nc("Error message: User defined parameters for computing interests could not be created", "Interest parameter creation failed"));
         }
     }
 
@@ -483,7 +522,10 @@ void SKGCalculatorPluginWidget::onUpdate()
     int nb = updatedInterest.count();
     {
         SKGInterestObject interestObj;
-        SKGBEGINTRANSACTION(*getDocument(), i18nc("Lets the user update parameters for computing interests on an account", "Interest parameter update for account '%1'", accountname), err)
+        SKGBEGINTRANSACTION(
+            *getDocument(),
+            i18nc("Lets the user update parameters for computing interests on an account", "Interest parameter update for account '%1'", accountname),
+            err)
 
         for (int i = 0; !err && i < nb; ++i) {
             interestObj = updatedInterest.at(i);
@@ -497,14 +539,19 @@ void SKGCalculatorPluginWidget::onUpdate()
             IFOKDO(err, interestObj.save())
 
             // Send message
-            IFOKDO(err, interestObj.getDocument()->sendMessage(i18nc("An information to the user", "The interest parameter '%1' has been updated", interestObj.getDisplayName()), SKGDocument::Hidden))
+            IFOKDO(err,
+                   interestObj.getDocument()->sendMessage(
+                       i18nc("An information to the user", "The interest parameter '%1' has been updated", interestObj.getDisplayName()),
+                       SKGDocument::Hidden))
         }
     }
 
     // status bar
     IFOKDO(err, SKGError(0, i18nc("User defined parameters for computing interests were successfully updated", "Interest parameter updated")))
-    else {
-        err.addError(ERR_FAIL, i18nc("Error message: User defined parameters for computing interests could not be updated",  "Interest parameter update failed"));
+    else
+    {
+        err.addError(ERR_FAIL,
+                     i18nc("Error message: User defined parameters for computing interests could not be updated", "Interest parameter update failed"));
     }
 
     // Display error
@@ -536,8 +583,10 @@ void SKGCalculatorPluginWidget::onAmortizationComputation()
     int periodInMonths = 12;
     int numberPayments = ui.kLenghtEdit->value() * periodInMonths;
     double periodicRate = ui.kAnnualRateEdit->value() / 100 / periodInMonths;
-    double insurance = qRound(ui.kLoanEdit->value() * ui.kInsuranceRateEdit->value() / 100.0 / static_cast<double>(periodInMonths) * static_cast<double>(p)) / static_cast<double>(p);
-    double periodicAmount = qRound(ui.kLoanEdit->value() * periodicRate / (1 - pow(1 + periodicRate, -numberPayments)) * static_cast<double>(p)) / static_cast<double>(p);
+    double insurance = qRound(ui.kLoanEdit->value() * ui.kInsuranceRateEdit->value() / 100.0 / static_cast<double>(periodInMonths) * static_cast<double>(p))
+        / static_cast<double>(p);
+    double periodicAmount =
+        qRound(ui.kLoanEdit->value() * periodicRate / (1 - pow(1 + periodicRate, -numberPayments)) * static_cast<double>(p)) / static_cast<double>(p);
 
     // Fill table
     double dueAmount = ui.kLoanEdit->value();
@@ -559,25 +608,26 @@ void SKGCalculatorPluginWidget::onAmortizationComputation()
         ui.kAmortizationTable->setItem(i, 4, new QTableWidgetItem(SKGServices::toCurrencyString(dueAmount, unitInfo.Symbol, unitInfo.NbDecimal)));
     }
 
-    ui.kAmortizationResult->setText(i18n("Number of payments:	%1\n"  // NOLINT(whitespace/tab)
-                                         "Monthly payment: 	%2\n"  // NOLINT(whitespace/tab)
-                                         "Monthly insurance: 	%3\n"  // NOLINT(whitespace/tab)
-                                         "Total principal paid: 	%4\n"  // NOLINT(whitespace/tab)
-                                         "Total interest paid: 	%5\n"  // NOLINT(whitespace/tab)
-                                         "Total insurance paid: 	%6\n"  // NOLINT(whitespace/tab)
-                                         "Total paid: 		%7",   // NOLINT(whitespace/tab)
-                                         SKGServices::intToString(numberPayments),
-                                         SKGServices::toCurrencyString(periodicAmount, unitInfo.Symbol, unitInfo.NbDecimal),
-                                         SKGServices::toCurrencyString(insurance, unitInfo.Symbol, unitInfo.NbDecimal),
-                                         SKGServices::toCurrencyString(ui.kLoanEdit->value(), unitInfo.Symbol, unitInfo.NbDecimal),
-                                         SKGServices::toCurrencyString(sumInterest, unitInfo.Symbol, unitInfo.NbDecimal),
-                                         SKGServices::toCurrencyString(numberPayments * insurance, unitInfo.Symbol, unitInfo.NbDecimal),
-                                         SKGServices::toCurrencyString(ui.kLoanEdit->value() + sumInterest + numberPayments * insurance, unitInfo.Symbol, unitInfo.NbDecimal)));
+    ui.kAmortizationResult->setText(
+        i18n("Number of payments:	%1\n" // NOLINT(whitespace/tab)
+             "Monthly payment: 	%2\n" // NOLINT(whitespace/tab)
+             "Monthly insurance: 	%3\n" // NOLINT(whitespace/tab)
+             "Total principal paid: 	%4\n" // NOLINT(whitespace/tab)
+             "Total interest paid: 	%5\n" // NOLINT(whitespace/tab)
+             "Total insurance paid: 	%6\n" // NOLINT(whitespace/tab)
+             "Total paid: 		%7", // NOLINT(whitespace/tab)
+             SKGServices::intToString(numberPayments),
+             SKGServices::toCurrencyString(periodicAmount, unitInfo.Symbol, unitInfo.NbDecimal),
+             SKGServices::toCurrencyString(insurance, unitInfo.Symbol, unitInfo.NbDecimal),
+             SKGServices::toCurrencyString(ui.kLoanEdit->value(), unitInfo.Symbol, unitInfo.NbDecimal),
+             SKGServices::toCurrencyString(sumInterest, unitInfo.Symbol, unitInfo.NbDecimal),
+             SKGServices::toCurrencyString(numberPayments * insurance, unitInfo.Symbol, unitInfo.NbDecimal),
+             SKGServices::toCurrencyString(ui.kLoanEdit->value() + sumInterest + numberPayments * insurance, unitInfo.Symbol, unitInfo.NbDecimal)));
 
     QApplication::restoreOverrideCursor();
 }
 
-QWidget* SKGCalculatorPluginWidget::zoomableWidget()
+QWidget *SKGCalculatorPluginWidget::zoomableWidget()
 {
     if (ui.kWidgetSelector->getSelectedMode() == 0) {
         return ui.kInterestView;
@@ -585,7 +635,7 @@ QWidget* SKGCalculatorPluginWidget::zoomableWidget()
     return ui.kAmortizationTable;
 }
 
-QWidget* SKGCalculatorPluginWidget::mainWidget()
+QWidget *SKGCalculatorPluginWidget::mainWidget()
 {
     if (ui.kWidgetSelector->getSelectedMode() == 0) {
         return ui.kInterestView;
