@@ -252,7 +252,7 @@ void SKGCategoriesPlugin::importStandardCategories()
             "Education > Tuition;Employment;Employment > Benefits;Employment > Foreign;Employment > Lump sums;Employment > Other employ;Employment > Salary & "
             "wages;Food;Food > Dining Out;Food > Groceries;Gardening;"
             "Gift Received;Gifts;Healthcare;Healthcare > Dental;Healthcare > Doctor;Healthcare > Hospital;Healthcare > Optician;Healthcare > "
-            "Prescriptions;Holidays;Holidays > Accomodation;Holidays > Travel;Household;"
+            "Prescriptions;Holidays;Holidays > Accommodation;Holidays > Travel;Household;"
             "Household > Furnishings;Household > Repairs;Insurance;Insurance > Auto;Insurance > Disability;Insurance > Home and Contents;Insurance > "
             "Life;Insurance > Medical;Int Inc;Int Inc > Bank Interest;Int Inc > Gross;Int Inc > Net;"
             "Int Inc > Other savings;Invest. income;Invest. income > 1st option;Invest. income > Dividend;Invest. income > Foreign;Invest. income > Other "
@@ -273,7 +273,7 @@ void SKGCategoriesPlugin::importStandardCategories()
             "Retirement Income > Pensions & Annuities;Retirement Income > State Pension Benefits;Short-Term Capital gains;Social Security Benefits;Taxes;Taxes "
             "> AMT;Taxes > Federal Tax;Taxes > Federal Taxes;Taxes > Local Tax;Taxes > Local Taxes;"
             "Taxes > Other Invest;Taxes > Other Tax;Taxes > Property Taxes;Taxes > Social Security;Taxes > State Tax;Taxes > State Taxes;Travel;Travel > "
-            "Accomodations;Travel > Car Rental;Travel > Fares;Utilities;Utilities > Electricity;"
+            "Accommodations;Travel > Car Rental;Travel > Fares;Utilities;Utilities > Electricity;"
             "Utilities > Garbage & Recycling;Utilities > Gas;Utilities > Sewer;Utilities > Telephone;Utilities > Water;Wages & Salary;Wages & Salary > "
             "Benefits;Wages & Salary > Bonus;Wages & Salary > Commission;"
             "Wages & Salary > Employer Pension Contributions;Wages & Salary > Gross Pay;Wages & Salary > Net Pay;Wages & Salary > Overtime;Wages & Salary > "
