@@ -25,8 +25,11 @@
 #include "skgmainpanel.h"
 #include "skgtablewidget.h"
 
-SKGSplitTableDelegate::SKGSplitTableDelegate(QObject* iParent, SKGDocument* iDoc, QStringList  iListAttribut) : QItemDelegate(iParent),
-    m_document(iDoc), m_listAttributes(std::move(iListAttribut)), m_table(qobject_cast<SKGTableWidget * >(iParent))
+SKGSplitTableDelegate::SKGSplitTableDelegate(QObject *iParent, SKGDocument *iDoc, QStringList iListAttribut)
+    : QItemDelegate(iParent)
+    , m_document(iDoc)
+    , m_listAttributes(std::move(iListAttribut))
+    , m_table(qobject_cast<SKGTableWidget *>(iParent))
 {
 }
 
@@ -35,19 +38,21 @@ SKGSplitTableDelegate::~SKGSplitTableDelegate()
     m_document = nullptr;
 }
 
-QWidget* SKGSplitTableDelegate::createEditor(QWidget* iParent,
-        const QStyleOptionViewItem& option,
-        const QModelIndex& index) const
+QWidget *SKGSplitTableDelegate::createEditor(QWidget *iParent, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     QSizePolicy newSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
     newSizePolicy.setHorizontalStretch(0);
     newSizePolicy.setVerticalStretch(0);
 
-    if (index.column() == m_listAttributes.indexOf(QLatin1String("t_category"))) {
+    if (index.column() == m_listAttributes.indexOf(QStringLiteral("t_category"))) {
         auto editor = new SKGComboBox(iParent);
         editor->setEditable(true);
         if (m_document != nullptr) {
-            SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << editor, m_document, QLatin1String("category"), QLatin1String("t_fullname"), QLatin1String("t_close='N'"));
+            SKGMainPanel::fillWithDistinctValue(QList<QWidget *>() << editor,
+                                                m_document,
+                                                QStringLiteral("category"),
+                                                QStringLiteral("t_fullname"),
+                                                QStringLiteral("t_close='N'"));
         }
         editor->setSizePolicy(newSizePolicy);
         editor->setSizeAdjustPolicy(QComboBox::AdjustToContents);
@@ -55,11 +60,15 @@ QWidget* SKGSplitTableDelegate::createEditor(QWidget* iParent,
 
         return editor;
     }
-    if (index.column() == m_listAttributes.indexOf(QLatin1String("t_comment"))) {
+    if (index.column() == m_listAttributes.indexOf(QStringLiteral("t_comment"))) {
         auto editor = new SKGComboBox(iParent);
         editor->setEditable(true);
         if (m_document != nullptr) {
-            SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << editor, m_document, QLatin1String("v_operation_all_comment"), QLatin1String("t_comment"), QLatin1String(""));
+            SKGMainPanel::fillWithDistinctValue(QList<QWidget *>() << editor,
+                                                m_document,
+                                                QStringLiteral("v_operation_all_comment"),
+                                                QStringLiteral("t_comment"),
+                                                QString());
         }
         editor->setSizePolicy(newSizePolicy);
         editor->setSizeAdjustPolicy(QComboBox::AdjustToContents);
@@ -67,7 +76,7 @@ QWidget* SKGSplitTableDelegate::createEditor(QWidget* iParent,
 
         return editor;
     }
-    if (index.column() == m_listAttributes.indexOf(QLatin1String("f_value"))) {
+    if (index.column() == m_listAttributes.indexOf(QStringLiteral("f_value"))) {
         auto editor = new SKGCalculatorEdit(iParent);
         editor->setMode(SKGCalculatorEdit::EXPRESSION);
         QMapIterator<QString, double> i(m_parameters);
@@ -80,18 +89,23 @@ QWidget* SKGSplitTableDelegate::createEditor(QWidget* iParent,
 
         return editor;
     }
-    if (index.column() == m_listAttributes.indexOf(QLatin1String("t_refund"))) {
+    if (index.column() == m_listAttributes.indexOf(QStringLiteral("t_refund"))) {
         auto editor = new SKGComboBox(iParent);
         editor->setEditable(true);
         if (m_document != nullptr) {
-            SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << editor, m_document, QLatin1String("refund"), QLatin1String("t_name"), QLatin1String("t_close='N'"));
+            SKGMainPanel::fillWithDistinctValue(QList<QWidget *>() << editor,
+                                                m_document,
+                                                QStringLiteral("refund"),
+                                                QStringLiteral("t_name"),
+                                                QStringLiteral("t_close='N'"));
         }
         editor->setSizePolicy(newSizePolicy);
         editor->setSizeAdjustPolicy(QComboBox::AdjustToContents);
         m_table->setColumnWidth(index.column(), editor->sizeHint().width());
 
         return editor;
-    }  if (index.column() == m_listAttributes.indexOf(QLatin1String("d_date"))) {
+    }
+    if (index.column() == m_listAttributes.indexOf(QStringLiteral("d_date"))) {
         auto editor = new SKGDateEdit(iParent);
         editor->setSizePolicy(newSizePolicy);
         editor->setSizeAdjustPolicy(QComboBox::AdjustToContents);
@@ -103,15 +117,15 @@ QWidget* SKGSplitTableDelegate::createEditor(QWidget* iParent,
     return QItemDelegate::createEditor(iParent, option, index);
 }
 
-void SKGSplitTableDelegate::setEditorData(QWidget* editor, const QModelIndex& index) const
+void SKGSplitTableDelegate::setEditorData(QWidget *editor, const QModelIndex &index) const
 {
-    if (index.column() == m_listAttributes.indexOf(QLatin1String("f_value"))) {
-        auto* calculator = qobject_cast<SKGCalculatorEdit*>(editor);
+    if (index.column() == m_listAttributes.indexOf(QStringLiteral("f_value"))) {
+        auto *calculator = qobject_cast<SKGCalculatorEdit *>(editor);
         if (calculator != nullptr) {
             calculator->setText(index.model()->data(index, Qt::ToolTipRole).toString());
         }
-    } else if (index.column() == m_listAttributes.indexOf(QLatin1String("d_date"))) {
-        auto* date = qobject_cast<SKGDateEdit*>(editor);
+    } else if (index.column() == m_listAttributes.indexOf(QStringLiteral("d_date"))) {
+        auto *date = qobject_cast<SKGDateEdit *>(editor);
         if (date != nullptr) {
             date->setDate(SKGServices::stringToDate(index.model()->data(index, Qt::ToolTipRole).toString()));
         }
@@ -120,10 +134,10 @@ void SKGSplitTableDelegate::setEditorData(QWidget* editor, const QModelIndex& in
     }
 }
 
-void SKGSplitTableDelegate::setModelData(QWidget* editor, QAbstractItemModel* model, const QModelIndex& index) const
+void SKGSplitTableDelegate::setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const
 {
-    if (index.column() == m_listAttributes.indexOf(QLatin1String("f_value"))) {
-        auto* calculator = qobject_cast<SKGCalculatorEdit*>(editor);
+    if (index.column() == m_listAttributes.indexOf(QStringLiteral("f_value"))) {
+        auto *calculator = qobject_cast<SKGCalculatorEdit *>(editor);
         if ((calculator != nullptr) && (model != nullptr)) {
             QString f = calculator->formula();
             QString t = SKGServices::doubleToString(calculator->value());
@@ -136,8 +150,8 @@ void SKGSplitTableDelegate::setModelData(QWidget* editor, QAbstractItemModel* mo
             model->blockSignals(previous);
             model->setData(index, t, Qt::DisplayRole);
         }
-    } else if (index.column() == m_listAttributes.indexOf(QLatin1String("d_date"))) {
-        auto* date = qobject_cast<SKGDateEdit*>(editor);
+    } else if (index.column() == m_listAttributes.indexOf(QStringLiteral("d_date"))) {
+        auto *date = qobject_cast<SKGDateEdit *>(editor);
         if ((date != nullptr) && (model != nullptr)) {
             QString dateDisplay = SKGMainPanel::dateToString(date->date());
             QString dateInternal = SKGServices::dateToSqlString(date->date());
@@ -152,8 +166,7 @@ void SKGSplitTableDelegate::setModelData(QWidget* editor, QAbstractItemModel* mo
     m_table->horizontalHeader()->setStretchLastSection(true);
 }
 
-void SKGSplitTableDelegate::addParameterValue(const QString& iParameter, double iValue)
+void SKGSplitTableDelegate::addParameterValue(const QString &iParameter, double iValue)
 {
     m_parameters.insert(iParameter, iValue);
 }
-
