@@ -15,7 +15,7 @@
 #include "skgreportpluginwidget.h"
 #include "skgtraces.h"
 
-SKGReportBoardWidget::SKGReportBoardWidget(QWidget* iParent, SKGDocumentBank* iDocument)
+SKGReportBoardWidget::SKGReportBoardWidget(QWidget *iParent, SKGDocumentBank *iDocument)
     : SKGBoardWidget(iParent, iDocument, i18nc("Dashboard widget title", "Report"), true)
 {
     SKGTRACEINFUNC(10)
@@ -27,8 +27,8 @@ SKGReportBoardWidget::SKGReportBoardWidget(QWidget* iParent, SKGDocumentBank* iD
     setContextMenuPolicy(Qt::ActionsContextMenu);
 
     QStringList overlayopen;
-    overlayopen.push_back(QLatin1String("quickopen"));
-    auto open = new QAction(SKGServices::fromTheme(QLatin1String("view-statistics"), overlayopen), i18nc("Verb", "Open report…"), this);
+    overlayopen.push_back(QStringLiteral("quickopen"));
+    auto open = new QAction(SKGServices::fromTheme(QStringLiteral("view-statistics"), overlayopen), i18nc("Verb", "Open report…"), this);
     connect(open, &QAction::triggered, this, &SKGReportBoardWidget::onOpen);
     addAction(open);
 
@@ -47,31 +47,30 @@ SKGReportBoardWidget::~SKGReportBoardWidget()
 
 QString SKGReportBoardWidget::getState()
 {
-    QDomDocument doc(QLatin1String("SKGML"));
+    QDomDocument doc(QStringLiteral("SKGML"));
     doc.setContent(SKGBoardWidget::getState());
     QDomElement root = doc.documentElement();
 
     if (m_graph != nullptr) {
-        root.setAttribute(QLatin1String("graph"), m_graph->getState());
+        root.setAttribute(QStringLiteral("graph"), m_graph->getState());
     }
     return doc.toString();
 }
 
-void SKGReportBoardWidget::setState(const QString& iState)
+void SKGReportBoardWidget::setState(const QString &iState)
 {
     SKGBoardWidget::setState(iState);
 
-    QDomDocument doc(QLatin1String("SKGML"));
+    QDomDocument doc(QStringLiteral("SKGML"));
     if (doc.setContent(iState)) {
         QDomElement root = doc.documentElement();
 
-        QString title = root.attribute(QLatin1String("title"));
+        QString title = root.attribute(QStringLiteral("title"));
         if (!title.isEmpty()) {
             setMainTitle(title);
         }
 
-
-        QString graphS = root.attribute(QLatin1String("graph"));
+        QString graphS = root.attribute(QStringLiteral("graph"));
         if (m_graph != nullptr) {
             if (graphS.isEmpty()) {
                 m_graph->setState(iState);
@@ -81,16 +80,16 @@ void SKGReportBoardWidget::setState(const QString& iState)
         }
     }
 
-    dataModified(QLatin1String(""), 0);
+    dataModified(QString(), 0);
 }
 
-void SKGReportBoardWidget::dataModified(const QString& iTableName, int iIdTransaction)
+void SKGReportBoardWidget::dataModified(const QString &iTableName, int iIdTransaction)
 {
     SKGTRACEINFUNC(10)
     Q_UNUSED(iIdTransaction)
-    if (iTableName == QLatin1String("operation") || iTableName.isEmpty()) {
+    if (iTableName == QStringLiteral("operation") || iTableName.isEmpty()) {
         bool exist = false;
-        getDocument()->existObjects(QLatin1String("account"), QLatin1String(""), exist);
+        getDocument()->existObjects(QStringLiteral("account"), QString(), exist);
         if (parentWidget() != nullptr) {
             setVisible(exist);
         }
@@ -99,24 +98,22 @@ void SKGReportBoardWidget::dataModified(const QString& iTableName, int iIdTransa
 
 void SKGReportBoardWidget::onOpen()
 {
-    QDomDocument doc(QLatin1String("SKGML"));
+    QDomDocument doc(QStringLiteral("SKGML"));
     QString graphS;
     if (doc.setContent(getState())) {
         QDomElement root = doc.documentElement();
-        graphS = root.attribute(QLatin1String("graph"));
+        graphS = root.attribute(QStringLiteral("graph"));
 
-        QDomDocument doc2(QLatin1String("SKGML"));
+        QDomDocument doc2(QStringLiteral("SKGML"));
         if (doc2.setContent(graphS)) {
             QDomElement root2 = doc2.documentElement();
 
-            QString currentPage = root2.attribute(QLatin1String("currentPage"));
+            QString currentPage = root2.attribute(QStringLiteral("currentPage"));
             if (SKGServices::stringToInt(currentPage) < -1) {
-                root2.setAttribute(QLatin1String("currentPage"), QLatin1String("-1"));
+                root2.setAttribute(QStringLiteral("currentPage"), QStringLiteral("-1"));
                 graphS = doc2.toString();
             }
         }
     }
-    SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName(QLatin1String("Skrooge report plugin")), -1, graphS);
+    SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName(QStringLiteral("Skrooge report plugin")), -1, graphS);
 }
-
-
