@@ -25,10 +25,12 @@
 #include "skgservices.h"
 #include "skgtraces.h"
 
-SKGScheduledBoardWidget::SKGScheduledBoardWidget(QWidget* iParent, SKGDocument* iDocument)
-    : SKGHtmlBoardWidget(iParent, iDocument, i18nc("Noun, the title of a section", "Scheduled transactions"),
-                         QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("skrooge/html/default/scheduled_operations.qml")),
-                         QStringList() << QLatin1String("v_recurrentoperation_display"))
+SKGScheduledBoardWidget::SKGScheduledBoardWidget(QWidget *iParent, SKGDocument *iDocument)
+    : SKGHtmlBoardWidget(iParent,
+                         iDocument,
+                         i18nc("Noun, the title of a section", "Scheduled transactions"),
+                         QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/scheduled_operations.qml")),
+                         QStringList() << QStringLiteral("v_recurrentoperation_display"))
 {
     SKGTRACEINFUNC(10)
     m_daysmax = new SKGComboBox(this);
@@ -41,48 +43,45 @@ SKGScheduledBoardWidget::SKGScheduledBoardWidget(QWidget* iParent, SKGDocument*
 
     // Add widget in menu
     auto daysmaxWidget = new QWidgetAction(this);
-    daysmaxWidget->setObjectName(QLatin1String("daysmaxWidget"));
+    daysmaxWidget->setObjectName(QStringLiteral("daysmaxWidget"));
     daysmaxWidget->setDefaultWidget(m_daysmax);
 
     addAction(daysmaxWidget);
 
-    connect(m_daysmax, static_cast<void (SKGComboBox::*)(const QString&)>(&SKGComboBox::currentTextChanged), this, [ = ]() {
+    connect(m_daysmax, static_cast<void (SKGComboBox::*)(const QString &)>(&SKGComboBox::currentTextChanged), this, [this]() {
         this->dataModified();
     });
 }
 
-SKGScheduledBoardWidget::~SKGScheduledBoardWidget()
-{
-    SKGTRACEINFUNC(10)
-}
+SKGScheduledBoardWidget::~SKGScheduledBoardWidget(){SKGTRACEINFUNC(10)}
 
 QString SKGScheduledBoardWidget::getState()
 {
-    QDomDocument doc(QLatin1String("SKGML"));
-    QDomElement root = doc.createElement(QLatin1String("parameters"));
+    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomElement root = doc.createElement(QStringLiteral("parameters"));
     doc.appendChild(root);
 
-    root.setAttribute(QLatin1String("daysmax"), (m_daysmax != nullptr ? m_daysmax->currentData().toString() : QLatin1String("30")));
+    root.setAttribute(QStringLiteral("daysmax"), (m_daysmax != nullptr ? m_daysmax->currentData().toString() : QStringLiteral("30")));
     return doc.toString();
 }
 
-void SKGScheduledBoardWidget::setState(const QString& iState)
+void SKGScheduledBoardWidget::setState(const QString &iState)
 {
-    QDomDocument doc(QLatin1String("SKGML"));
+    QDomDocument doc(QStringLiteral("SKGML"));
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
-    QString daysmax = root.attribute(QLatin1String("daysmax"));
+    QString daysmax = root.attribute(QStringLiteral("daysmax"));
     if (daysmax.isEmpty()) {
-        daysmax = QLatin1String("30");
+        daysmax = QStringLiteral("30");
     }
     if (m_daysmax != nullptr && !daysmax.isEmpty()) {
         m_daysmax->setCurrentIndex(m_daysmax->findData(daysmax));
     }
 }
 
-void SKGScheduledBoardWidget::dataModified(const QString& iTableName, int iIdTransaction)
+void SKGScheduledBoardWidget::dataModified(const QString &iTableName, int iIdTransaction)
 {
-    m_Report->addParameter(QLatin1String("scheduled_operation_days_max"), m_daysmax->currentData());
+    m_Report->addParameter(QStringLiteral("scheduled_operation_days_max"), m_daysmax->currentData());
     SKGHtmlBoardWidget::dataModified(iTableName, iIdTransaction);
 }
