@@ -13,7 +13,6 @@
 #include <kaboutdata.h>
 #include <kactioncollection.h>
 #include <kpluginfactory.h>
-#include <ktoolbarpopupaction.h>
 
 #include <qstandardpaths.h>
 
@@ -81,8 +80,9 @@ bool SKGScheduledPlugin::setupActions(SKGDocument *iDocument)
                          410);
 
     auto actAssignScheduleAction =
-        new KToolBarPopupAction(SKGServices::fromTheme(QStringLiteral("edit-guides")), i18nc("Verb, action to assign a schedule", "Assign schedule"), this);
-    m_assignScheduleMenu = actAssignScheduleAction->popupMenu();
+        new QAction(SKGServices::fromTheme(QStringLiteral("edit-guides")), i18nc("Verb, action to assign a schedule", "Assign schedule"), this);
+    m_assignScheduleMenu = new QMenu();
+    actAssignScheduleAction->setMenu(m_assignScheduleMenu);
     connect(m_assignScheduleMenu, &QMenu::aboutToShow, this, &SKGScheduledPlugin::onShowAssignScheduleMenu);
     actAssignScheduleAction->setData(1);
     registerGlobalAction(QStringLiteral("edit_assign_schedule"), actAssignScheduleAction, listOperation, 1, -1, 412);
