@@ -42,7 +42,7 @@ SKGSearchPluginWidget::SKGSearchPluginWidget(QWidget *iParent, SKGDocument *iDoc
 
     ui.kView->getShowWidget()->addItem(QStringLiteral("search"),
                                        i18nc("Noun, a search", "Search"),
-                                       QStringLiteral("edit-find"),
+                                       QStringLiteral("system-search"),
                                        QStringLiteral("t_action_type='S'"),
                                        QString(),
                                        QString(),
@@ -91,7 +91,7 @@ SKGSearchPluginWidget::SKGSearchPluginWidget(QWidget *iParent, SKGDocument *iDoc
     // Add Standard KDE Icons to buttons
     ui.kUpdate->setIcon(SKGServices::fromTheme(QStringLiteral("dialog-ok")));
     ui.kAdd->setIcon(SKGServices::fromTheme(QStringLiteral("list-add")));
-    ui.kSearch->setIcon(SKGServices::fromTheme(QStringLiteral("edit-find")));
+    ui.kSearch->setIcon(SKGServices::fromTheme(QStringLiteral("system-search")));
     QStringList overlayopen;
     overlayopen.push_back(QStringLiteral("quickopen"));
     ui.kOpenReport->setIcon(SKGServices::fromTheme(QStringLiteral("view-statistics"), overlayopen));
@@ -105,7 +105,10 @@ SKGSearchPluginWidget::SKGSearchPluginWidget(QWidget *iParent, SKGDocument *iDoc
         SKGWidgetSelector::SKGListQWidget list;
         list.push_back(ui.kQueryGrp);
         list.push_back(ui.kBtnFrm);
-        ui.kWidgetSelector->addButton(SKGServices::fromTheme(QStringLiteral("edit-find")), i18n("Search"), i18n("Display the edit panel for searches"), list);
+        ui.kWidgetSelector->addButton(SKGServices::fromTheme(QStringLiteral("system-search")),
+                                      i18n("Search"),
+                                      i18n("Display the edit panel for searches"),
+                                      list);
     }
     {
         SKGWidgetSelector::SKGListQWidget list;
@@ -664,7 +667,7 @@ void SKGSearchPluginWidget::open(const SKGRuleObject &iRule, OpenMode iMode)
 
     root.setAttribute(QStringLiteral("operationWhereClause"), wc);
     root.setAttribute(QStringLiteral("title"), title);
-    root.setAttribute(QStringLiteral("title_icon"), QStringLiteral("edit-find"));
+    root.setAttribute(QStringLiteral("title_icon"), QStringLiteral("system-search"));
 
     if (iMode == TABLE) {
         root.setAttribute(QStringLiteral("operationTable"), QStringLiteral("v_suboperation_consolidated"));
