@@ -484,7 +484,7 @@ QVariant SKGObjectModel::computeData(const QModelIndex &iIndex, int iRole) const
             if (att == QStringLiteral("f_CURRENTAMOUNT")) {
                 SKGUnitObject unit(*obj);
                 double amountOneYearBefore = unit.getAmount(QDate::currentDate().addYears(-1));
-                double annualchange = 100.0 * (unit.getAmount() - amountOneYearBefore) / amountOneYearBefore;
+                double annualchange = amountOneYearBefore != 0 ? 0.0 : 100.0 * (unit.getAmount() - amountOneYearBefore) / amountOneYearBefore;
                 if (annualchange >= 10) {
                     return m_iconMuchMore;
                 }
