@@ -42,8 +42,11 @@ public:
      * @param iModeUpdate to enable mode update
      * @param iListAtt list of attribute
      */
-    explicit SKGPredicatCreator(QWidget* iParent, SKGDocument* document, const QString& attribute = QString(),
-                                bool iModeUpdate = false, const QStringList& iListAtt = QStringList());
+    explicit SKGPredicatCreator(QWidget *iParent,
+                                SKGDocument *document,
+                                const QString &attribute = QString(),
+                                bool iModeUpdate = false,
+                                const QStringList &iListAtt = QStringList());
 
     /**
      * Default Destructor
@@ -60,7 +63,7 @@ public:
      * Get Text from XML description
      * @param iXML the description
      */
-    static QString getTextFromXml(const QString& iXML);
+    static QString getTextFromXml(const QString &iXML);
 
     /**
      * Get XML description
@@ -72,7 +75,7 @@ public:
      * Set XML description
      * @param iXML the description
      */
-    virtual void setXmlDescription(const QString& iXML);
+    virtual void setXmlDescription(const QString &iXML);
 
 Q_SIGNALS:
     /**
@@ -85,14 +88,15 @@ Q_SIGNALS:
      */
     void xmlDescriptionChanged();
 
-protected :
+protected:
     /**
      * Event filtering
      * @param iObject object
      * @param iEvent event
-     * @return In your reimplementation of this function, if you want to filter the event out, i.e. stop it being handled further, return true; otherwise return false.
+     * @return In your reimplementation of this function, if you want to filter the event out, i.e. stop it being handled further, return true; otherwise return
+     * false.
      */
-    bool eventFilter(QObject* iObject, QEvent* iEvent) override;
+    bool eventFilter(QObject *iObject, QEvent *iEvent) override;
 
 private Q_SLOTS:
     void onOperatorChanged();
@@ -101,10 +105,10 @@ private:
     Q_DISABLE_COPY(SKGPredicatCreator)
     bool m_updateMode;
 
-    SKGComboBox* m_kOperator;
-    QWidget* m_kValue1;
-    QWidget* m_kValue2;
-    SKGComboBox* m_kAttributes;
+    SKGComboBox *m_kOperator;
+    QWidget *m_kValue1;
+    QWidget *m_kValue2;
+    SKGComboBox *m_kAttributes;
 };
 
-#endif  // SKGPREDICATCREATOR_H
+#endif // SKGPREDICATCREATOR_H
