@@ -28,7 +28,7 @@
         connect(act, &QAction::triggered, this, &SKGQueryCreator::onAddText);                                                                                  \
     }
 
-SKGQueryCreator::SKGQueryCreator(QWidget *iParent)
+SKGQueryCreator::SKGQueryCreator(QWidget *iParent, bool iDisableAdvancedMode)
     : QWidget(iParent)
     , m_document(nullptr)
     , m_updateMode(false)
@@ -43,6 +43,9 @@ SKGQueryCreator::SKGQueryCreator(QWidget *iParent)
     ui.kToolHelp->setIcon(SKGServices::fromTheme(QStringLiteral("dialog-information")));
     ui.kCheckMode->setIcon(SKGServices::fromTheme(QStringLiteral("arrow-down")));
     ui.kCheckMode->setToolTip(i18nc("A tool tip", "Switch in advanced mode"));
+    if (iDisableAdvancedMode) {
+        ui.kCheckMode->setVisible(false);
+    }
 
     connect(ui.kFilterEdit, &QLineEdit::textChanged, this, &SKGQueryCreator::onTextFilterChanged);
     connect(ui.kCheckMode, &QToolButton::clicked, this, &SKGQueryCreator::switchAdvancedSearchMode);
@@ -127,7 +130,8 @@ void SKGQueryCreator::setParameters(SKGDocument *iDocument, const QString &iTabl
     m_attributes = iListAttribute;
 
     setAdvancedSearchMode(m_updateMode);
-    ui.kCheckMode->setVisible(!m_updateMode);
+    if (m_updateMode)
+        ui.kCheckMode->setVisible(false);
 
     //     QString txt=(updateMode ? i18nc("Description", "Double click on a field name to add it to your modification definition.") : i18nc("Description",
     //     "Double click on a field name to add it to your search definition."))+'\n'+i18nc("Description", "Double click on a cell to modify it.");
