@@ -27,13 +27,13 @@ class SKGBANKMODELER_EXPORT SKGDocumentBank : public SKGDocument
 
 public:
     /**
-    * Constructor
-    */
+     * Constructor
+     */
     explicit SKGDocumentBank();
 
     /**
-    * Destructor
-    */
+     * Destructor
+     */
     ~SKGDocumentBank() override;
 
     /**
@@ -56,7 +56,7 @@ public:
      * @return an object managing the error.
      *   @see SKGError
      */
-    virtual SKGError addOrModifyAccount(const QString& iName, const QString& iNumber, const QString& iBankName) const;
+    virtual SKGError addOrModifyAccount(const QString &iName, const QString &iNumber, const QString &iBankName) const;
 
     /**
      * Create or modify the value of an unit
@@ -68,7 +68,7 @@ public:
      *   @see SKGError
      */
     // cppcheck-suppress passedByValue
-    virtual SKGError addOrModifyUnitValue(const QString& iUnitName, QDate iDate, double iValue, SKGUnitValueObject* oValue = nullptr) const;
+    virtual SKGError addOrModifyUnitValue(const QString &iUnitName, QDate iDate, double iValue, SKGUnitValueObject *oValue = nullptr) const;
 
     /**
      * Get Primary unit. WARNING: This value can be not uptodated in a transaction.
@@ -83,12 +83,12 @@ public:
     virtual SKGServices::SKGUnitInfo getSecondaryUnit() const;
 
     /**
-    * Get the preferred category for a payee. WARNING: This value can be not uptodated in a transaction.
-    * @param iPayee the payee
-    * @param iComputeAllPayees compute all categories for all payees and put them in cache. This is better when you know that you will need all.
-    * @return The preferred category.
-    */
-    virtual QString getCategoryForPayee(const QString& iPayee, bool iComputeAllPayees = true) const;
+     * Get the preferred category for a payee. WARNING: This value can be not uptodated in a transaction.
+     * @param iPayee the payee
+     * @param iComputeAllPayees compute all categories for all payees and put them in cache. This is better when you know that you will need all.
+     * @return The preferred category.
+     */
+    virtual QString getCategoryForPayee(const QString &iPayee, bool iComputeAllPayees = true) const;
 
     /**
      * Return the number version of views, indexes and triggers
@@ -101,34 +101,34 @@ public:
      * @param iRealTable the real table name
      * @return list of schemas
      */
-    SKGDocument::SKGModelTemplateList getDisplaySchemas(const QString& iRealTable) const override;
+    SKGDocument::SKGModelTemplateList getDisplaySchemas(const QString &iRealTable) const override;
 
     /**
      * Get the display string for any modeler object (table, attribute)
      * @param iString the name of the object (example: v_operation, v_unit.t_name)
      * @return the display string
      */
-    QString getDisplay(const QString& iString) const override;
+    QString getDisplay(const QString &iString) const override;
 
     /**
      * Get the real attribute
      * @param iString the name of the attribute (something like t_BANK)
      * @return the real attribute (something like bank.rd_bank_id.t_name)
      */
-    QString getRealAttribute(const QString& iString) const override;
+    QString getRealAttribute(const QString &iString) const override;
     /**
      * Get the icon for attribute
      * @param iString the name of the attribute
      * @return the icon name
      */
-    QString getIconName(const QString& iString) const override;
+    QString getIconName(const QString &iString) const override;
 
     /**
      * Get the attribute type
      * @param iAttributeName the name of an attribute
      * @return the type
      */
-    SKGServices::AttributeType getAttributeType(const QString& iAttributeName) const override;
+    SKGServices::AttributeType getAttributeType(const QString &iAttributeName) const override;
 
     /**
      * Get the file extension for this kind of document (must be overwritten)
@@ -147,7 +147,7 @@ public:
      * @param iMonth the month
      * @return the report
      */
-    virtual QVariantList getBudget(const QString& iMonth) const;
+    virtual QVariantList getBudget(const QString &iMonth) const;
 
     /**
      * Get main categories report
@@ -155,7 +155,7 @@ public:
      * @param iNb number of categories
      * @return the report
      */
-    virtual QVariantList getMainCategories(const QString& iPeriod, int iNb = 5);
+    virtual QVariantList getMainCategories(const QString &iPeriod, int iNb = 5);
 
     /**
      * Get 5 main variation of categories report
@@ -165,14 +165,15 @@ public:
      * @param oCategoryList to get the category for each variation
      * @return the list of variation string
      */
-    virtual QStringList get5MainCategoriesVariationList(const QString& iPeriod, const QString& iPreviousPeriod, bool iOnlyIssues, QStringList* oCategoryList = nullptr);
+    virtual QStringList
+    get5MainCategoriesVariationList(const QString &iPeriod, const QString &iPreviousPeriod, bool iOnlyIssues, QStringList *oCategoryList = nullptr);
 
     /**
      * Get the report
      * Do not forget to delete the pointer
      * @return the report
      */
-    SKGReport* getReport() const override;
+    SKGReport *getReport() const override;
 
     /**
      * Refresh all views and indexes in the database
@@ -183,18 +184,18 @@ public:
     SKGError refreshViewsIndexesAndTriggers(bool iForce = false) const override;
 
     /**
-     * Get formated money in primary unit
+     * Get formatted money in primary unit
      * @param iValue value
      * @param iForcedNbOfDigit the number of digit (-1 means nb of digit of the unit)
-     * @return formated value in red or black
+     * @return formatted value in red or black
      */
     Q_INVOKABLE QString formatPrimaryMoney(double iValue, int iForcedNbOfDigit = -1) const override;
 
     /**
-     * Get formated money in primary unit
+     * Get formatted money in primary unit
      * @param iValue value
      * @param iForcedNbOfDigit the number of digit (-1 means nb of digit of the unit)
-     * @return formated value in red or black
+     * @return formatted value in red or black
      */
     Q_INVOKABLE QString formatSecondaryMoney(double iValue, int iForcedNbOfDigit = -1) const override;
 
@@ -220,7 +221,7 @@ public Q_SLOTS:
      * Refresh the case.
      * @param iTable the modified table triggering the cache refresh.
      */
-    void refreshCache(const QString& iTable) const override;
+    void refreshCache(const QString &iTable) const override;
 
 protected:
     /**
@@ -231,7 +232,7 @@ protected:
      * @return an object managing the error.
      *   @see SKGError
      */
-    SKGError migrate(bool& oMigrationDone) override;
+    SKGError migrate(bool &oMigrationDone) override;
 
     /**
      * Compute balance of each transaction.
