@@ -81,8 +81,8 @@ QString SKGImportExportManager::getLocalFileName(bool iDownload)
             } else {
                 QTemporaryFile tmpFile;
                 tmpFile.setAutoRemove(false);
-                tmpFile.open();
-                m_localFileName = tmpFile.fileName();
+                if (tmpFile.open())
+                    m_localFileName = tmpFile.fileName();
             }
         }
     }
