@@ -10,11 +10,11 @@
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
+#include <qdom.h>
 #include <qmap.h>
 #include <qobject.h>
 #include <qstringlist.h>
 #include <qurl.h>
-#include <qdom.h>
 
 #include "skgaccountobject.h"
 #include "skgbankmodeler_export.h"
@@ -38,8 +38,7 @@ public:
      * @param iDocument the document
      * @param iFileName the file name
      */
-    explicit SKGImportExportManager(SKGDocumentBank* iDocument = nullptr,
-                                    const QUrl& iFileName = QUrl(QLatin1String("")));
+    explicit SKGImportExportManager(SKGDocumentBank *iDocument = nullptr, const QUrl &iFileName = QUrl(QString()));
 
     /**
      * Destructor
@@ -50,7 +49,7 @@ public:
      * Set the codec used for imports.
      * @param iCodec the codec name.
      */
-    inline void setCodec(const QString& iCodec)
+    inline void setCodec(const QString &iCodec)
     {
         m_codec = iCodec;
     }
@@ -70,7 +69,7 @@ public:
      * @return an object managing the error.
      *   @see SKGError
      */
-    SKGError setDefaultAccount(SKGAccountObject* iAccount);
+    SKGError setDefaultAccount(SKGAccountObject *iAccount);
 
     /**
      * Set the default unit for import in case of unit is not detected in imported file.
@@ -78,7 +77,7 @@ public:
      * @return an object managing the error.
      *   @see SKGError
      */
-    SKGError setDefaultUnit(SKGUnitObject* iUnit);
+    SKGError setDefaultUnit(SKGUnitObject *iUnit);
 
     /**
      * Enable/disable the automatically validation of imported transactions.
@@ -99,9 +98,9 @@ public:
     void setAutomaticApplyRules(bool iApply);
 
     /**
-    * get the automatic apply rules state
-    * @return The automatic apply rules state.
-    */
+     * get the automatic apply rules state
+     * @return The automatic apply rules state.
+     */
     bool automaticApplyRules() const;
 
     /**
@@ -111,9 +110,9 @@ public:
     void setSinceLastImportDate(bool iSinceLast);
 
     /**
-    * get the since last import state
-    * @return The since last import state.
-    */
+     * get the since last import state
+     * @return The since last import state.
+     */
     bool sinceLastImportDate() const;
 
     /**
@@ -126,7 +125,7 @@ public:
      * Set parameters for Export
      * @param iParameters the parameters
      */
-    void setExportParameters(const QMap<QString, QString>& iParameters);
+    void setExportParameters(const QMap<QString, QString> &iParameters);
 
     /**
      * Get parameters for Import
@@ -138,13 +137,13 @@ public:
      * Set parameters for Import
      * @param iParameters the parameters
      */
-    void setImportParameters(const QMap<QString, QString>& iParameters);
+    void setImportParameters(const QMap<QString, QString> &iParameters);
 
     /**
      * Get the default value of a parameter
      * @param iParameter the parameter
      */
-    QString getParameterDefaultValue(const QString& iParameter);
+    QString getParameterDefaultValue(const QString &iParameter);
 
     /**
      * Get the mime type filter for import
@@ -181,7 +180,7 @@ public:
      * @return an object managing the error.
      *   @see SKGError
      */
-    SKGError anonymize(const QString& iKey);
+    SKGError anonymize(const QString &iKey);
 
     /**
      * Find and group transactions
@@ -190,7 +189,7 @@ public:
      * @return an object managing the error.
      *   @see SKGError
      */
-    SKGError findAndGroupTransfers(int& oNbOperationsMerged, const QString& iAdditionnalCondition);
+    SKGError findAndGroupTransfers(int &oNbOperationsMerged, const QString &iAdditionnalCondition);
 
     /**
      * Find and group transactions
@@ -199,7 +198,7 @@ public:
      * @return an object managing the error.
      *   @see SKGError
      */
-    SKGError findAndGroupTransfers(int& oNbOperationsMerged, bool iOnCurrentlyImport = false);
+    SKGError findAndGroupTransfers(int &oNbOperationsMerged, bool iOnCurrentlyImport = false);
 
     /**
      * Clean transactions after an import coming from bank's web sites
@@ -212,7 +211,7 @@ public:
      * Get the document
      * @return the document.
      */
-    inline SKGDocumentBank* getDocument()
+    inline SKGDocumentBank *getDocument()
     {
         return m_document;
     }
@@ -242,7 +241,7 @@ public:
      * @return an object managing the error.
      *   @see SKGError
      */
-    SKGError getDefaultAccount(SKGAccountObject& oAccount);
+    SKGError getDefaultAccount(SKGAccountObject &oAccount);
 
     /**
      * Return the preferred unit for a date for import
@@ -255,7 +254,7 @@ public:
      * @return an object managing the error.
      *   @see SKGError
      */
-    SKGError getDefaultUnit(SKGUnitObject& oUnit, const QDate* iDate = nullptr);
+    SKGError getDefaultUnit(SKGUnitObject &oUnit, const QDate *iDate = nullptr);
 
     /**
      * Finalize an import by changing state and applying rules
@@ -268,7 +267,7 @@ public:
      * @param iAccount the account.
      * @param iBalance the balance.
      */
-    void addAccountToCheck(const SKGAccountObject& iAccount, double iBalance);
+    void addAccountToCheck(const SKGAccountObject &iAccount, double iBalance);
 
     /**
      * get accounts to check
@@ -282,30 +281,29 @@ public:
      * @return an object managing the error.
      *   @see SKGError
      */
-    SKGError importItems(QDomElement& docElem);
+    SKGError importItems(QDomElement &docElem);
 
 private:
     Q_DISABLE_COPY(SKGImportExportManager)
 
-
-    SKGImportPlugin* getImportPlugin();
-    SKGImportPlugin* getExportPlugin();
+    SKGImportPlugin *getImportPlugin();
+    SKGImportPlugin *getExportPlugin();
 
     void loadPlugins();
     QMap<QString, SKGObjectBase> m_mapIdObject;
-    SKGDocumentBank* m_document;
+    SKGDocumentBank *m_document;
     QUrl m_fileName;
     QString m_localFileName;
-    SKGAccountObject* m_defaultAccount;
-    SKGUnitObject* m_defaultUnit;
+    SKGAccountObject *m_defaultAccount;
+    SKGUnitObject *m_defaultUnit;
     QString m_codec;
     bool m_automaticValidationOfImportedOperation{};
     bool m_automaticApplyRulesOfImportedOperation{};
     bool m_since_last_import;
-    SKGImportPlugin* m_importPlugin;
-    SKGImportPlugin* m_exportPlugin;
+    SKGImportPlugin *m_importPlugin;
+    SKGImportPlugin *m_exportPlugin;
     QList<QPair<SKGAccountObject, double>> m_AccountToCheck;
-    QList<SKGImportPlugin*> m_plugins;
+    QList<SKGImportPlugin *> m_plugins;
 };
 
 #endif
