@@ -145,25 +145,159 @@ SKGRecurrentOperationObject::PeriodUnit SKGRecurrentOperationObject::getPeriodUn
 {
     QString t_period_unit = getAttribute(QStringLiteral("t_period_unit"));
     if (t_period_unit == QStringLiteral("D")) {
-        return SKGRecurrentOperationObject::DAY;
+        return DAY;
     }
     if (t_period_unit == QStringLiteral("W")) {
-        return SKGRecurrentOperationObject::WEEK;
+        return WEEK;
     }
     if (t_period_unit == QStringLiteral("M")) {
-        return SKGRecurrentOperationObject::MONTH;
+        return MONTH;
     }
-    return SKGRecurrentOperationObject::YEAR;
+    return YEAR;
 }
 
 SKGError SKGRecurrentOperationObject::setPeriodUnit(SKGRecurrentOperationObject::PeriodUnit iPeriod)
 {
     return setAttribute(
         QStringLiteral("t_period_unit"),
-        (iPeriod == SKGRecurrentOperationObject::DAY
-             ? QStringLiteral("D")
-             : (iPeriod == SKGRecurrentOperationObject::WEEK ? QStringLiteral("W")
-                                                             : (iPeriod == SKGRecurrentOperationObject::MONTH ? QStringLiteral("M") : QStringLiteral("Y")))));
+        (iPeriod == DAY ? QStringLiteral("D") : (iPeriod == WEEK ? QStringLiteral("W") : (iPeriod == MONTH ? QStringLiteral("M") : QStringLiteral("Y")))));
+}
+
+SKGRecurrentOperationObject::Adapter SKGRecurrentOperationObject::getAdapter() const
+{
+    QString t_adapter = getAttribute(QStringLiteral("t_adapter"));
+    if (t_adapter == QStringLiteral("P1")) {
+        return PREVIOUS_MONDAY;
+    }
+    if (t_adapter == QStringLiteral("P2")) {
+        return PREVIOUS_TUESDAY;
+    }
+    if (t_adapter == QStringLiteral("P3")) {
+        return PREVIOUS_WEDNESDAY;
+    }
+    if (t_adapter == QStringLiteral("P4")) {
+        return PREVIOUS_THURSDAY;
+    }
+    if (t_adapter == QStringLiteral("P5")) {
+        return PREVIOUS_FRIDAY;
+    }
+    if (t_adapter == QStringLiteral("P6")) {
+        return PREVIOUS_SATURDAY;
+    }
+    if (t_adapter == QStringLiteral("P7")) {
+        return PREVIOUS_SUNDAY;
+    }
+    if (t_adapter == QStringLiteral("C1")) {
+        return CLOSEST_MONDAY;
+    }
+    if (t_adapter == QStringLiteral("C2")) {
+        return CLOSEST_TUESDAY;
+    }
+    if (t_adapter == QStringLiteral("C3")) {
+        return CLOSEST_WEDNESDAY;
+    }
+    if (t_adapter == QStringLiteral("C4")) {
+        return CLOSEST_THURSDAY;
+    }
+    if (t_adapter == QStringLiteral("C5")) {
+        return CLOSEST_FRIDAY;
+    }
+    if (t_adapter == QStringLiteral("C6")) {
+        return CLOSEST_SATURDAY;
+    }
+    if (t_adapter == QStringLiteral("C7")) {
+        return CLOSEST_SUNDAY;
+    }
+    if (t_adapter == QStringLiteral("N1")) {
+        return NEXT_MONDAY;
+    }
+    if (t_adapter == QStringLiteral("N2")) {
+        return NEXT_TUESDAY;
+    }
+    if (t_adapter == QStringLiteral("N3")) {
+        return NEXT_WEDNESDAY;
+    }
+    if (t_adapter == QStringLiteral("N4")) {
+        return NEXT_THURSDAY;
+    }
+    if (t_adapter == QStringLiteral("N5")) {
+        return NEXT_FRIDAY;
+    }
+    if (t_adapter == QStringLiteral("N6")) {
+        return NEXT_SATURDAY;
+    }
+    if (t_adapter == QStringLiteral("N7")) {
+        return NEXT_SUNDAY;
+    }
+    if (t_adapter == QStringLiteral("PO")) {
+        return PREVIOUS_OPEN_DAY;
+    }
+    if (t_adapter == QStringLiteral("CO")) {
+        return CLOSEST_OPEN_DAY;
+    }
+    if (t_adapter == QStringLiteral("NO")) {
+        return NEXT_OPEN_DAY;
+    }
+    if (t_adapter == QStringLiteral("1MO")) {
+        return FIRST_OPEN_DAY_OF_MONTH;
+    }
+    return NONE;
+}
+
+SKGError SKGRecurrentOperationObject::setAdapter(SKGRecurrentOperationObject::Adapter iAdapter)
+{
+    auto t_adapter = QStringLiteral("NONE");
+    if (iAdapter == PREVIOUS_MONDAY)
+        t_adapter = "P1";
+    else if (iAdapter == PREVIOUS_TUESDAY)
+        t_adapter = "P2";
+    else if (iAdapter == PREVIOUS_WEDNESDAY)
+        t_adapter = "P3";
+    else if (iAdapter == PREVIOUS_THURSDAY)
+        t_adapter = "P4";
+    else if (iAdapter == PREVIOUS_FRIDAY)
+        t_adapter = "P5";
+    else if (iAdapter == PREVIOUS_SATURDAY)
+        t_adapter = "P6";
+    else if (iAdapter == PREVIOUS_SUNDAY)
+        t_adapter = "P7";
+    else if (iAdapter == CLOSEST_MONDAY)
+        t_adapter = "C1";
+    else if (iAdapter == CLOSEST_TUESDAY)
+        t_adapter = "C2";
+    else if (iAdapter == CLOSEST_WEDNESDAY)
+        t_adapter = "C3";
+    else if (iAdapter == CLOSEST_THURSDAY)
+        t_adapter = "C4";
+    else if (iAdapter == CLOSEST_FRIDAY)
+        t_adapter = "C5";
+    else if (iAdapter == CLOSEST_SATURDAY)
+        t_adapter = "C6";
+    else if (iAdapter == CLOSEST_SUNDAY)
+        t_adapter = "C7";
+    else if (iAdapter == NEXT_MONDAY)
+        t_adapter = "N1";
+    else if (iAdapter == NEXT_TUESDAY)
+        t_adapter = "N2";
+    else if (iAdapter == NEXT_WEDNESDAY)
+        t_adapter = "N3";
+    else if (iAdapter == NEXT_THURSDAY)
+        t_adapter = "N4";
+    else if (iAdapter == NEXT_FRIDAY)
+        t_adapter = "N5";
+    else if (iAdapter == NEXT_SATURDAY)
+        t_adapter = "N6";
+    else if (iAdapter == NEXT_SUNDAY)
+        t_adapter = "N7";
+    else if (iAdapter == PREVIOUS_OPEN_DAY)
+        t_adapter = "PO";
+    else if (iAdapter == CLOSEST_OPEN_DAY)
+        t_adapter = "CO";
+    else if (iAdapter == NEXT_OPEN_DAY)
+        t_adapter = "NO";
+    else if (iAdapter == FIRST_OPEN_DAY_OF_MONTH)
+        t_adapter = "1MO";
+    return setAttribute(QStringLiteral("t_adapter"), t_adapter);
 }
 
 SKGError SKGRecurrentOperationObject::setAutoWriteDays(int iDays)
@@ -203,18 +337,18 @@ SKGError SKGRecurrentOperationObject::setTimeLimit(QDate iLastDate)
     if (iLastDate < firstDate) {
         return setTimeLimit(0);
     }
-    SKGRecurrentOperationObject::PeriodUnit period = this->getPeriodUnit();
+    PeriodUnit period = this->getPeriodUnit();
     int occu = qMax(this->getPeriodIncrement(), 1);
 
     // Compute nb time
     int nbd = firstDate.daysTo(iLastDate);
-    if (period == SKGRecurrentOperationObject::DAY) {
+    if (period == DAY) {
         nbd = nbd / occu;
-    } else if (period == SKGRecurrentOperationObject::WEEK) {
+    } else if (period == WEEK) {
         nbd = nbd / (7 * occu);
-    } else if (period == SKGRecurrentOperationObject::MONTH) {
+    } else if (period == MONTH) {
         nbd = (iLastDate.day() >= firstDate.day() ? 0 : -1) + (iLastDate.year() - firstDate.year()) * 12 + (iLastDate.month() - firstDate.month());
-    } else if (period == SKGRecurrentOperationObject::YEAR) {
+    } else if (period == YEAR) {
         nbd = nbd / (365 * occu);
     }
 
@@ -241,18 +375,72 @@ SKGError SKGRecurrentOperationObject::setDate(QDate iDate)
 
 QDate SKGRecurrentOperationObject::getNextDate() const
 {
+    // Compute next date
     QDate nextDate = getDate();
-    SKGRecurrentOperationObject::PeriodUnit punit = getPeriodUnit();
+    PeriodUnit punit = getPeriodUnit();
     int p = getPeriodIncrement();
-    if (punit == SKGRecurrentOperationObject::DAY) {
+    if (punit == DAY) {
         nextDate = nextDate.addDays(p);
-    } else if (punit == SKGRecurrentOperationObject::WEEK) {
+    } else if (punit == WEEK) {
         nextDate = nextDate.addDays(7 * p);
-    } else if (punit == SKGRecurrentOperationObject::MONTH) {
+    } else if (punit == MONTH) {
         nextDate = nextDate.addMonths(p);
-    } else if (punit == SKGRecurrentOperationObject::YEAR) {
+    } else if (punit == YEAR) {
         nextDate = nextDate.addYears(p);
     }
+
+    // Apply the adapter
+    QDate nextDateAdapted = nextDate;
+    const auto adapter = getAdapter();
+    if (adapter >= PREVIOUS_MONDAY && adapter <= PREVIOUS_SUNDAY) {
+        int targetWeekDay = (adapter - PREVIOUS_MONDAY + 1);
+        int diff = (nextDateAdapted.dayOfWeek() - targetWeekDay + 7) % 7;
+        nextDateAdapted = nextDateAdapted.addDays(-diff);
+    } else if (adapter >= NEXT_MONDAY && adapter <= NEXT_SUNDAY) {
+        int targetWeekDay = (adapter - NEXT_MONDAY + 1);
+        int diff = (targetWeekDay - nextDateAdapted.dayOfWeek() + 7) % 7;
+        nextDateAdapted = nextDateAdapted.addDays(diff);
+    } else if (adapter >= CLOSEST_MONDAY && adapter <= CLOSEST_SUNDAY) {
+        int targetWeekDay = (adapter - CLOSEST_MONDAY + 1);
+        int forward = (targetWeekDay - nextDateAdapted.dayOfWeek() + 7) % 7;
+        int backward = (nextDateAdapted.dayOfWeek() - targetWeekDay + 7) % 7;
+        if (backward <= forward) {
+            nextDateAdapted = nextDateAdapted.addDays(-backward);
+        } else {
+            nextDateAdapted = nextDateAdapted.addDays(forward);
+        }
+    } else if (adapter == PREVIOUS_OPEN_DAY) {
+        if (nextDateAdapted.dayOfWeek() == Qt::Saturday) {
+            nextDateAdapted = nextDateAdapted.addDays(-1);
+        } else if (nextDateAdapted.dayOfWeek() == Qt::Sunday) {
+            nextDateAdapted = nextDateAdapted.addDays(-2);
+        }
+    } else if (adapter == NEXT_OPEN_DAY) {
+        if (nextDateAdapted.dayOfWeek() == Qt::Saturday) {
+            nextDateAdapted = nextDateAdapted.addDays(2);
+        } else if (nextDateAdapted.dayOfWeek() == Qt::Sunday) {
+            nextDateAdapted = nextDateAdapted.addDays(1);
+        }
+    } else if (adapter == CLOSEST_OPEN_DAY) {
+        if (nextDateAdapted.dayOfWeek() == Qt::Saturday) {
+            nextDateAdapted = nextDateAdapted.addDays(-1);
+        } else if (nextDateAdapted.dayOfWeek() == Qt::Sunday) {
+            nextDateAdapted = nextDateAdapted.addDays(1);
+        }
+    } else if (adapter == FIRST_OPEN_DAY_OF_MONTH) {
+        nextDateAdapted = QDate(nextDateAdapted.year(), nextDateAdapted.month(), 1);
+        SKGTRACE << "First day of month is (before) " << nextDateAdapted.toString() << Qt::endl;
+        if (nextDateAdapted.dayOfWeek() == Qt::Saturday) {
+            nextDateAdapted = nextDateAdapted.addDays(2);
+        } else if (nextDateAdapted.dayOfWeek() == Qt::Sunday) {
+            nextDateAdapted = nextDateAdapted.addDays(1);
+        }
+        SKGTRACE << "First day of month is (after) " << nextDateAdapted.toString() << Qt::endl;
+    }
+    if (nextDateAdapted > getDate()) {
+        nextDate = nextDateAdapted;
+    }
+
     return nextDate;
 }
 
