@@ -22,6 +22,39 @@ class SKGDocumentBank;
 class SKGBANKMODELER_EXPORT SKGRecurrentOperationObject final : public SKGObjectBase
 {
 public:
+    /**
+     * This enumerate defines the adaptation of the date
+     */
+    enum Adapter {
+        NONE = 0,
+        PREVIOUS_MONDAY = 1,
+        PREVIOUS_TUESDAY = 2,
+        PREVIOUS_WEDNESDAY = 3,
+        PREVIOUS_THURSDAY = 4,
+        PREVIOUS_FRIDAY = 5,
+        PREVIOUS_SATURDAY = 6,
+        PREVIOUS_SUNDAY = 7,
+        CLOSEST_MONDAY = 8,
+        CLOSEST_TUESDAY = 9,
+        CLOSEST_WEDNESDAY = 10,
+        CLOSEST_THURSDAY = 11,
+        CLOSEST_FRIDAY = 12,
+        CLOSEST_SATURDAY = 13,
+        CLOSEST_SUNDAY = 14,
+        NEXT_MONDAY = 15,
+        NEXT_TUESDAY = 16,
+        NEXT_WEDNESDAY = 17,
+        NEXT_THURSDAY = 18,
+        NEXT_FRIDAY = 19,
+        NEXT_SATURDAY = 20,
+        NEXT_SUNDAY = 21,
+        PREVIOUS_OPEN_DAY = 22,
+        CLOSEST_OPEN_DAY = 23,
+        NEXT_OPEN_DAY = 24,
+        FIRST_OPEN_DAY_OF_MONTH = 25,
+    };
+    Q_ENUM(Adapter)
+
     /**
      * This enumerate defines the period unit
      */
@@ -124,7 +157,7 @@ public:
 
     /**
      * Get the period unit of this recurrent operation
-     * @return the status
+     * @return the unit
      */
     SKGRecurrentOperationObject::PeriodUnit getPeriodUnit() const;
 
@@ -136,6 +169,20 @@ public:
      */
     SKGError setPeriodUnit(SKGRecurrentOperationObject::PeriodUnit iPeriod);
 
+    /**
+     * Get the adapter of this recurrent operation
+     * @return the adapter
+     */
+    SKGRecurrentOperationObject::Adapter getAdapter() const;
+
+    /**
+     * Set the adapter of this recurrent operation
+     * @param iAdapter the adapter
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    SKGError setAdapter(SKGRecurrentOperationObject::Adapter iAdapter);
+
     /**
      * Set the number of days before term to create operation
      * @param iDays the number of days
