@@ -279,7 +279,7 @@ QVariantList SKGReportBank::getUnitTable()
                         double v1 = unit.getAmount(date1);
                         double v2 = unit.getAmount(date2);
                         QVariantList line2; // clazy:exclude=container-inside-loop
-                        line2 << false << unit.getName() << v1 << v2 << (100.0 * (v2 - v1) / qAbs(v1)) << unit.getSymbol();
+                        line2 << false << unit.getName() << v1 << v2 << (v1 == 0 ? 0.0 : 100.0 * (v2 - v1) / qAbs(v1)) << unit.getSymbol();
                         table << QVariant(line2);
                     }
                 }
@@ -357,8 +357,9 @@ QVariantList SKGReportBank::getAccountTable()
                                     icon = std::move(iconfile);
                                 }
                             }
-                            table.push_back(QVariantList() << false << account.getName() << v1 << v2 << (100.0 * (v2 - v1) / qAbs(v1)) << v3 << v2
-                                                           << (100.0 * (v2 - v3) / qAbs(v3)) << account.getAttribute(QStringLiteral("t_BANK")) << icon);
+                            if (v1 != 0 || v3 != 0)
+                                table.push_back(QVariantList() << false << account.getName() << v1 << v2 << (100.0 * (v2 - v1) / qAbs(v1)) << v3 << v2
+                                                               << (100.0 * (v2 - v3) / qAbs(v3)) << account.getAttribute(QStringLiteral("t_BANK")) << icon);
                             nbAdded++;
                         }
                         sumTypeV1 += v1;
@@ -369,13 +370,15 @@ QVariantList SKGReportBank::getAccountTable()
                         sumV3 += v3;
                     }
 
-                    table.push_back(QVariantList() << true << i18nc("Noun", "Total of %1", currentType) << sumTypeV1 << sumTypeV2
-                                                   << (100.0 * (sumTypeV2 - sumTypeV1) / qAbs(sumTypeV1)) << sumTypeV3 << sumTypeV2
-                                                   << (100.0 * (sumTypeV2 - sumTypeV3) / qAbs(sumTypeV3)) << "" << "");
+                    if (sumTypeV1 != 0 || sumTypeV3 != 0)
+                        table.push_back(QVariantList() << true << i18nc("Noun", "Total of %1", currentType) << sumTypeV1 << sumTypeV2
+                                                       << (100.0 * (sumTypeV2 - sumTypeV1) / qAbs(sumTypeV1)) << sumTypeV3 << sumTypeV2
+                                                       << (100.0 * (sumTypeV2 - sumTypeV3) / qAbs(sumTypeV3)) << "" << "");
 
-                    table.push_back(QVariantList() << true << i18nc("Noun, the numerical total of a sum of values", "Total") << sumV1 << sumV2
-                                                   << (100.0 * (sumV2 - sumV1) / qAbs(sumV1)) << sumV3 << sumV2 << (100.0 * (sumV2 - sumV3) / qAbs(sumV3)) << ""
-                                                   << "");
+                    if (sumV1 != 0 || sumV3 != 0)
+                        table.push_back(QVariantList()
+                                        << true << i18nc("Noun, the numerical total of a sum of values", "Total") << sumV1 << sumV2
+                                        << (100.0 * (sumV2 - sumV1) / qAbs(sumV1)) << sumV3 << sumV2 << (100.0 * (sumV2 - sumV3) / qAbs(sumV3)) << "" << "");
                 }
             }
         }
@@ -465,8 +468,10 @@ QVariantList SKGReportBank::getBankTable()
                                                        << sumTypeV3 << sumTypeV2 << (100.0 * (sumTypeV2 - sumTypeV3) / qAbs(sumTypeV3)) << currentIcon);
                     }
 
-                    table.push_back(QVariantList() << true << i18nc("Noun, the numerical total of a sum of values", "Total") << sumV1 << sumV2
-                                                   << (100.0 * (sumV2 - sumV1) / qAbs(sumV1)) << sumV3 << sumV2 << (100.0 * (sumV2 - sumV3) / qAbs(sumV3)));
+                    if (sumV1 != 0 || sumV3 != 0) {
+                        table.push_back(QVariantList() << true << i18nc("Noun, the numerical total of a sum of values", "Total") << sumV1 << sumV2
+                                                       << (100.0 * (sumV2 - sumV1) / qAbs(sumV1)) << sumV3 << sumV2 << (100.0 * (sumV2 - sumV3) / qAbs(sumV3)));
+                    }
                 }
             }
         }
