@@ -39,12 +39,13 @@ public:
     /**
      * Process mode
      */
-    enum ProcessMode {ALL,
-                      NOTCHECKED,
-                      IMPORTED,
-                      IMPORTEDNOTVALIDATE,
-                      IMPORTING
-                     };
+    enum ProcessMode {
+        ALL,
+        NOTCHECKED,
+        IMPORTED,
+        IMPORTEDNOTVALIDATE,
+        IMPORTING
+    };
     /**
      * Process mode
      */
@@ -53,11 +54,12 @@ public:
     /**
      * Action type
      */
-    enum ActionType {SEARCH,
-                     UPDATE,
-                     ALARM,
-                     APPLYTEMPLATE
-                    };
+    enum ActionType {
+        SEARCH,
+        UPDATE,
+        ALARM,
+        APPLYTEMPLATE
+    };
     /**
      * Action type
      */
@@ -73,31 +75,31 @@ public:
      * @param iDocument the document containing the object
      * @param iID the identifier of the object
      */
-    explicit SKGRuleObject(SKGDocument* iDocument, int iID = 0);
+    explicit SKGRuleObject(SKGDocument *iDocument, int iID = 0);
 
     /**
      * Copy constructor
      * @param iObject the object to copy
      */
-    SKGRuleObject(const SKGRuleObject& iObject);
+    SKGRuleObject(const SKGRuleObject &iObject);
 
     /**
      * Copy constructor
      * @param iObject the object to copy
      */
-    explicit SKGRuleObject(const SKGObjectBase& iObject);
+    explicit SKGRuleObject(const SKGObjectBase &iObject);
 
     /**
      * Operator affectation
      * @param iObject the object to copy
      */
-    SKGRuleObject& operator= (const SKGObjectBase& iObject);
+    SKGRuleObject &operator=(const SKGObjectBase &iObject);
 
     /**
      * Operator affectation
      * @param iObject the object to copy
      */
-    SKGRuleObject& operator= (const SKGRuleObject& iObject);
+    SKGRuleObject &operator=(const SKGRuleObject &iObject);
 
     /**
      * Destructor
@@ -124,7 +126,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    SKGError setXMLSearchDefinition(const QString& iXml);
+    SKGError setXMLSearchDefinition(const QString &iXml);
 
     /**
      * Get the XML for the search definition
@@ -147,7 +149,8 @@ public:
      * <!DOCTYPE SKGML>
      *   <element> <!--OR-->
      *     <element>  <!--AND-->
-     *       <element attribute="f_REALCURRENTAMOUNT" operator="ABS(TOTAL(#ATT#))#OP##V1#,ABS(TOTAL(#ATT#)), #V1#, '#V2S#'" value="1000" value2="Take care!"  operator2=">="/>
+     *       <element attribute="f_REALCURRENTAMOUNT" operator="ABS(TOTAL(#ATT#))#OP##V1#,ABS(TOTAL(#ATT#)), #V1#, '#V2S#'" value="1000" value2="Take care!"
+     * operator2=">="/>
      *     </element>
      *   </element>
      * @endcode
@@ -162,7 +165,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    SKGError setXMLActionDefinition(const QString& iXml);
+    SKGError setXMLActionDefinition(const QString &iXml);
 
     /**
      * Get the XML for the action definition
@@ -176,7 +179,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    SKGError setSearchDescription(const QString& iDescription);
+    SKGError setSearchDescription(const QString &iDescription);
 
     /**
      * Get the search description
@@ -190,7 +193,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    SKGError setActionDescription(const QString& iDescription);
+    SKGError setActionDescription(const QString &iDescription);
 
     /**
      * Get the action description
@@ -198,13 +201,12 @@ public:
      */
     QString getActionDescription() const;
 
-
     /**
-    * Set the action type
-    * @param iType the action type
-    * @return an object managing the error
-    *   @see SKGError
-    */
+     * Set the action type
+     * @param iType the action type
+     * @return an object managing the error
+     *   @see SKGError
+     */
     SKGError setActionType(SKGRuleObject::ActionType iType);
 
     /**
@@ -266,7 +268,7 @@ public:
      * @param iAdditionalCondition additional select condition
      * @return the where clause
      */
-    QString getSelectSqlOrder(const QString& iAdditionalCondition = QString()) const;
+    QString getSelectSqlOrder(const QString &iAdditionalCondition = QString()) const;
 
     /**
      * Get alarm info
@@ -283,7 +285,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    static SKGError createPayeeCategoryRule(SKGDocument* iDocument, const QString& iPayee, const QString& iCategory, SKGRuleObject& oRule);
+    static SKGError createPayeeCategoryRule(SKGDocument *iDocument, const QString &iPayee, const QString &iCategory, SKGRuleObject &oRule);
 
     /**
      * Get the list of supported operators
@@ -301,14 +303,14 @@ public:
      * @param iAtt2 attribute number 2
      * @return the NLS display
      */
-    static QString getDisplayForOperator(const QString& iOperator, const QString& iParam1, const QString& iParam2, const QString& iAtt2);
+    static QString getDisplayForOperator(const QString &iOperator, const QString &iParam1, const QString &iParam2, const QString &iAtt2);
 
     /**
      * Get the NLS tooltip of an operator
      * @param iOperator the operator (see @see getListOfOperators)
      * @return the NLS display
      */
-    static QString getToolTipForOperator(const QString& iOperator);
+    static QString getToolTipForOperator(const QString &iOperator);
 
 protected:
     /**
@@ -319,10 +321,11 @@ protected:
      * @param iType mode
      * @return the description
      */
-    static QString getDescriptionFromXML(SKGDocument* iDocument, const QString& iXML, bool iSQL = false, SKGRuleObject::ActionType iType = SEARCH);
+    static QString getDescriptionFromXML(SKGDocument *iDocument, const QString &iXML, bool iSQL = false, SKGRuleObject::ActionType iType = SEARCH);
 
 private:
-    static QStringList getFromXML(SKGDocument* iDocument, const QString& iXML, bool iSQL = false, SKGRuleObject::ActionType iType = SEARCH, bool iFullUpdate = false);
+    static QStringList
+    getFromXML(SKGDocument *iDocument, const QString &iXML, bool iSQL = false, SKGRuleObject::ActionType iType = SEARCH, bool iFullUpdate = false);
 };
 /**
  * Declare the class
