@@ -10,22 +10,21 @@
  */
 #include "skgcolorbutton.h"
 
-SKGColorButton::SKGColorButton(QWidget* iParent)
+SKGColorButton::SKGColorButton(QWidget *iParent)
     : QWidget(iParent)
 {
     ui.setupUi(this);
     connect(ui.button, &KColorButton::changed, this, &SKGColorButton::changed);
 }
 
-SKGColorButton::~SKGColorButton()
-    = default;
+SKGColorButton::~SKGColorButton() = default;
 
 QString SKGColorButton::text() const
 {
     return m_text;
 }
 
-void SKGColorButton::setText(const QString& iText)
+void SKGColorButton::setText(const QString &iText)
 {
     m_text = iText;
     ui.label->setText(iText);
@@ -36,7 +35,7 @@ QColor SKGColorButton::color() const
     return ui.button->color();
 }
 
-void SKGColorButton::setColor(const QColor& iColor)
+void SKGColorButton::setColor(const QColor &iColor)
 {
     ui.button->setColor(iColor);
 }
@@ -46,10 +45,7 @@ QColor SKGColorButton::defaultColor() const
     return ui.button->defaultColor();
 }
 
-void SKGColorButton::setDefaultColor(const QColor& iColor)
+void SKGColorButton::setDefaultColor(const QColor &iColor)
 {
     ui.button->setDefaultColor(iColor);
 }
-
-
-
