@@ -4,9 +4,9 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
-* This file defines classes SKGFlowLayout.
-*
-* @author Stephane MANKOWSKI / Guillaume DE BURE
+ * This file defines classes SKGFlowLayout.
+ *
+ * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgflowlayout.h"
 #include "skgdefine.h"
@@ -15,14 +15,17 @@
 #include <qwidget.h>
 #include <utility>
 
-SKGFlowLayout::SKGFlowLayout(QWidget* iParent, int iMargin, int hSpacing, int vSpacing)
-    : QLayout(iParent), m_hSpace(hSpacing), m_vSpace(vSpacing)
+SKGFlowLayout::SKGFlowLayout(QWidget *iParent, int iMargin, int hSpacing, int vSpacing)
+    : QLayout(iParent)
+    , m_hSpace(hSpacing)
+    , m_vSpace(vSpacing)
 {
     setContentsMargins(iMargin, iMargin, iMargin, iMargin);
 }
 
 SKGFlowLayout::SKGFlowLayout(int iMargin, int hSpacing, int vSpacing)
-    :  m_hSpace(hSpacing), m_vSpace(vSpacing)
+    : m_hSpace(hSpacing)
+    , m_vSpace(vSpacing)
 {
     setContentsMargins(iMargin, iMargin, iMargin, iMargin);
 }
@@ -30,16 +33,16 @@ SKGFlowLayout::SKGFlowLayout(int iMargin, int hSpacing, int vSpacing)
 SKGFlowLayout::~SKGFlowLayout()
 {
     while (count() != 0) {
-        QLayoutItem* child = takeAt(0);
+        QLayoutItem *child = takeAt(0);
         if (child != nullptr) {
-            QWidget* w = child->widget();
+            QWidget *w = child->widget();
             delete w;
             delete child;
         }
     }
 }
 
-void SKGFlowLayout::addItem(QLayoutItem* item)
+void SKGFlowLayout::addItem(QLayoutItem *item)
 {
     m_itemList.append(item);
 }
@@ -71,12 +74,12 @@ int SKGFlowLayout::count() const
     return m_itemList.size();
 }
 
-QLayoutItem* SKGFlowLayout::itemAt(int index) const
+QLayoutItem *SKGFlowLayout::itemAt(int index) const
 {
     return m_itemList.value(index);
 }
 
-QLayoutItem* SKGFlowLayout::takeAt(int index)
+QLayoutItem *SKGFlowLayout::takeAt(int index)
 {
     if (index >= 0 && index < m_itemList.size()) {
         return m_itemList.takeAt(index);
@@ -100,7 +103,7 @@ int SKGFlowLayout::heightForWidth(int width) const
     return height;
 }
 
-void SKGFlowLayout::setGeometry(const QRect& rect)  // clazy:exclude=function-args-by-value
+void SKGFlowLayout::setGeometry(const QRect &rect) // clazy:exclude=function-args-by-value
 {
     QLayout::setGeometry(rect);
     doLayout(rect, false);
@@ -135,7 +138,7 @@ int SKGFlowLayout::doLayout(const QRect rect, bool testOnly) const
     int y1 = y;
 
     for (auto item : std::as_const(m_itemList)) {
-        QWidget* wid = item->widget();
+        QWidget *wid = item->widget();
         if (wid != nullptr) {
             // Get spaces
             int spaceX = horizontalSpacing();
@@ -190,13 +193,13 @@ int SKGFlowLayout::doLayout(const QRect rect, bool testOnly) const
 
 int SKGFlowLayout::smartSpacing(QStyle::PixelMetric pm) const
 {
-    QObject* p = this->parent();
+    QObject *p = this->parent();
     if (p == nullptr) {
         return -1;
     }
     if (p->isWidgetType()) {
-        auto* pw = qobject_cast<QWidget*>(p);
+        auto *pw = qobject_cast<QWidget *>(p);
         return pw->style()->pixelMetric(pm, nullptr, pw);
     }
-    return qobject_cast<QLayout*>(p)->spacing();
+    return qobject_cast<QLayout *>(p)->spacing();
 }
