@@ -4,25 +4,22 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
-* This file defines classes SKGGraphicsScene.
-*
-* @author Stephane MANKOWSKI / Guillaume DE BURE
+ * This file defines classes SKGGraphicsScene.
+ *
+ * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skggraphicsscene.h"
 
-SKGGraphicsScene::SKGGraphicsScene(QObject* iParent)
+SKGGraphicsScene::SKGGraphicsScene(QObject *iParent)
     : QGraphicsScene(iParent)
 {
 }
 
-SKGGraphicsScene::~SKGGraphicsScene()
-    = default;
+SKGGraphicsScene::~SKGGraphicsScene() = default;
 
-void SKGGraphicsScene::mouseDoubleClickEvent(QGraphicsSceneMouseEvent* mouseEvent)
+void SKGGraphicsScene::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *mouseEvent)
 {
     Q_EMIT doubleClicked();
 
     QGraphicsScene::mouseDoubleClickEvent(mouseEvent);
 }
-
-
