@@ -15,13 +15,13 @@
 #include <qqmlcontext.h>
 #include <qquickitem.h>
 #include <qquickwidget.h>
+#include <qregularexpression.h>
 #include <qtoolbutton.h>
 #include <qwidgetaction.h>
-#include <qregularexpression.h>
 
-#include <klocalizedstring.h>
 #include <kcolorscheme.h>
 #include <klineedit.h>
+#include <klocalizedstring.h>
 
 #include "skgdocument.h"
 #include "skgmainpanel.h"
@@ -29,8 +29,23 @@
 #include "skgtraces.h"
 #include <utility>
 
-SKGHtmlBoardWidget::SKGHtmlBoardWidget(QWidget* iParent, SKGDocument* iDocument, const QString& iTitle, const QString& iTemplate, QStringList  iTablesRefreshing, SKGSimplePeriodEdit::Modes iOptions, const QStringList& iAttributesForFilter)
-    : SKGBoardWidget(iParent, iDocument, iTitle), m_Quick(nullptr), m_Report(iDocument->getReport()),  m_Text(nullptr), m_Template(iTemplate), m_TablesRefreshing(std::move(iTablesRefreshing)), m_refreshNeeded(false), m_period(nullptr), m_filter(nullptr), m_attributes(iAttributesForFilter)
+SKGHtmlBoardWidget::SKGHtmlBoardWidget(QWidget *iParent,
+                                       SKGDocument *iDocument,
+                                       const QString &iTitle,
+                                       const QString &iTemplate,
+                                       QStringList iTablesRefreshing,
+                                       SKGSimplePeriodEdit::Modes iOptions,
+                                       const QStringList &iAttributesForFilter)
+    : SKGBoardWidget(iParent, iDocument, iTitle)
+    , m_Quick(nullptr)
+    , m_Report(iDocument->getReport())
+    , m_Text(nullptr)
+    , m_Template(iTemplate)
+    , m_TablesRefreshing(std::move(iTablesRefreshing))
+    , m_refreshNeeded(false)
+    , m_period(nullptr)
+    , m_filter(nullptr)
+    , m_attributes(iAttributesForFilter)
 {
     SKGTRACEINFUNC(10)
     // Create menu
@@ -43,7 +58,10 @@ SKGHtmlBoardWidget::SKGHtmlBoardWidget(QWidget* iParent, SKGDocument* iDocument,
         QDate date = QDate::currentDate();
         QStringList list;
         // TODO(Stephane MANKOWSKI): v_operation_display must be generic
-        getDocument()->getDistinctValues(QLatin1String("v_operation_display"), QLatin1String("MIN(d_DATEMONTH)"), QLatin1String("d_date<=CURRENT_DATE"), list);
+        getDocument()->getDistinctValues(QStringLiteral("v_operation_display"),
+                                         QStringLiteral("MIN(d_DATEMONTH)"),
+                                         QStringLiteral("d_date<=CURRENT_DATE"),
+                                         list);
         if (!list.isEmpty()) {
             if (!list[0].isEmpty()) {
                 date = SKGServices::periodToDate(list[0]);
@@ -73,14 +91,14 @@ SKGHtmlBoardWidget::SKGHtmlBoardWidget(QWidget* iParent, SKGDocument* iDocument,
 
     // Create main widget
     QString ext = QFileInfo(iTemplate).suffix().toLower();
-    if (ext == QLatin1String("qml")) {
+    if (ext == QStringLiteral("qml")) {
         // Mode QML
         m_Quick = new QQuickWidget(this);
         m_Quick->setResizeMode(QQuickWidget::SizeViewToRootObject);
         m_Quick->setClearColor(Qt::transparent);
         m_Quick->setAttribute(Qt::WA_AlwaysStackOnTop);
         m_Quick->setAttribute(Qt::WA_TranslucentBackground);
-        m_Quick->setObjectName(QLatin1String("m_Quick"));
+        m_Quick->setObjectName(QStringLiteral("m_Quick"));
         QSizePolicy newSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
         newSizePolicy.setHorizontalStretch(0);
         newSizePolicy.setVerticalStretch(0);
@@ -89,22 +107,22 @@ SKGHtmlBoardWidget::SKGHtmlBoardWidget(QWidget* iParent, SKGDocument* iDocument,
         // Set properties
         QVariantHash mapping = m_Report->getContextProperty();
         auto keys = mapping.keys();
-        for (const auto& k : std::as_const(keys)) {
+        for (const auto &k : std::as_const(keys)) {
             m_Quick->rootContext()->setContextProperty(k, mapping[k]);
         }
-        m_Quick->rootContext()->setContextProperty(QLatin1String("periodWidget"), m_period);
-        m_Quick->rootContext()->setContextProperty(QLatin1String("filterWidget"), m_filter);
-        m_Quick->rootContext()->setContextProperty(QLatin1String("panel"), SKGMainPanel::getMainPanel());
+        m_Quick->rootContext()->setContextProperty(QStringLiteral("periodWidget"), m_period);
+        m_Quick->rootContext()->setContextProperty(QStringLiteral("filterWidget"), m_filter);
+        m_Quick->rootContext()->setContextProperty(QStringLiteral("panel"), SKGMainPanel::getMainPanel());
 
         setMainWidget(m_Quick);
     } else {
         // Mode template HTML
         m_Text = new QLabel(this);
-        m_Text->setObjectName(QLatin1String("m_Text"));
+        m_Text->setObjectName(QStringLiteral("m_Text"));
         m_Text->setTextFormat(Qt::RichText);
         m_Text->setAlignment(Qt::AlignLeading | Qt::AlignLeft | Qt::AlignTop);
         m_Text->setTextInteractionFlags(Qt::TextBrowserInteraction);
-        connect(m_Text, &QLabel::linkActivated, this, [ = ](const QString & val) {
+        connect(m_Text, &QLabel::linkActivated, this, [](const QString &val) {
             SKGMainPanel::getMainPanel()->openPage(val);
         });
 
@@ -114,7 +132,7 @@ SKGHtmlBoardWidget::SKGHtmlBoardWidget(QWidget* iParent, SKGDocument* iDocument,
     // Connects
     connect(getDocument(), &SKGDocument::tableModified, this, &SKGHtmlBoardWidget::dataModified, Qt::QueuedConnection);
     if (m_period != nullptr) {
-        connect(m_period, static_cast<void (SKGComboBox::*)(const QString&)>(&SKGComboBox::currentTextChanged), this, [ = ]() {
+        connect(m_period, static_cast<void (SKGComboBox::*)(const QString &)>(&SKGComboBox::currentTextChanged), this, [this]() {
             this->dataModified();
         });
     }
@@ -145,46 +163,47 @@ SKGHtmlBoardWidget::~SKGHtmlBoardWidget()
 QString SKGHtmlBoardWidget::getState()
 {
     SKGTRACEINFUNC(10)
-    QDomDocument doc(QLatin1String("SKGML"));
+    QDomDocument doc(QStringLiteral("SKGML"));
     doc.setContent(SKGBoardWidget::getState());
     QDomElement root = doc.documentElement();
 
     // Get state
     if (m_period != nullptr) {
-        root.setAttribute(QLatin1String("period"), m_period->text());
+        root.setAttribute(QStringLiteral("period"), m_period->text());
     }
     if (m_filter != nullptr) {
-        root.setAttribute(QLatin1String("filter"), m_filter->text());
+        root.setAttribute(QStringLiteral("filter"), m_filter->text());
     }
     return doc.toString();
 }
 
-void SKGHtmlBoardWidget::setState(const QString& iState)
+void SKGHtmlBoardWidget::setState(const QString &iState)
 {
     SKGTRACEINFUNC(10)
     SKGBoardWidget::setState(iState);
 
-    QDomDocument doc(QLatin1String("SKGML"));
+    QDomDocument doc(QStringLiteral("SKGML"));
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
     // Set state
     if (m_period != nullptr) {
-        QString oldMode = root.attribute(QLatin1String("previousMonth"));
+        QString oldMode = root.attribute(QStringLiteral("previousMonth"));
         if (oldMode.isEmpty()) {
-            QString period = root.attribute(QLatin1String("period"));
+            QString period = root.attribute(QStringLiteral("period"));
             if (!period.isEmpty() && m_period->contains(period)) {
                 m_period->setText(period);
             }
         } else {
-            m_period->setText(oldMode == QLatin1String("N") ? i18nc("The current month", "Current month") : i18nc("The month before the current month", "Last month"));
+            m_period->setText(oldMode == QStringLiteral("N") ? i18nc("The current month", "Current month")
+                                                             : i18nc("The month before the current month", "Last month"));
         }
     }
     if (m_filter != nullptr) {
-        QString filter = root.attribute(QLatin1String("filter"));
+        QString filter = root.attribute(QStringLiteral("filter"));
         m_filter->setText(filter);
     }
-    dataModified(QLatin1String(""), 0);
+    dataModified(QString(), 0);
 }
 
 void SKGHtmlBoardWidget::setPointSize(int iPointSize) const
@@ -201,10 +220,12 @@ void SKGHtmlBoardWidget::pageChanged()
     }
 }
 
-void SKGHtmlBoardWidget::onTextFilterChanged(const QString& iFilter)
+void SKGHtmlBoardWidget::onTextFilterChanged(const QString &iFilter)
 {
-    auto tooltip = i18nc("Tooltip", "<html><head/><body><p>Searching is case-insensitive. So table, Table, and TABLE are all the same.<br/>"
-                         "If you just put a word or series of words in the search box, the application will filter the table to keep all lines having these words (logical operator AND). <br/>"
+    auto tooltip = i18nc("Tooltip",
+                         "<html><head/><body><p>Searching is case-insensitive. So table, Table, and TABLE are all the same.<br/>"
+                         "If you just put a word or series of words in the search box, the application will filter the table to keep all lines having these "
+                         "words (logical operator AND). <br/>"
                          "If you want to add (logical operator OR) some lines, you must prefix your word by '+'.<br/>"
                          "If you want to remove (logical operator NOT) some lines, you must prefix your word by '-'.<br/>"
                          "If you want to search only on some columns, you must prefix your word by the beginning of column name like: col1:word.<br/>"
@@ -226,43 +247,38 @@ void SKGHtmlBoardWidget::onTextFilterChanged(const QString& iFilter)
                          "Amount&lt;=10 =&gt;Keep lines where at least one attribute starting by Amount is less or equal to 10<br/>"
                          "abc#^d.*f$ =&gt; Keep lines having a column name starting by abc and matching the regular expression ^d.*f$</p>"
                          "<span style=\"font-weight:600; text-decoration: underline;\">Your filter is understood like this:</span><br/>"
-                         "%1</body></html>", SKGServices::searchCriteriasToWhereClause(SKGServices::stringToSearchCriterias(iFilter), m_attributes, getDocument(), true));
+                         "%1</body></html>",
+                         SKGServices::searchCriteriasToWhereClause(SKGServices::stringToSearchCriterias(iFilter), m_attributes, getDocument(), true));
     m_filter->setToolTip(tooltip);
 
     SKGHtmlBoardWidget::dataModified();
 }
 
-void SKGHtmlBoardWidget::dataModified(const QString& iTableName, int iIdTransaction)
+void SKGHtmlBoardWidget::dataModified(const QString &iTableName, int iIdTransaction)
 {
     SKGTRACEINFUNC(10)
     Q_UNUSED(iIdTransaction)
 
     // Set title
-    QString period = (m_period != nullptr ? m_period->period() : QLatin1String(""));
+    QString period = (m_period != nullptr ? m_period->period() : QString());
     QString title = getOriginalTitle();
-    if (title.contains(QLatin1String("%1"))) {
+    if (title.contains(QStringLiteral("%1"))) {
         setMainTitle(title.arg(period));
     }
     QString filterSQL;
     QString filterTXT;
     if (m_Report != nullptr) {
-        m_Report->setPeriod((m_period != nullptr ? m_period->period() : SKGServices::dateToPeriod(QDate::currentDate(), QLatin1String("M"))));
+        m_Report->setPeriod((m_period != nullptr ? m_period->period() : SKGServices::dateToPeriod(QDate::currentDate(), QStringLiteral("M"))));
         if (m_filter) {
-            filterSQL = SKGServices::searchCriteriasToWhereClause(SKGServices::stringToSearchCriterias(m_filter->text()),
-                        m_attributes,
-                        getDocument(),
-                        false);
-            filterTXT = SKGServices::searchCriteriasToWhereClause(SKGServices::stringToSearchCriterias(m_filter->text()),
-                        m_attributes,
-                        getDocument(),
-                        true);
+            filterSQL = SKGServices::searchCriteriasToWhereClause(SKGServices::stringToSearchCriterias(m_filter->text()), m_attributes, getDocument(), false);
+            filterTXT = SKGServices::searchCriteriasToWhereClause(SKGServices::stringToSearchCriterias(m_filter->text()), m_attributes, getDocument(), true);
             m_Report->setSqlFilter(filterSQL);
         }
     }
 
     if (m_TablesRefreshing.isEmpty() || m_TablesRefreshing.contains(iTableName) || iTableName.isEmpty()) {
         // Is this the current page
-        SKGTabPage* page = SKGTabPage::parentTabPage(this);
+        SKGTabPage *page = SKGTabPage::parentTabPage(this);
         if (page != nullptr && page != SKGMainPanel::getMainPanel()->currentPage()) {
             // No, we memorize that we have to compute later the report
             m_refreshNeeded = true;
@@ -271,19 +287,19 @@ void SKGHtmlBoardWidget::dataModified(const QString& iTableName, int iIdTransact
 
         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
         if (m_Quick != nullptr) {
-            m_Quick->rootContext()->setContextProperty(QLatin1String("filterWidget_sql"), filterSQL);
-            m_Quick->rootContext()->setContextProperty(QLatin1String("filterWidget_txt"), filterTXT);
+            m_Quick->rootContext()->setContextProperty(QStringLiteral("filterWidget_sql"), filterSQL);
+            m_Quick->rootContext()->setContextProperty(QStringLiteral("filterWidget_txt"), filterTXT);
 
             // Set the source
             if (!m_Quick->source().isValid()) {
                 m_Quick->setSource(QUrl::fromLocalFile(m_Template));
 
-                QQuickItem* root = m_Quick->rootObject();
+                QQuickItem *root = m_Quick->rootObject();
                 if (root != nullptr) {
-                    connect(root, &QQuickItem::widthChanged, this, [ = ]() {
+                    connect(root, &QQuickItem::widthChanged, this, [this, root]() {
                         m_Quick->setMinimumSize(QSize(root->width(), root->height()));
                     });
-                    connect(root, &QQuickItem::heightChanged, this, [ = ]() {
+                    connect(root, &QQuickItem::heightChanged, this, [this, root]() {
                         m_Quick->setMinimumSize(QSize(root->width(), root->height()));
                     });
                     m_Quick->setMinimumSize(QSize(root->width(), root->height()));
@@ -304,12 +320,13 @@ void SKGHtmlBoardWidget::dataModified(const QString& iTableName, int iIdTransact
             QString stream;
             SKGError err = SKGReport::getReportFromTemplate(m_Report, m_Template, stream);
             IFKO(err) stream = err.getFullMessage();
-            stream = stream.remove(QRegularExpression(QLatin1String("<img[^>]*/>")));
+            static QRegularExpression reg(QStringLiteral("<img[^>]*/>"));
+            stream = stream.remove(reg);
 
             // Remove color of hyperlinks
             KColorScheme scheme(QPalette::Normal, KColorScheme::Window);
             auto color = scheme.foreground(KColorScheme::NormalText).color().name().right(6);
-            stream = stream.replace(QLatin1String("<a href"), QLatin1String("<a style=\"color: #") + color + ";\" href");
+            stream = stream.replace(QStringLiteral("<a href"), QStringLiteral("<a style=\"color: #") + color + ";\" href");
 
             m_Text->setText(stream);
 
@@ -320,7 +337,7 @@ void SKGHtmlBoardWidget::dataModified(const QString& iTableName, int iIdTransact
 
     // TODO(Stephane MANKOWSKI): No widget if no account (must not be hardcoded)
     bool exist = false;
-    getDocument()->existObjects(QLatin1String("account"), QLatin1String(""), exist);
+    getDocument()->existObjects(QStringLiteral("account"), QString(), exist);
     if (parentWidget() != nullptr) {
         setVisible(exist);
     }
