@@ -20,8 +20,11 @@
 #include "skgservices.h"
 #include <utility>
 
-SKGShow::SKGShow(QWidget* iParent)
-    : QToolButton(iParent), m_mode(OR), m_inTrigger(false), m_displayTitle(true)
+SKGShow::SKGShow(QWidget *iParent)
+    : QToolButton(iParent)
+    , m_mode(OR)
+    , m_inTrigger(false)
+    , m_displayTitle(true)
 {
     setPopupMode(QToolButton::InstantPopup);
     setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
@@ -59,15 +62,15 @@ QString SKGShow::getState()
 {
     QStringList itemsChecked;
     if (m_menu != nullptr) {
-        QList<QAction*> actionsList = m_menu->actions();
+        QList<QAction *> actionsList = m_menu->actions();
         int nb = actionsList.count();
         itemsChecked.reserve(nb);
         for (int i = 0; i < nb; ++i) {
-            QAction* act = actionsList.at(i);
+            QAction *act = actionsList.at(i);
             if (act != nullptr) {
-                auto* wact = qobject_cast<QWidgetAction*>(act);
+                auto *wact = qobject_cast<QWidgetAction *>(act);
                 if (wact != nullptr) {
-                    auto* pedit = qobject_cast<SKGPeriodEdit*>(wact->defaultWidget());
+                    auto *pedit = qobject_cast<SKGPeriodEdit *>(wact->defaultWidget());
                     itemsChecked.push_back(act->data().toString() % ":" % pedit->getState());
                 } else {
                     if (act->isChecked()) {
@@ -80,26 +83,26 @@ QString SKGShow::getState()
     return SKGServices::stringsToCsv(itemsChecked);
 }
 
-void SKGShow::setDefaultState(const QString& iState)
+void SKGShow::setDefaultState(const QString &iState)
 {
     m_defaultState = iState;
     setState(m_defaultState);
 }
 
-void SKGShow::setState(const QString& iState)
+void SKGShow::setState(const QString &iState)
 {
     if (m_menu != nullptr) {
         QStringList itemsChecked = SKGServices::splitCSVLine(iState.isEmpty() ? m_defaultState : iState);
 
         int nb = m_actions.count();
         for (int i = 0; i < nb; ++i) {
-            QAction* act = m_actions.at(i);
+            QAction *act = m_actions.at(i);
             if (act != nullptr) {
                 QString identifier = m_actions.at(i)->data().toString();
-                auto* wact = qobject_cast<QWidgetAction*>(act);
+                auto *wact = qobject_cast<QWidgetAction *>(act);
                 if (wact != nullptr) {
-                    auto* pedit = qobject_cast<SKGPeriodEdit*>(wact->defaultWidget());
-                    for (const auto& item : std::as_const(itemsChecked)) {
+                    auto *pedit = qobject_cast<SKGPeriodEdit *>(wact->defaultWidget());
+                    for (const auto &item : std::as_const(itemsChecked)) {
                         if (item.startsWith(identifier % ":")) {
                             pedit->setState(item.right(item.length() - identifier.length() - 1));
                             break;
@@ -123,32 +126,32 @@ QString SKGShow::getWhereClause() const
 {
     QString wc;
     if (m_menu != nullptr) {
-        QList<QAction*> actionsList = m_menu->actions();
+        QList<QAction *> actionsList = m_menu->actions();
         int nb = actionsList.count();
         bool noCheck = true;
         for (int i = 0; i < nb; ++i) {
-            QAction* act = actionsList.at(i);
+            QAction *act = actionsList.at(i);
 
             if (act != nullptr) {
-                auto* wact = qobject_cast<QWidgetAction*>(act);
+                auto *wact = qobject_cast<QWidgetAction *>(act);
                 if (wact != nullptr) {
-                    auto* pedit = qobject_cast<SKGPeriodEdit*>(wact->defaultWidget());
+                    auto *pedit = qobject_cast<SKGPeriodEdit *>(wact->defaultWidget());
                     if (!wc.isEmpty()) {
-                        wc += (m_mode == OR ? QLatin1String(" OR ") : QLatin1String(" AND "));
+                        wc += (m_mode == OR ? QStringLiteral(" OR ") : QStringLiteral(" AND "));
                     }
-                    wc += QLatin1Char('(') % pedit->getWhereClause() % QLatin1Char(')');
+                    wc += u'(' % pedit->getWhereClause() % u')';
                     noCheck = false;
 
                 } else {
                     if (act->isChecked()) {
                         if (!wc.isEmpty()) {
-                            wc += (m_mode == OR ? QLatin1String(" OR ") : QLatin1String(" AND "));
+                            wc += (m_mode == OR ? QStringLiteral(" OR ") : QStringLiteral(" AND "));
                         }
-                        wc += QLatin1Char('(') % m_whereclause.value(act) % QLatin1Char(')');
+                        wc += u'(' % m_whereclause.value(act) % u')';
                         noCheck = false;
 
                         if (m_whereclause.value(act).isEmpty()) {
-                            wc = QLatin1String("");
+                            wc = QString();
                             break;
                         }
                     }
@@ -156,7 +159,7 @@ QString SKGShow::getWhereClause() const
             }
         }
         if ((nb != 0) && noCheck) {
-            wc = QLatin1String("1=0");
+            wc = QStringLiteral("1=0");
         }
     }
     return wc;
@@ -168,19 +171,19 @@ QString SKGShow::getTitle() const
     if (m_menu != nullptr) {
         int nb = m_actions.count();
         for (int i = 0; i < nb; ++i) {
-            QAction* act = m_actions.at(i);
+            QAction *act = m_actions.at(i);
             if (act != nullptr) {
-                auto* wact = qobject_cast<QWidgetAction*>(act);
+                auto *wact = qobject_cast<QWidgetAction *>(act);
                 if (wact != nullptr) {
-                    auto* pedit = qobject_cast<SKGPeriodEdit*>(wact->defaultWidget());
+                    auto *pedit = qobject_cast<SKGPeriodEdit *>(wact->defaultWidget());
                     if (!wc.isEmpty()) {
-                        wc += (m_mode == OR ? QLatin1String(" + ") : QLatin1String(" , "));
+                        wc += (m_mode == OR ? QStringLiteral(" + ") : QStringLiteral(" , "));
                     }
                     wc += pedit->text();
                 } else {
                     if (act->isChecked()) {
                         if (!wc.isEmpty()) {
-                            wc += (m_mode == OR ? QLatin1String(" + ") : QLatin1String(" , "));
+                            wc += (m_mode == OR ? QStringLiteral(" + ") : QStringLiteral(" , "));
                         }
                         wc += act->toolTip();
                     }
@@ -209,19 +212,23 @@ int SKGShow::count()
     return m_check_to_check.count();
 }
 
-int SKGShow::addGroupedItem(const QString& iIdentifier, const QString& iText, const QString& iIcon,
-                            const QString& iWhereClose, const QString& iGroup, const QKeySequence& iShortcut)
+int SKGShow::addGroupedItem(const QString &iIdentifier,
+                            const QString &iText,
+                            const QString &iIcon,
+                            const QString &iWhereClose,
+                            const QString &iGroup,
+                            const QKeySequence &iShortcut)
 {
     if (m_menu != nullptr) {
-        QActionGroup* groupAction = m_groups.value(iGroup);
+        QActionGroup *groupAction = m_groups.value(iGroup);
         if (groupAction == nullptr) {
             groupAction = new QActionGroup(this);
             m_groups[iGroup] = groupAction;
         }
 
         QString name = iText;
-        name = name.replace('&', QLatin1String("&&"));
-        QAction* act = m_menu->addAction(name);
+        name = name.replace('&', QStringLiteral("&&"));
+        QAction *act = m_menu->addAction(name);
         if (act != nullptr) {
             act->setToolTip(name);
             act->setIcon(SKGServices::fromTheme(iIcon));
@@ -231,10 +238,10 @@ int SKGShow::addGroupedItem(const QString& iIdentifier, const QString& iText, co
                 act->setShortcuts(QList<QKeySequence>() << iShortcut << QKeySequence::fromString("Ctrl+Alt+" % iShortcut.toString()));
             }
 
-            m_check_to_check[act] = QLatin1String("");
-            m_check_to_uncheck[act] = QLatin1String("");
-            m_uncheck_to_check[act] = QLatin1String("");
-            m_uncheck_to_uncheck[act] = QLatin1String("");
+            m_check_to_check[act] = QString();
+            m_check_to_uncheck[act] = QString();
+            m_uncheck_to_check[act] = QString();
+            m_uncheck_to_uncheck[act] = QString();
             m_actions.push_back(act);
             m_icons.push_back(iIcon);
 
@@ -252,16 +259,16 @@ int SKGShow::addGroupedItem(const QString& iIdentifier, const QString& iText, co
     return -1;
 }
 
-int SKGShow::addPeriodItem(const QString& iIdentifier)
+int SKGShow::addPeriodItem(const QString &iIdentifier)
 {
     if (m_menu != nullptr) {
         auto m_periodEdit1 = new SKGPeriodEdit(this);
 
         // Set default
-        QDomDocument doc(QLatin1String("SKGML"));
-        QDomElement root = doc.createElement(QLatin1String("parameters"));
+        QDomDocument doc(QStringLiteral("SKGML"));
+        QDomElement root = doc.createElement(QStringLiteral("parameters"));
         doc.appendChild(root);
-        root.setAttribute(QLatin1String("period"), SKGServices::intToString(static_cast<int>(SKGPeriodEdit::ALL)));
+        root.setAttribute(QStringLiteral("period"), SKGServices::intToString(static_cast<int>(SKGPeriodEdit::ALL)));
         m_periodEdit1->setState(doc.toString());
 
         // Add widget in menu
@@ -270,14 +277,14 @@ int SKGShow::addPeriodItem(const QString& iIdentifier)
             act->setData(iIdentifier);
             act->setDefaultWidget(m_periodEdit1);
 
-            m_check_to_check[act] = QLatin1String("");
-            m_check_to_uncheck[act] = QLatin1String("");
-            m_uncheck_to_check[act] = QLatin1String("");
-            m_uncheck_to_uncheck[act] = QLatin1String("");
+            m_check_to_check[act] = QString();
+            m_check_to_uncheck[act] = QString();
+            m_uncheck_to_check[act] = QString();
+            m_uncheck_to_uncheck[act] = QString();
             m_actions.push_back(act);
-            m_icons.push_back(QLatin1String(""));
+            m_icons.push_back(QString());
 
-            m_whereclause[act] = QLatin1String("");
+            m_whereclause[act] = QString();
 
             connect(m_periodEdit1, &SKGPeriodEdit::changed, this, &SKGShow::triggerRefreshOnly);
 
@@ -291,19 +298,20 @@ int SKGShow::addPeriodItem(const QString& iIdentifier)
     return -1;
 }
 
-int SKGShow::addItem(const QString& iIdentifier, const QString& iText, const QString& iIcon,
-                     const QString& iWhereClose,
-                     const QString& iListIdToCheckWhenChecked,
-                     const QString& iListIdToUncheckWhenChecked,
-                     const QString& iListIdToCheckWhenUnchecked,
-                     const QString& iListIdToUncheckWhenUnchecked,
-                     const QKeySequence& iShortcut
-                    )
+int SKGShow::addItem(const QString &iIdentifier,
+                     const QString &iText,
+                     const QString &iIcon,
+                     const QString &iWhereClose,
+                     const QString &iListIdToCheckWhenChecked,
+                     const QString &iListIdToUncheckWhenChecked,
+                     const QString &iListIdToCheckWhenUnchecked,
+                     const QString &iListIdToUncheckWhenUnchecked,
+                     const QKeySequence &iShortcut)
 {
     if (m_menu != nullptr) {
         QString name = iText;
-        name = name.replace('&', QLatin1String("&&"));
-        QAction* act = m_menu->addAction(name);
+        name = name.replace('&', QStringLiteral("&&"));
+        QAction *act = m_menu->addAction(name);
         if (act != nullptr) {
             act->setToolTip(name);
             act->setIcon(SKGServices::fromTheme(iIcon));
@@ -332,22 +340,22 @@ int SKGShow::addItem(const QString& iIdentifier, const QString& iText, const QSt
     return -1;
 }
 
-void SKGShow::setListIdToCheckWhenChecked(int iIndex, const QString& iIds)
+void SKGShow::setListIdToCheckWhenChecked(int iIndex, const QString &iIds)
 {
     m_check_to_check[m_actions.at(iIndex)] = iIds;
 }
 
-void SKGShow::setListIdToCheckWhenUnchecked(int iIndex, const QString& iIds)
+void SKGShow::setListIdToCheckWhenUnchecked(int iIndex, const QString &iIds)
 {
     m_uncheck_to_check[m_actions.at(iIndex)] = iIds;
 }
 
-void SKGShow::setListIdToUncheckWhenChecked(int iIndex, const QString& iIds)
+void SKGShow::setListIdToUncheckWhenChecked(int iIndex, const QString &iIds)
 {
     m_check_to_uncheck[m_actions.at(iIndex)] = iIds;
 }
 
-void SKGShow::setListIdToUncheckWhenUnchecked(int iIndex, const QString& iIds)
+void SKGShow::setListIdToUncheckWhenUnchecked(int iIndex, const QString &iIds)
 {
     m_uncheck_to_uncheck[m_actions.at(iIndex)] = iIds;
 }
@@ -361,19 +369,18 @@ void SKGShow::addSeparator()
 
 void SKGShow::trigger()
 {
-    auto* act = qobject_cast<QAction*>(sender());
+    auto *act = qobject_cast<QAction *>(sender());
     if ((act != nullptr) && !m_inTrigger) {
         m_inTrigger = true;
 
         // Apply rules
-        QStringList over;
         if (act->isChecked()) {
             {
                 // Check items
                 QStringList items = SKGServices::splitCSVLine(m_check_to_check.value(act));
                 int nb = items.count();
                 for (int i = 0; i < nb; ++i) {
-                    QAction* act2 = getAction(items.at(i));
+                    QAction *act2 = getAction(items.at(i));
                     if ((act2 != nullptr) && act2 != act) {
                         act2->setChecked(true);
                     }
@@ -385,7 +392,7 @@ void SKGShow::trigger()
                 QStringList items = SKGServices::splitCSVLine(m_check_to_uncheck.value(act));
                 int nb = items.count();
                 for (int i = 0; i < nb; ++i) {
-                    QAction* act2 = getAction(items.at(i));
+                    QAction *act2 = getAction(items.at(i));
                     if ((act2 != nullptr) && act2 != act) {
                         act2->setChecked(false);
                     }
@@ -397,7 +404,7 @@ void SKGShow::trigger()
                 QStringList items = SKGServices::splitCSVLine(m_uncheck_to_check.value(act));
                 int nb = items.count();
                 for (int i = 0; i < nb; ++i) {
-                    QAction* act2 = getAction(items.at(i));
+                    QAction *act2 = getAction(items.at(i));
                     if ((act2 != nullptr) && act2 != act) {
                         act2->setChecked(true);
                     }
@@ -409,7 +416,7 @@ void SKGShow::trigger()
                 QStringList items = SKGServices::splitCSVLine(m_uncheck_to_uncheck.value(act));
                 int nb = items.count();
                 for (int i = 0; i < nb; ++i) {
-                    QAction* act2 = getAction(items.at(i));
+                    QAction *act2 = getAction(items.at(i));
                     if ((act2 != nullptr) && act2 != act) {
                         act2->setChecked(false);
                     }
@@ -427,7 +434,7 @@ void SKGShow::trigger()
             int nb = m_actions.count();
             icons.reserve(nb);
             for (int i = 0; i < nb; ++i) {
-                QAction* act2 = m_actions.at(i);
+                QAction *act2 = m_actions.at(i);
                 if ((act2 != nullptr) && act2->isChecked()) {
                     if (!m_icons.at(i).isEmpty()) {
                         if (mainIcon.isEmpty()) {
@@ -437,14 +444,14 @@ void SKGShow::trigger()
                         }
                     } else {
                         if (mainIcon.isEmpty()) {
-                            mainIcon = QLatin1String("show-menu");
+                            mainIcon = QStringLiteral("show-menu");
                         }
                     }
                 }
             }
         }
         if (mainIcon.isEmpty()) {
-            mainIcon = QLatin1String("show-menu");
+            mainIcon = QStringLiteral("show-menu");
         }
         setIcon(SKGServices::fromTheme(mainIcon, icons));
 
@@ -463,7 +470,6 @@ void SKGShow::triggerRefreshOnly()
     refreshTitle();
 }
 
-
 bool SKGShow::getDisplayTitle()
 {
     return m_displayTitle;
@@ -487,14 +493,14 @@ void SKGShow::refreshTitle()
     }
 }
 
-QAction* SKGShow::getAction(const QString& iIdentifier) const
+QAction *SKGShow::getAction(const QString &iIdentifier) const
 {
-    QAction* output = nullptr;
+    QAction *output = nullptr;
     if (m_menu != nullptr) {
-        QList<QAction*> actionsList = m_menu->actions();
+        QList<QAction *> actionsList = m_menu->actions();
         int nb = actionsList.count();
         for (int i = 0; (output == nullptr) && i < nb; ++i) {
-            QAction* act = actionsList.at(i);
+            QAction *act = actionsList.at(i);
             if ((act != nullptr) && act->data().toString() == iIdentifier) {
                 output = act;
             }
@@ -502,5 +508,3 @@ QAction* SKGShow::getAction(const QString& iIdentifier) const
     }
     return output;
 }
-
-
