@@ -11,9 +11,11 @@
 #include "skgsimpleperiodedit.h"
 #include <skgservices.h>
 
-
-SKGSimplePeriodEdit::SKGSimplePeriodEdit(QWidget* iParent)
-    : SKGComboBox(iParent), m_Mode(PREVIOUS_MONTHS) {}
+SKGSimplePeriodEdit::SKGSimplePeriodEdit(QWidget *iParent)
+    : SKGComboBox(iParent)
+    , m_Mode(PREVIOUS_MONTHS)
+{
+}
 
 SKGSimplePeriodEdit::~SKGSimplePeriodEdit() = default;
 
@@ -58,38 +60,38 @@ QString SKGSimplePeriodEdit::period() const
 void SKGSimplePeriodEdit::refreshList()
 {
     QDate today = QDate::currentDate();
-    QDate c = SKGServices::periodToDate(SKGServices::dateToPeriod(m_FirstDate, QLatin1String("M")));
+    QDate c = SKGServices::periodToDate(SKGServices::dateToPeriod(m_FirstDate, QStringLiteral("M")));
     if (!c.isValid()) {
         c = today;
     }
     c = c.addDays(1 - c.day());
 
-    QString smonth = SKGServices::dateToPeriod(today, QLatin1String("M"));
-    QString squarter = SKGServices::dateToPeriod(today, QLatin1String("Q"));
-    QString ssemester = SKGServices::dateToPeriod(today, QLatin1String("S"));
-    QString syear = SKGServices::dateToPeriod(today, QLatin1String("Y"));
+    QString smonth = SKGServices::dateToPeriod(today, QStringLiteral("M"));
+    QString squarter = SKGServices::dateToPeriod(today, QStringLiteral("Q"));
+    QString ssemester = SKGServices::dateToPeriod(today, QStringLiteral("S"));
+    QString syear = SKGServices::dateToPeriod(today, QStringLiteral("Y"));
 
     // Build the list
     QStringList list;
     do {
-        QString cmonth = SKGServices::dateToPeriod(c, QLatin1String("M"));
-        QString cquarter = SKGServices::dateToPeriod(c, QLatin1String("Q"));
-        QString csemester = SKGServices::dateToPeriod(c, QLatin1String("S"));
-        QString cyear = SKGServices::dateToPeriod(c, QLatin1String("Y"));
-        if ((cmonth != smonth && (((m_Mode & PREVIOUS_MONTHS)) != 0u)) ||
-            (cmonth == smonth && (((m_Mode & CURRENT_MONTH)) != 0u))) {
+        QString cmonth = SKGServices::dateToPeriod(c, QStringLiteral("M"));
+        QString cquarter = SKGServices::dateToPeriod(c, QStringLiteral("Q"));
+        QString csemester = SKGServices::dateToPeriod(c, QStringLiteral("S"));
+        QString cyear = SKGServices::dateToPeriod(c, QStringLiteral("Y"));
+        if ((cmonth != smonth && (((m_Mode & PREVIOUS_MONTHS)) != 0u)) || (cmonth == smonth && (((m_Mode & CURRENT_MONTH)) != 0u))) {
             list.insert(0, cmonth);
         }
-        if (!list.contains(cquarter) && ((cquarter != squarter && (((m_Mode & PREVIOUS_PERIODS)) != 0u)) ||
-                                         (cquarter == squarter && (((m_Mode & CURRENT_PERIOD)) != 0u)))) {
+        if (!list.contains(cquarter)
+            && ((cquarter != squarter && (((m_Mode & PREVIOUS_PERIODS)) != 0u)) || (cquarter == squarter && (((m_Mode & CURRENT_PERIOD)) != 0u)))) {
             list.insert(0, cquarter);
         }
-        if (!list.contains(csemester) && ((csemester != ssemester && (((m_Mode & PREVIOUS_PERIODS)) != 0u)) ||
-                                          (csemester == ssemester && (((m_Mode & CURRENT_PERIOD)) != 0u)))) {
+        if (!list.contains(csemester)
+            && ((csemester != ssemester && (((m_Mode & PREVIOUS_PERIODS)) != 0u)) || (csemester == ssemester && (((m_Mode & CURRENT_PERIOD)) != 0u)))) {
             list.insert(0, csemester);
         }
-        if (!list.contains(cyear) && ((cyear != syear && ((((m_Mode & PREVIOUS_PERIODS)) != 0u) || (((m_Mode & PREVIOUS_YEARS)) != 0u))) ||
-                                      (cyear == syear && ((((m_Mode & CURRENT_PERIOD)) != 0u) || (((m_Mode & CURRENT_YEAR)) != 0u))))) {
+        if (!list.contains(cyear)
+            && ((cyear != syear && ((((m_Mode & PREVIOUS_PERIODS)) != 0u) || (((m_Mode & PREVIOUS_YEARS)) != 0u)))
+                || (cyear == syear && ((((m_Mode & CURRENT_PERIOD)) != 0u) || (((m_Mode & CURRENT_YEAR)) != 0u))))) {
             list.insert(0, cyear);
         }
         if (cmonth == smonth || c >= today) {
@@ -152,4 +154,3 @@ void SKGSimplePeriodEdit::refreshList()
     }
     blockSignals(previous);
 }
-
