@@ -20,8 +20,10 @@
 #include "skgtraces.h"
 #include <utility>
 
-SKGTableWidget::SKGTableWidget(QWidget* iParent)
-    : QTableWidget(iParent), stickH(false), stickV(false)
+SKGTableWidget::SKGTableWidget(QWidget *iParent)
+    : QTableWidget(iParent)
+    , stickH(false)
+    , stickV(false)
 {
     this->installEventFilter(this);
     connect(horizontalScrollBar(), &QScrollBar::valueChanged, this, &SKGTableWidget::onActionTriggered);
@@ -30,12 +32,11 @@ SKGTableWidget::SKGTableWidget(QWidget* iParent)
     connect(verticalScrollBar(), &QScrollBar::rangeChanged, this, &SKGTableWidget::onRangeChanged);
 }
 
-SKGTableWidget::~SKGTableWidget()
-    = default;
+SKGTableWidget::~SKGTableWidget() = default;
 
 void SKGTableWidget::onRangeChanged()
 {
-    auto* scrollb = qobject_cast<QScrollBar*>(sender());
+    auto *scrollb = qobject_cast<QScrollBar *>(sender());
     if ((stickH && scrollb == horizontalScrollBar()) || (stickV && scrollb == verticalScrollBar())) {
         scrollb->setValue(scrollb->maximum());
     }
@@ -43,7 +44,7 @@ void SKGTableWidget::onRangeChanged()
 
 void SKGTableWidget::onActionTriggered()
 {
-    auto* scrollb = qobject_cast<QScrollBar*>(sender());
+    auto *scrollb = qobject_cast<QScrollBar *>(sender());
     if (scrollb != nullptr) {
         if (scrollb == horizontalScrollBar()) {
             stickH = (scrollb->value() == scrollb->maximum());
@@ -73,13 +74,13 @@ bool SKGTableWidget::stickVertical() const
     return stickV;
 }
 
-bool SKGTableWidget::eventFilter(QObject* iObject, QEvent* iEvent)
+bool SKGTableWidget::eventFilter(QObject *iObject, QEvent *iEvent)
 {
     if (iObject == this && iEvent != nullptr && iEvent->type() == QEvent::KeyPress) {
-        auto* kevent = dynamic_cast<QKeyEvent*>(iEvent);
+        auto *kevent = dynamic_cast<QKeyEvent *>(iEvent);
         if (kevent != nullptr) {
             if (kevent->key() == Qt::Key_Delete && state() != QAbstractItemView::EditingState) {
-                QList<QTableWidgetItem*> listOfSelectedItems = this->selectedItems();
+                QList<QTableWidgetItem *> listOfSelectedItems = this->selectedItems();
                 int nb = listOfSelectedItems.count();
                 if (nb > 0) {
                     // Build list of indexes
@@ -104,14 +105,14 @@ bool SKGTableWidget::eventFilter(QObject* iObject, QEvent* iEvent)
                     if (iEvent != nullptr) {
                         iEvent->accept();
                     }
-                    return true;  // stop the process
+                    return true; // stop the process
                 }
             } else if (kevent->matches(QKeySequence::Copy) && this->state() != QAbstractItemView::EditingState) {
                 copy();
                 if (iEvent != nullptr) {
                     iEvent->accept();
                 }
-                return true;  // stop the process
+                return true; // stop the process
             }
         }
     }
@@ -121,7 +122,7 @@ bool SKGTableWidget::eventFilter(QObject* iObject, QEvent* iEvent)
 
 void SKGTableWidget::copy()
 {
-    QItemSelectionModel* selection = selectionModel();
+    QItemSelectionModel *selection = selectionModel();
     if (selection != nullptr) {
         QModelIndexList indexes = selection->selectedIndexes();
 
@@ -137,18 +138,18 @@ void SKGTableWidget::copy()
         QString header_text;
         bool header_done = false;
         QString selected_text;
-        for (const auto& current : std::as_const(indexes)) {
+        for (const auto &current : std::as_const(indexes)) {
             selected_text.append(model()->data(previous).toString());
             if (!header_done) {
                 header_text.append(model()->headerData(previous.column(), Qt::Horizontal).toString());
             }
             if (current.row() != previous.row()) {
-                selected_text.append(QLatin1Char('\n'));
+                selected_text.append(u'\n');
                 header_done = true;
             } else {
-                selected_text.append(QLatin1Char(';'));
+                selected_text.append(u';');
                 if (!header_done) {
-                    header_text.append(QLatin1Char(';'));
+                    header_text.append(u';');
                 }
             }
             previous = current;
@@ -156,9 +157,7 @@ void SKGTableWidget::copy()
 
         // add last element
         selected_text.append(model()->data(previous).toString());
-        selected_text.append(QLatin1Char('\n'));
+        selected_text.append(u'\n');
         QApplication::clipboard()->setText(header_text + '\n' + selected_text);
     }
 }
-
-
