@@ -46,7 +46,7 @@ void SKGTabWidget::onCurrentChanged()
         // Build widgets
         auto kSave = new QPushButton(this);
         kSave->setIcon(SKGServices::fromTheme(QStringLiteral("document-save")));
-        kSave->setToolTip(i18nc("Verb", "Save this tab"));
+        kSave->setToolTip(i18nc("Verb", "Save the state of this tab"));
         kSave->setFlat(true);
         kSave->setMaximumSize(QSize(16, 16));
         kSave->show();
