@@ -10,18 +10,16 @@
  */
 #include "skgprogressbardesignerplugin.h"
 
-
-
 #include "skgprogressbar.h"
 #include "skgservices.h"
 
-SKGProgressBarDesignerPlugin::SKGProgressBarDesignerPlugin(QObject* iParent)
+SKGProgressBarDesignerPlugin::SKGProgressBarDesignerPlugin(QObject *iParent)
     : QObject(iParent)
 {
     m_initialized = false;
 }
 
-void SKGProgressBarDesignerPlugin::initialize(QDesignerFormEditorInterface*  iCore)
+void SKGProgressBarDesignerPlugin::initialize(QDesignerFormEditorInterface *iCore)
 {
     Q_UNUSED(iCore)
     if (m_initialized) {
@@ -36,34 +34,34 @@ bool SKGProgressBarDesignerPlugin::isInitialized() const
     return m_initialized;
 }
 
-QWidget* SKGProgressBarDesignerPlugin::createWidget(QWidget* iParent)
+QWidget *SKGProgressBarDesignerPlugin::createWidget(QWidget *iParent)
 {
     return new SKGProgressBar(iParent);
 }
 
 QString SKGProgressBarDesignerPlugin::name() const
 {
-    return QLatin1String("SKGProgressBar");
+    return QStringLiteral("SKGProgressBar");
 }
 
 QString SKGProgressBarDesignerPlugin::group() const
 {
-    return QLatin1String("SKG Widgets");
+    return QStringLiteral("SKG Widgets");
 }
 
 QIcon SKGProgressBarDesignerPlugin::icon() const
 {
-    return SKGServices::fromTheme(QLatin1String("quickopen"));
+    return SKGServices::fromTheme(QStringLiteral("quickopen"));
 }
 
 QString SKGProgressBarDesignerPlugin::toolTip() const
 {
-    return QLatin1String("A progress bar with colors");
+    return QStringLiteral("A progress bar with colors");
 }
 
 QString SKGProgressBarDesignerPlugin::whatsThis() const
 {
-    return QLatin1String("A progress bar with colors");
+    return QStringLiteral("A progress bar with colors");
 }
 
 bool SKGProgressBarDesignerPlugin::isContainer() const
@@ -73,20 +71,20 @@ bool SKGProgressBarDesignerPlugin::isContainer() const
 
 QString SKGProgressBarDesignerPlugin::domXml() const
 {
-    return QLatin1String("<widget class=\"SKGProgressBar\" name=\"SKGProgressBar\">\n"
-                         " <property name=\"geometry\">\n"
-                         "  <rect>\n"
-                         "   <x>0</x>\n"
-                         "   <y>0</y>\n"
-                         "   <width>100</width>\n"
-                         "   <height>10</height>\n"
-                         "  </rect>\n"
-                         " </property>\n"
-                         "</widget>\n");
+    return QStringLiteral(
+        "<widget class=\"SKGProgressBar\" name=\"SKGProgressBar\">\n"
+        " <property name=\"geometry\">\n"
+        "  <rect>\n"
+        "   <x>0</x>\n"
+        "   <y>0</y>\n"
+        "   <width>100</width>\n"
+        "   <height>10</height>\n"
+        "  </rect>\n"
+        " </property>\n"
+        "</widget>\n");
 }
 
 QString SKGProgressBarDesignerPlugin::includeFile() const
 {
-    return QLatin1String("skgprogressbar.h");
+    return QStringLiteral("skgprogressbar.h");
 }
-
