@@ -13,13 +13,13 @@
 #include "skgservices.h"
 #include "skgtabwidget.h"
 
-SKGTabWidgetDesignerPlugin::SKGTabWidgetDesignerPlugin(QObject* iParent)
+SKGTabWidgetDesignerPlugin::SKGTabWidgetDesignerPlugin(QObject *iParent)
     : QObject(iParent)
 {
     m_initialized = false;
 }
 
-void SKGTabWidgetDesignerPlugin::initialize(QDesignerFormEditorInterface*  iCore)
+void SKGTabWidgetDesignerPlugin::initialize(QDesignerFormEditorInterface *iCore)
 {
     Q_UNUSED(iCore)
     if (m_initialized) {
@@ -34,34 +34,34 @@ bool SKGTabWidgetDesignerPlugin::isInitialized() const
     return m_initialized;
 }
 
-QWidget* SKGTabWidgetDesignerPlugin::createWidget(QWidget* iParent)
+QWidget *SKGTabWidgetDesignerPlugin::createWidget(QWidget *iParent)
 {
     return new SKGTabWidget(iParent);
 }
 
 QString SKGTabWidgetDesignerPlugin::name() const
 {
-    return QLatin1String("SKGTabWidget");
+    return QStringLiteral("SKGTabWidget");
 }
 
 QString SKGTabWidgetDesignerPlugin::group() const
 {
-    return QLatin1String("SKG Widgets");
+    return QStringLiteral("SKG Widgets");
 }
 
 QIcon SKGTabWidgetDesignerPlugin::icon() const
 {
-    return SKGServices::fromTheme(QLatin1String("quickopen"));
+    return SKGServices::fromTheme(QStringLiteral("quickopen"));
 }
 
 QString SKGTabWidgetDesignerPlugin::toolTip() const
 {
-    return QLatin1String("A QTabWidget with more feature");
+    return QStringLiteral("A QTabWidget with more feature");
 }
 
 QString SKGTabWidgetDesignerPlugin::whatsThis() const
 {
-    return QLatin1String("A QTabWidget with more feature");
+    return QStringLiteral("A QTabWidget with more feature");
 }
 
 bool SKGTabWidgetDesignerPlugin::isContainer() const
@@ -71,20 +71,20 @@ bool SKGTabWidgetDesignerPlugin::isContainer() const
 
 QString SKGTabWidgetDesignerPlugin::domXml() const
 {
-    return QLatin1String("<widget class=\"SKGTabWidget\" name=\"SKGTabWidget\">\n"
-                         " <property name=\"geometry\">\n"
-                         "  <rect>\n"
-                         "   <x>0</x>\n"
-                         "   <y>0</y>\n"
-                         "   <width>100</width>\n"
-                         "   <height>100</height>\n"
-                         "  </rect>\n"
-                         " </property>\n"
-                         "</widget>\n");
+    return QStringLiteral(
+        "<widget class=\"SKGTabWidget\" name=\"SKGTabWidget\">\n"
+        " <property name=\"geometry\">\n"
+        "  <rect>\n"
+        "   <x>0</x>\n"
+        "   <y>0</y>\n"
+        "   <width>100</width>\n"
+        "   <height>100</height>\n"
+        "  </rect>\n"
+        " </property>\n"
+        "</widget>\n");
 }
 
 QString SKGTabWidgetDesignerPlugin::includeFile() const
 {
-    return QLatin1String("skgtabwidget.h");
+    return QStringLiteral("skgtabwidget.h");
 }
-
