@@ -10,18 +10,16 @@
  */
 #include "skgwebviewdesignerplugin.h"
 
-
-
 #include "skgservices.h"
 #include "skgwebview.h"
 
-SKGWebViewDesignerPlugin::SKGWebViewDesignerPlugin(QObject* iParent)
+SKGWebViewDesignerPlugin::SKGWebViewDesignerPlugin(QObject *iParent)
     : QObject(iParent)
 {
     m_initialized = false;
 }
 
-void SKGWebViewDesignerPlugin::initialize(QDesignerFormEditorInterface*  iCore)
+void SKGWebViewDesignerPlugin::initialize(QDesignerFormEditorInterface *iCore)
 {
     Q_UNUSED(iCore)
     if (m_initialized) {
@@ -36,34 +34,34 @@ bool SKGWebViewDesignerPlugin::isInitialized() const
     return m_initialized;
 }
 
-QWidget* SKGWebViewDesignerPlugin::createWidget(QWidget* iParent)
+QWidget *SKGWebViewDesignerPlugin::createWidget(QWidget *iParent)
 {
     return new SKGWebView(iParent);
 }
 
 QString SKGWebViewDesignerPlugin::name() const
 {
-    return QLatin1String("SKGWebView");
+    return QStringLiteral("SKGWebView");
 }
 
 QString SKGWebViewDesignerPlugin::group() const
 {
-    return QLatin1String("SKG Widgets");
+    return QStringLiteral("SKG Widgets");
 }
 
 QIcon SKGWebViewDesignerPlugin::icon() const
 {
-    return SKGServices::fromTheme(QLatin1String("quickopen"));
+    return SKGServices::fromTheme(QStringLiteral("quickopen"));
 }
 
 QString SKGWebViewDesignerPlugin::toolTip() const
 {
-    return QLatin1String("A web viewer with more features");
+    return QStringLiteral("A web viewer with more features");
 }
 
 QString SKGWebViewDesignerPlugin::whatsThis() const
 {
-    return QLatin1String("A web viewer with more features");
+    return QStringLiteral("A web viewer with more features");
 }
 
 bool SKGWebViewDesignerPlugin::isContainer() const
@@ -73,20 +71,20 @@ bool SKGWebViewDesignerPlugin::isContainer() const
 
 QString SKGWebViewDesignerPlugin::domXml() const
 {
-    return QLatin1String("<widget class=\"SKGWebView\" name=\"SKGWebView\">\n"
-                         " <property name=\"geometry\">\n"
-                         "  <rect>\n"
-                         "   <x>0</x>\n"
-                         "   <y>0</y>\n"
-                         "   <width>100</width>\n"
-                         "   <height>10</height>\n"
-                         "  </rect>\n"
-                         " </property>\n"
-                         "</widget>\n");
+    return QStringLiteral(
+        "<widget class=\"SKGWebView\" name=\"SKGWebView\">\n"
+        " <property name=\"geometry\">\n"
+        "  <rect>\n"
+        "   <x>0</x>\n"
+        "   <y>0</y>\n"
+        "   <width>100</width>\n"
+        "   <height>10</height>\n"
+        "  </rect>\n"
+        " </property>\n"
+        "</widget>\n");
 }
 
 QString SKGWebViewDesignerPlugin::includeFile() const
 {
-    return QLatin1String("skgwebview.h");
+    return QStringLiteral("skgwebview.h");
 }
-
