@@ -4,28 +4,33 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
-* This file implements classes SKGAdvice.
-*
-* @author Stephane MANKOWSKI / Guillaume DE BURE
-*/
+ * This file implements classes SKGAdvice.
+ *
+ * @author Stephane MANKOWSKI / Guillaume DE BURE
+ */
 #include "skgadvice.h"
 #include "skgdefine.h"
 #include <utility>
 
-SKGAdvice::SKGAdvice() :  QObject()
-{}
+SKGAdvice::SKGAdvice()
+    : QObject()
+{
+}
 
-SKGAdvice::SKGAdvice(const SKGAdvice& iAdvice)
-    :  QObject(), m_uuid(iAdvice.m_uuid), m_priority(iAdvice.m_priority),
-       m_shortMessage(iAdvice.m_shortMessage), m_longMessage(iAdvice.m_longMessage),
-       m_autoCorrections(iAdvice.m_autoCorrections)
+SKGAdvice::SKGAdvice(const SKGAdvice &iAdvice)
+    : QObject()
+    , m_uuid(iAdvice.m_uuid)
+    , m_priority(iAdvice.m_priority)
+    , m_shortMessage(iAdvice.m_shortMessage)
+    , m_longMessage(iAdvice.m_longMessage)
+    , m_autoCorrections(iAdvice.m_autoCorrections)
 
-{}
+{
+}
 
-SKGAdvice::~SKGAdvice()
-    = default;
+SKGAdvice::~SKGAdvice() = default;
 
-SKGAdvice& SKGAdvice::operator= (const SKGAdvice& iAdvice)
+SKGAdvice &SKGAdvice::operator=(const SKGAdvice &iAdvice)
 {
     if (&iAdvice != this) {
         m_priority = iAdvice.m_priority;
@@ -38,7 +43,7 @@ SKGAdvice& SKGAdvice::operator= (const SKGAdvice& iAdvice)
     return *this;
 }
 
-void SKGAdvice::setUUID(const QString& iUUID)
+void SKGAdvice::setUUID(const QString &iUUID)
 {
     if (m_uuid != iUUID) {
         m_uuid = iUUID;
@@ -64,7 +69,7 @@ int SKGAdvice::getPriority() const
     return m_priority;
 }
 
-void SKGAdvice::setShortMessage(const QString& iMessage)
+void SKGAdvice::setShortMessage(const QString &iMessage)
 {
     if (m_shortMessage != iMessage) {
         m_shortMessage = iMessage;
@@ -77,7 +82,7 @@ QString SKGAdvice::getShortMessage() const
     return m_shortMessage;
 }
 
-void SKGAdvice::setLongMessage(const QString& iMessage)
+void SKGAdvice::setLongMessage(const QString &iMessage)
 {
     if (m_longMessage != iMessage) {
         m_longMessage = iMessage;
@@ -90,11 +95,11 @@ QString SKGAdvice::getLongMessage() const
     return m_longMessage;
 }
 
-void SKGAdvice::setAutoCorrections(const QStringList& iCorrections)
+void SKGAdvice::setAutoCorrections(const QStringList &iCorrections)
 {
     SKGAdvice::SKGAdviceActionList tmp;
     tmp.reserve(iCorrections.count());
-    for (const auto& c : std::as_const(iCorrections)) {
+    for (const auto &c : std::as_const(iCorrections)) {
         SKGAdviceAction a;
         a.Title = c;
         a.IsRecommended = false;
@@ -104,7 +109,7 @@ void SKGAdvice::setAutoCorrections(const QStringList& iCorrections)
     setAutoCorrections(tmp);
 }
 
-void SKGAdvice::setAutoCorrections(const SKGAdvice::SKGAdviceActionList& iCorrections)
+void SKGAdvice::setAutoCorrections(const SKGAdvice::SKGAdviceActionList &iCorrections)
 {
     m_autoCorrections = iCorrections;
     Q_EMIT modified();
