@@ -17,10 +17,6 @@
 #include "skgbasemodeler_export.h"
 #include "skgerror.h"
 
-#ifndef SKG_QT6
-#define KTextTemplate Grantlee
-#endif
-
 class SKGDocument;
 /**
  * A report class for document
