@@ -8,11 +8,7 @@
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
-#ifdef SKG_QT6
 #include "q6sql_sqlite_p.h"
-#else
-#include "qsql_sqlite_p.h"
-#endif
 #include <qsqldriverplugin.h>
 #include <qstringlist.h>
 
