@@ -6,7 +6,7 @@ EXE=skgtestunit
 
 export PATH=${IN}/../../skgbankmodeler:${PATH}
 
-skrooge-yahoodl.py AIR.PA 20170801 20170809 1d
+skrooge-boursorama.py AIRBUS 2024-09-01 1d
 rc=$?
 if [ $rc != 0 ] ; then
 	exit $rc
