@@ -83,7 +83,7 @@ export MM_CHARSET="ISO-8859-15"
 export LC_ALL="fr_FR.ISO8859-1"
 
 SPECIALDIR="${OUT}skroogeconvert/téléchargement"
-mkdir ${SPECIALDIR}
+mkdir "${SPECIALDIR}"
 "${EXE}" --in 228904.csv --out "${SPECIALDIR}/228904.csv" --param header_position --value 1
 rc=$?
 if [ $rc != 0 ] ; then
