@@ -15,7 +15,7 @@
  * @param argc the number of arguments
  * @param argv the list of arguments
  */
-int main(int argc, char** argv)
+int main(int argc, char **argv)
 {
     Q_UNUSED(argc)
     Q_UNUSED(argv)
@@ -26,16 +26,16 @@ int main(int argc, char** argv)
     // Test inserts
     {
         SKGDocument document1;
-        SKGTESTERROR(QLatin1String("document1.initialize()"), document1.initialize(), true)
+        SKGTESTERROR(QStringLiteral("document1.initialize()"), document1.initialize(), true)
         SKGError err;
         {
             // Scope of the transaction
-            SKGBEGINTRANSACTION(document1, QLatin1String("INSERT"), err)
+            SKGBEGINTRANSACTION(document1, QStringLiteral("INSERT"), err)
 
             for (int i = 0; i < 10000; ++i) {
                 QString v = QString::number(i);
-                SKGTESTERROR(QLatin1String("PARAM:setParameter"), document1.setParameter(v, v), true)
-                SKGTEST(QLatin1String("PARAM:getParameter"), document1.getParameter(v), v)
+                SKGTESTERROR(QStringLiteral("PARAM:setParameter"), document1.setParameter(v, v), true)
+                SKGTEST(QStringLiteral("PARAM:getParameter"), document1.getParameter(v), v)
             }
         }
     }
